# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2022 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# -------------------------------------------------------------------------------

# File:	clients/edirectory_auto.ycp
# Package:	Configuration of edirectory
# Summary:	Client for autoinstallation
# Authors:	Anas Nashif <nashif@suse.de>
#
# $Id: edirectory_auto.ycp,v 1.1.2.3 2005/04/14 21:18:44 rhaslam Exp $
#
# This is a client for autoinstallation. It takes its arguments,
# goes through the configuration and return the setting.
# Does not do any changes to the configuration.

# @param function to execute
# @param map/list of edirectory settings
# @return [Hash] edited settings, Summary or boolean on success depending on called function
# @example map mm = $[ "FAIL_DELAY" : "77" ];
# @example map ret = WFM::CallFunction ("edirectory_auto", [ "Summary", mm ]);
module Yast
  class EdirectoryAutoClient < Client
    def main
      Yast.import "UI"

      textdomain "novell-edirectory"

      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("Edirectory auto started")

      Yast.import "Edirectory"
      Yast.include self, "novell-edirectory/wizards.rb"

      @ret = nil
      @func = ""
      @param = {}

      # Check arguments
      if Ops.greater_than(Builtins.size(WFM.Args), 0) &&
          Ops.is_string?(WFM.Args(0))
        @func = Convert.to_string(WFM.Args(0))
        if Ops.greater_than(Builtins.size(WFM.Args), 1) &&
            Ops.is_map?(WFM.Args(1))
          @param = Convert.to_map(WFM.Args(1))
        end
      end
      Builtins.y2debug("func=%1", @func)
      Builtins.y2debug("param=%1", @param)

      # Create a summary
      if @func == "Summary"
        @ret = Ops.get_string(Edirectory.Summary, 0, "")
      # Reset configuration
      elsif @func == "Reset"
        Edirectory.Import({})
        @ret = {}
      # Change configuration (run AutoSequence)
      elsif @func == "Change"
        Edirectory.autoyast_tool = true
        @ret = EdirectoryAutoSequence()
      # Import configuration
      elsif @func == "Import"
        @ret = Edirectory.Import(@param)
      # Return actual state
      elsif @func == "Export"
        Edirectory.auto_clone = true
        if Edirectory.EdirSettings == nil || Edirectory.EdirSettings == {}
          Edirectory.Read
        end
        @ret = Edirectory.Export
      # Return needed packages
      elsif @func == "Packages"
        @ret = Edirectory.AutoPackages
      # Read current state
      elsif @func == "Read"
        Yast.import "Progress"
        @progress_orig = Progress.set(false)
        @ret = Edirectory.Read
        Progress.set(@progress_orig)
      # Write given settings
      elsif @func == "Write"
        Yast.import "Progress"
        @progress_orig = Progress.set(false)
        @ret = Edirectory.Write
        while @ret == :again || @ret == :again_up
          # run the edirectory dialog workflow.
          @stored = Edirectory.ExportSettings
          @seq = nil
          if Mode.update || Mode.autoupgrade
            @seq = Convert.to_symbol(
              WFM.CallFunction("edirectory", [path(".upgrade")])
            )
          else
            @seq = Convert.to_symbol(
              WFM.CallFunction("edirectory", [path(".propose")])
            )
          end
          Edirectory.Import(@stored) if @seq != :next # restore the previous settings.
          @ret = Edirectory.Write # Try the eDirectory config again
        end
        Progress.Finish

        Progress.set(@progress_orig)
      # Return if configuration  was changed
      # return boolean
      elsif @func == "GetModified"
        Edirectory.globals_configured = true
        @ret = Edirectory.globals_configured
      # Set modified flag
      # return boolean
      elsif @func == "SetModified"
        Edirectory.globals_configured = true
        @ret = true
      else
        Builtins.y2error("Unknown function: %1", @func)
        @ret = false
      end

      Builtins.y2debug("ret=%1", @ret)
      Builtins.y2milestone("Edirectory auto finished")
      Builtins.y2milestone("----------------------------------------")

      deep_copy(@ret)

      # EOF
    end
  end
end

Yast::EdirectoryAutoClient.new.main
