# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2022 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# -------------------------------------------------------------------------------

# File:	modules/Edirectory.ycp
# Package:	Configuration of edirectory
# Summary:	Edirectory settings, input and output functions
# Authors:	Reed B. Haslam (Novell)
#
# $Id: Edirectory.ycp,v 1.1.2.130 2005/10/28 23:08:51 rhaslam Exp $
#
# Representation of the configuration of edirectory.
# Input and output routines.
require "yast"

module Yast
  class EdirectoryClass < Module
    def main
      require 'json'

      textdomain "novell-edirectory"

      Yast.import "Service"
      Yast.import "Progress"
      Yast.import "Report"
      Yast.import "Package"
      Yast.import "Summary"
      Yast.import "Mode"
      Yast.import "Stage"
      Yast.import "Popup"
      Yast.import "ProductControl"
      Yast.import "String"
      Yast.import "Hostname"
      Yast.import "FileUtils"
      Yast.import "Wizard"
      Yast.import "Arch"

      Yast.import "EdirUtils"
      Yast.import "NovellUtils"
      Yast.import "NovellLDAP"
      Yast.import "NovellLDAPUI"
      Yast.import "NovellValidators"
      Yast.import "NovellPatterns"
      Yast.import "NovellAddonInstall"
      Yast.import "NtpClient"

      # Settings Maps
      @EdirSettings = {}
      @old_EdirSettings = {} # For upgrade mode. These are the values from the old OES 1.0 or 2.0 config file.
      @old_XadSettings = {} # For upgrade mode. These are the values from the old OES 2.0 config file.
      @old_DnsSettings = {} # For upgrade mode. These are the values from the old OES 2.0 config file.
      @DnsSettings = {}

      @ndsconfigWorked = true
      @backButtonClicked = false
      @quickInstallBackButtonClicked = false

      @auto_clone = false
      # Global variables
      @oesinstall_dir = "/opt/novell/oes-install"
      @schemaLogPath = "/var/opt/novell/eDirectory/log/oes_schema.log"

      @upgrade_from = ""
      @eDirInstalled = false
      @dibExists = false
      @eDirRunning = false
      @eDir_Being_Configured = false
      @ndsconfig_bin = "/opt/novell/eDirectory/bin/ndsconfig" # Location of the ndsconfig binary
      @dibLocation = "/var/opt/novell/eDirectory/data/dib"
      @ndsConfigFailureMap = {}
      @rerun_workflow = false
      @retryInProgress = false
      @nameMapCheck = false

      @ldap_bind_no_response = _(
        "The attempt to perform a secure LDAP bind did not respond in 2 minutes\n" +
          "This may indicate a problem with LDAP on the target server.\n" +
          "If you are confident that your credentials are correct you may continue,\n" +
          "otherwise please determine if LDAP is running correctly on the target system\n" +
          "Do you want to continue?"
      )
      @ldap_secure_bind_timeout = _("LDAP secure bind timeout")
      @validateCredsWarning = _(
        "User credentials failed to validate Using:\n" +
          "      Server: %1\n" +
          "      User: %2\n" +
          "      LDAP port: %3\n" +
          "Do you want to continue anyway?"
      )
      @credentialsFailedWarning = _("Credentials Failed")
      @adminWarning = _(
        "\n" +
          "The administrator specified is not a tree administrator. \n" +
          "\n" +
          "\n" +
          "Ensure that the DSfW schema is already extended and the\n" +
          "specified user has administrator rights on the mapped\n" +
          "container, security container, and DNS-related contexts."
      )

      # XAD and upgrade test stuff...

      @xadTestMode = false
      @doXadSequence = false


      @upgradeTestMode = false # if set to "true", then there must be an OES 1.0 or OES 2.0 spx /etc/sysconfig/edirectory file in place
      # Also, xadTestMode above must also be set to "true".

      @xad_pattern = Convert.to_string(
        SCR.Read(path(".sysconfig.novell.xad.PATTERN_NAME"))
      )

      @xad_packages_installed = NovellPatterns.IsPatternInstalled(@xad_pattern)

      @migration_pattern_installed = NovellPatterns.IsPatternInstalled(
        "novell-premigration-server"
      )

      @ndsdcinit_bin = "perl /opt/novell/xad/sbin/ndsdcinit.pl" # Location of the ndsdcinit (XAD) script

      @service_configured_str = _(
        "It appears that %1 has already been configured. It cannot be reconfigured with this interface."
      )

      @channelUpgrade = false

      @oesContext = "ou=OESSystemObjects"

      # Data was modified?
      @modified = false

      # is the proposal valid?
      @proposal_valid = false

      @globals_configured = false

      # autoyast_tool, set to true only when the autoyast control file
      # generation tool is running
      @autoyast_tool = false

      # Abort function
      # return boolean return true if abort
      @AbortFunction = fun_ref(method(:Modified), "boolean ()")
      Edirectory()
    end

    # Abort function
    # @return [Boolean] return true if abort
    def Abort
      return @AbortFunction.call == true if @AbortFunction != nil
      false
    end

    # Data was modified?
    # @return true if modified
    def Modified
      Builtins.y2debug("modified=%1", @modified)
      @modified
    end


    #*******************  BEGIN UTILITY ROUTINES ********************************

    def GetNameServer
      retString = ""

      resolvPath = "/etc/resolv.conf"
      if Ops.greater_than(SCR.Read(path(".target.size"), resolvPath), 0)
        build_str = Convert.to_string(
          SCR.Read(path(".target.string"), resolvPath)
        ) # read the contents of the resolv.conf file

        myLines = Builtins.splitstring(build_str, "\n")
        Builtins.foreach(myLines) do |testLine|
          testLine = Builtins.tolower(NovellUtils.StripLeading(testLine, " \t"))
          Builtins.y2milestone(
            "edirectory.GetNameServer:test line: '%1'",
            testLine
          )
          if Builtins.search(testLine, "nameserver") == 0
            nameserverlist = Builtins.splitstring(testLine, " ")
            retString = NovellUtils.CleanUpString(
              Ops.get(nameserverlist, 1, "")
            )
            Builtins.y2milestone(
              "edirectory.GetNameServer(): retstring: '%1'",
              retString
            )
            raise Break
          end
        end
      end
      retString
    end

    # Get the list of ntp servers
    #
    # @return [String] ntp server on success
    def GetNTPServerList
      if !Mode.autoupgrade
        NtpClient.Read
      end
      ntp_file = "/etc/chrony.conf"
      retserverlist = []
      if Ops.greater_than(SCR.Read(path(".target.size"), ntp_file), 0)
        retserverlist = NtpClient.GetUsedNtpServers
      else
        Builtins.y2milestone(
          "Edirectory:GetNTPServer - /etc/chrony.conf not present"
        )
      end
      Builtins.y2milestone(
        "Edirectory:GetNTPServer - ntp servers: %1",
        retserverlist
      )
      deep_copy(retserverlist)
    end

    def GetNTPServer(i)
      mylist = GetNTPServerList()
      if Ops.less_or_equal(Builtins.size(mylist), i)
        return ""
      else
        return mylist[i]
      end
    end


    # Configure the SuSEFirewall with the appropriate ports
    #
    # @return [Boolean] true on success
    def ConfigureFirewall
      return true if @xadTestMode

      local_server = Ops.get(NovellLDAP.GetLocalServers(nil), 0, {})

      retVal = NovellUtils.SetFirewallPort(
        Ops.get_integer(local_server, "CONFIG_LDAP_PORT", 389),
        :tcp,
        true
      )
      retVal = retVal &&
        NovellUtils.SetFirewallPort(
          Ops.get_integer(local_server, "CONFIG_LDAP_SECURE_PORT", 636),
          :tcp,
          true
        )
      retVal = retVal &&
        NovellUtils.SetFirewallPort(
          Ops.get_integer(@EdirSettings, "CONFIG_EDIR_HTTP_PORT", 8028),
          :tcp,
          true
        )
      retVal = retVal &&
        NovellUtils.SetFirewallPort(
          Ops.get_integer(@EdirSettings, "CONFIG_EDIR_HTTPS_PORT", 8030),
          :tcp,
          true
        )
      retVal = retVal && NovellUtils.SetFirewallPort(524, :tcp, true)
      retVal = retVal && NovellUtils.SetFirewallPort(524, :udp, true)
      retVal = retVal && NovellUtils.SetFirewallPort(123, :udp, true) # Bugzilla #251135, open NTP port

      retVal = retVal && NovellUtils.SetFirewallPort(7023, :tcp, true) # NCS ports
      retVal = retVal && NovellUtils.SetFirewallPort(224, :udp, true)

      slpMode = Ops.get_string(@EdirSettings, "CONFIG_EDIR_SLP_MODE", "none")
      if slpMode == "da" || slpMode == "da_server" || slpMode == "multicast"
        retVal = retVal && NovellUtils.SetFirewallPort(427, :both, true)
      end

      if Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        Builtins.y2milestone("Edirectory:ConfigureFirewall:setting XAD ports.")
        xad_tcp_ports = [
          445, # Microsoft-DS traffic (445/tcp, 445/udp)
          464, # kpasswdd
          389,
          636, # LDAP(389/tcp, 636/tcp) and LDAP ping (389/udp)
          88, # Kerberos (88/tcp, 88/udp)
          53, # DNS (53/tcp, 53/udp)
          135, # RPC endpoint mapper (135/tcp, 135/udp)
          3268, # Global Catalog LDAP (3268/tcp)
          3269, # Global Catalog LDAP over SSL (3269/tcp)
          137, # NetBIOS name service (137/tcp, 137/udp)
          139, # NetBIOS session service (139/tcp)
          139, # NetBIOS session service (139/tcp)
          8025, #
          1389, # for DNS, DHCP with DSFW
          1636
        ] # for DNS, DHSP, and iPrint with DSFW
        xad_udp_ports = [
          445, # Microsoft-DS traffic (445/tcp, 445/udp)
          464, # kpasswdd
          389, # LDAP(389/tcp) and LDAP ping (389/udp)
          88, # Kerberos (88/tcp, 88/udp)
          53, # DNS (53/tcp, 53/udp)
          135, # RPC endpoint mapper (135/tcp, 135/udp)
          123, # Network Time Protocol (NTP) (123/udp)
          137, # NetBIOS name service (137/tcp, 137/udp)
          138, # NetBIOS datagram service (138/udp)
          8025
        ] #
        Builtins.foreach(xad_tcp_ports) do |port|
          retVal = retVal && NovellUtils.SetFirewallPort(port, :tcp, true)
        end
        Builtins.foreach(xad_udp_ports) do |port|
          retVal = retVal && NovellUtils.SetFirewallPort(port, :udp, true)
        end
      end

#Due to one of the SLES12 fix, changing the mode to normal and Activating the firewall

      old_mode = Mode.mode
      begin
        Mode.SetMode("normal")
        Builtins.y2milestone("Setting mode to %1",Mode.mode)
        NovellUtils.ReloadFirewall
      ensure
        Mode.SetMode(old_mode)
        Builtins.y2milestone("Setting mode to %1",Mode.mode)
      end

      Builtins.y2milestone(
        "Edirectory::ConfigureFirewall() returned: %1",
        retVal
      )
      retVal
    end

    def WriteNRMCerts
      ret = true

      if Mode.update || Mode.autoupgrade
        symlink1 = "/etc/opt/novell/httpstkd/server.pem"
        symlink2 = "/etc/opt/novell/httpstkd/server.key"
        extension = "org"

        cmd = Builtins.sformat("test -f %1", symlink1) # check for the file
        ccode = Convert.to_integer(SCR.Execute(path(".target.bash"), cmd))
        if ccode == 0 # the file exists
          cmd = Builtins.sformat("test -h %1", symlink1) # check if file is a symlink
          ccode = Convert.to_integer(SCR.Execute(path(".target.bash"), cmd))
          if ccode != 0 # file is not a symlink
            cmd = Builtins.sformat("mv %1 %2.%3", symlink1, symlink1, extension) # move first file
            ccode = Convert.to_integer(SCR.Execute(path(".target.bash"), cmd))
            if ccode != 0
              ret = false
              Builtins.y2milestone(
                "Edirectory::WriteNRMCerts:failed to execute %1  ccode %2",
                cmd,
                ccode
              )
            end
            cmd = Builtins.sformat("mv %1 %2.%3", symlink2, symlink2, extension) # move second file
            ccode = Convert.to_integer(SCR.Execute(path(".target.bash"), cmd))
            if ccode != 0
              ret = false
              Builtins.y2milestone(
                "Edirectory::WriteNRMCerts:failed to execute %1  ccode %2",
                cmd,
                ccode
              )
            end
          else
            Builtins.y2milestone(
              "Edirectory::WriteNRMCerts: %1 is a symlink.  ccode %2",
              symlink1,
              ccode
            )
          end
        else
          Builtins.y2milestone(
            "Edirectory::WriteNRMCerts:failed to find %1.  ccode %2",
            symlink1,
            ccode
          )
        end
      end
      ret
    end

    # Setup cert file to use eDirectory certs and keys for http services.
    #
    # Return values
    #
    #     true - setup worked
    def SetupEdirCerts
      ret = true

      ret = SCR.Write(
        path(".target.string"),
        "/opt/novell/oes-install/eDirCerts.txt",
        ""
      )
      ret = SCR.Write(
        path(".target.string"),
        "/opt/novell/oes-install/eDirCerts.txt",
        nil
      ) # flush
      Builtins.y2milestone(
        "Edirectory:SetupEdirCerts.wrote the file /opt/novell/oes-install/eDirCerts.txt"
      )
      WriteNRMCerts()

      ret
    end

    def SoftwareInstalled
      # Verify the eDirectory software been installed
      installed = Package.Installed("edirectory-oes-server")
      Builtins.y2milestone(
        "Edirectory::SoftwareInstalled() returned %1",
        installed
      )
      installed
    end


    # Proposes a new or existing tree type based on
    # currently entered parameters
    #
    # @return [String] "new" or "existing"
    def ProposeTreeType
      treeType = "existing"
      server_list = Ops.get_list(
        NovellLDAP.Settings,
        "CONFIG_LDAP_SERVERS_LIST",
        []
      )
      if NovellLDAP.RemoteAddressExists(server_list)
        Builtins.y2milestone(
          "remote address found in server list -- proposing \"existing\" tree"
        )
        treeType = "existing"
      end
      treeType
    end

    # Execute the script to check the rights of the user on the [root] partition
    # @param [String] admin name to check the rights against
    # @param [String] admin password
    # @param [String] tree name
    # @param [String] tree root IP address
    # @return admin
    def ValidateTreeRootRights(admin, pwd, ip, tree)
      cmd = Builtins.sformat(
        "/opt/novell/xad/share/dcinit/validateInput.pl -T -a '%1' -w '%2' -i %3 -t %4",
        admin,
        pwd,
        ip,
        tree
      )
      #Execute the script to check the rights of the specified user
      returnvalue = Convert.to_integer(SCR.Execute(path(".target.bash"), cmd))
      if returnvalue != 0
        Builtins.y2milestone(
          "Edirectory.ValidateTreeRootRights:The admin %1 doesn't have right on the [root] partition ",
          admin
        )
        return returnvalue
      end

      0
    end

    # Get the tree name
    #
    # installType can be "adc" or "child"
    def GetExistingTreeName(installType)
      ret = ""

      cmd = Builtins.sformat(
        "/opt/novell/xad/share/dcinit/provisionTools.sh get-existing-tree -d '%1' -t 'treeName'",
        installType
      )

      Builtins.y2milestone("Edirectory.GetExistingTreeName:executing:%1", cmd)

      val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      exit = Ops.get_integer(val, "exit", -1)
      Builtins.y2milestone("Edirectory.GetExistingTreeName:returned:%1", val)

      return "psf" if @xadTestMode

      if exit == 0
        ret = Ops.get_string(val, "stdout", "")
        ret = "" if ret == nil

        # remove the line feed from the stdout string
        ret = NovellUtils.StripTrailing(ret, "\n ")

        Builtins.y2milestone("Edirectory.GetExistingTreeName:tree is %1", ret)
      end
      ret
    end

    # Get existing server IP
    #
    # installType can be "adc" or "child"
    def GetServerIP(installType)
      ret = ""

      cmd = Builtins.sformat(
        "/opt/novell/xad/share/dcinit/provisionTools.sh get-existing-tree -d '%1' -t 'serverIpAddress'",
        installType
      )

      Builtins.y2milestone("Edirectory.GetServerIP:executing:%1", cmd)

      val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      exit = Ops.get_integer(val, "exit", -1)
      Builtins.y2milestone("Edirectory.GetServerIP:returned:%1", val)

      return "137.65.59.88" if @xadTestMode

      if exit == 0
        ret = Ops.get_string(val, "stdout", "")
        ret = "" if ret == nil

        # remove the line feed from the stdout string
        ret = NovellUtils.StripTrailing(ret, "\n ")

        Builtins.y2milestone(
          "Edirectory.GetServerIP:existing server IP is %1",
          ret
        )
      end
      ret
    end

    # Get forest root domain
    #
    # installType can be "adc" or "child"
    def GetForestRoot(installType)
      ret = ""

      cmd = Builtins.sformat(
        "/opt/novell/xad/share/dcinit/provisionTools.sh get-domain -d '%1' -t 'forestDomain'",
        installType
      )

      Builtins.y2milestone("Edirectory.GetForestRoot:executing:%1", cmd)

      val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      exit = Ops.get_integer(val, "exit", -1)
      Builtins.y2milestone("Edirectory.GetForestRoot:returned:%1", val)

      return "novell.com" if @xadTestMode

      if exit == 0
        ret = Ops.get_string(val, "stdout", "")
        ret = "" if ret == nil

        # remove the line feed from the stdout string
        ret = NovellUtils.StripTrailing(ret, "\n ")

        Builtins.y2milestone("Edirectory.GetForestRoot:forest root is %1", ret)
      end
      ret
    end

    # Get parent domain
    #
    #
    def GetParentDomain
      ret = ""

      cmd = "/opt/novell/xad/share/dcinit/provisionTools.sh get-domain -d 'child' -t 'parentDomain'"

      Builtins.y2milestone("Edirectory.GetParentDomain:executing:%1", cmd)

      val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      exit = Ops.get_integer(val, "exit", -1)
      Builtins.y2milestone("Edirectory.GetParentDomain:returned:%1", val)

      return "novell.com" if @xadTestMode

      if exit == 0
        ret = Ops.get_string(val, "stdout", "")
        ret = "" if ret == nil

        # remove the line feed from the stdout string
        ret = NovellUtils.StripTrailing(ret, "\n ")

        Builtins.y2milestone(
          "Edirectory.GetParentDomain:parent domain is %1",
          ret
        )
      end
      ret
    end

    # Get parent domain IP
    #
    #
    def GetParentDomainIP
      ret = ""

      cmd = "/opt/novell/xad/share/dcinit/provisionTools.sh get-domain -d 'child' -t 'parentIpAddress'"

      Builtins.y2milestone("Edirectory.GetParentDomainIP:executing:%1", cmd)

      val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      exit = Ops.get_integer(val, "exit", -1)
      Builtins.y2milestone("Edirectory.GetParentDomainIP:returned:%1", val)

      return "137.65.59.87" if @xadTestMode

      if exit == 0
        ret = Ops.get_string(val, "stdout", "")
        ret = "" if ret == nil

        # remove the line feed from the stdout string
        ret = NovellUtils.StripTrailing(ret, "\n ")

        Builtins.y2milestone(
          "Edirectory.GetParentDomainIP:parent domain IP is %1",
          ret
        )
      end
      ret
    end

    # Get the parent domain administrator
    #
    #
    def GetDomainAdministrator(domainName)
      ret = ""

      admin = NovellUtils.Ldap2Nds(
        Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
      )
      admPassword = Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_PASSWORD", "")

      cmd = Builtins.sformat(
        "/opt/novell/xad/share/dcinit/provisionTools.sh get-admin-name -a '%1' -d '%2'",
        admin,
        domainName
      )

      if @xadTestMode == false
        Builtins.y2milestone(
          "Edirectory.GetDomainAdministrator:executing:%1",
          cmd
        )
      end

      cmd = Builtins.sformat("ADM_PASSWD='%1' %2", admPassword, cmd)

      if @xadTestMode
        Builtins.y2milestone(
          "Edirectory.GetDomainAdministrator:executing:%1",
          cmd
        )
      end

      val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      exit = Ops.get_integer(val, "exit", -1)
      Builtins.y2milestone("Edirectory.GetDomainAdministrator:returned:%1", val)

      return "cn=parentadmin,o=novell" if @xadTestMode

      if exit == 0
        ret = Ops.get_string(val, "stdout", "")
        ret = "" if ret == nil

        # remove the line feed from the stdout string
        ret = NovellUtils.StripTrailing(ret, "\n ")

        Builtins.y2milestone(
          "Edirectory.GetParnetDomainAdministrator:admin is %1",
          ret
        )
      end
      ret
    end

    # See if a domain exists in a forest..
    #
    #
    def CheckNameMapContainer(container, ipAddress)
      tree = Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_TREE_NAME", "")
      admin = NovellUtils.Ldap2Nds(
        Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
      )
      admPassword = Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_PASSWORD", "")

      cmd = Builtins.sformat(
        "TREE_NAME=%1 /opt/novell/xad/share/dcinit/provisionTools.sh validate-new-nm-domain -p %2 -c '%3' -a '%4'",
        tree,
        ipAddress,
        container,
        admin
      )
      Builtins.y2milestone("Edirectory.CheckNameMapContainer:executing:%1", cmd)

      cmd = Builtins.sformat("ADM_PASSWD='%1' %2", admPassword, cmd)
      val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      exit = Ops.get_integer(val, "exit", -1)
      Builtins.y2milestone(
        "Edirectory.CheckNameMapContainer:return code:%1",
        exit
      )

      exit
    end

    # See if a domain exists in a forest.
    #
    #
    def DoesDomainExistInForest(domain, ipAddress)
      tree = Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_TREE_NAME", "")
      admin = NovellUtils.Ldap2Nds(
        Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
      )
      admPassword = Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_PASSWORD", "")

      cmd = Builtins.sformat(
        "TREE_NAME=%1 /opt/novell/xad/share/dcinit/provisionTools.sh domain-query -d %2 -a '%3' -p %4",
        tree,
        domain,
        admin,
        ipAddress
      )
      Builtins.y2milestone(
        "Edirectory.DoesDomainExistInForest:executing:%1",
        cmd
      )
      cmd = Builtins.sformat("ADM_PASSWD='%1' %2", admPassword, cmd)
      if @xadTestMode
        Builtins.y2milestone(
          "xad.Edirectory.DoesDomainExistInForest:executing:%1",
          cmd
        )
      end
      val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      exit = Ops.get_integer(val, "exit", -1)
      Builtins.y2milestone(
        "Edirectory.DoesDomainExistInForest:return code:%1",
        exit
      )

      exit
    end

    # See if a parent domain is name mapped.
    #
    # -1 = error, 1 = name mapped, and 0 = NOT name mapped
    def IsParentDomainMapped(domain)
      retCode = -1
      stdout = ""

      admin = NovellUtils.Ldap2Nds(
        Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
      )
      admPassword = Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_PASSWORD", "")

      cmd = Builtins.sformat(
        "/opt/novell/xad/share/dcinit/provisionTools.sh get-domain-type -d %1 -a '%2'",
        domain,
        admin
      )
      Builtins.y2milestone("Edirectory.IsParentDomainMapped:executing:%1", cmd)
      cmd = Builtins.sformat("ADM_PASSWD='%1' %2", admPassword, cmd)
      if @xadTestMode
        Builtins.y2milestone(
          "xad.Edirectory.IsParentDomainMapped:executing:%1",
          cmd
        )
      end

      val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      Builtins.y2milestone(
        "Edirectory.IsParentDomainMapped:get-domain-type returned:%1",
        val
      )

      exit = Ops.get_integer(val, "exit", -1)
      if exit == 0
        stdout = Ops.get_string(val, "stdout", "")
        # remove the line feed from the stdout string
        stdout = NovellUtils.StripTrailing(stdout, "\n ")
        if stdout == "1"
          retCode = 1 # we are name mapped
        else
          retCode = 0
        end # we are NOT name mapped
      else
        Builtins.y2milestone(
          "Edirectory.IsParentDomainMapped:get-domain-type returned error:%1",
          exit
        )
        retCode = -1 # script error - fall back to old behavior
      end

      Builtins.y2milestone(
        "Edirectory.IsParentDomainMapped:returned:%1",
        retCode
      )
      retCode
    end

    # Make sure there is not already a forest in the tree we are installing.
    #
    #
    def CheckForExistingForest(domain, ipAddress)
      tree = Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_TREE_NAME", "")
      admin = NovellUtils.Ldap2Nds(
        Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
      )
      admPassword = Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_PASSWORD", "")

      Builtins.y2milestone(
        "Edirectory.CheckForExistingForest:checking ip:%1",
        ipAddress
      )
      cmd = Builtins.sformat(
        "TREE_NAME=%1 /opt/novell/xad/share/dcinit/provisionTools.sh forest-query -d %2 -a '%3' -p %4",
        tree,
        domain,
        admin,
        ipAddress
      )
      Builtins.y2milestone(
        "Edirectory.CheckForExistingForest:executing:%1",
        cmd
      )

      cmd = Builtins.sformat("ADM_PASSWD='%1' %2", admPassword, cmd)
      if @xadTestMode
        Builtins.y2milestone(
          "xad.Edirectory.CheckForExistingForest:executing:%1",
          cmd
        )
      end

      val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      exit = Ops.get_integer(val, "exit", -1)
      Builtins.y2milestone(
        "Edirectory.CheckForExistingForest:return code:%1",
        exit
      )

      exit
    end

    # Make sure netbios name is valid.
    #
    # @return 0 if ok
    def CheckForValidNetbiosName(netbiosName)
      Builtins.y2milestone(
        "Edirectory.CheckForValidNetbiosName:checking name %1",
        netbiosName
      )
      cmd = Builtins.sformat(
        "/opt/novell/xad/share/dcinit/provisionTools.sh netbios-valid-query -n %1",
        netbiosName
      )

      Builtins.y2milestone(
        "Edirectory.CheckForValidNetbiosName:executing:%1",
        cmd
      )

      val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      exit = Ops.get_integer(val, "exit", -1)
      Builtins.y2milestone(
        "Edirectory.CheckForValidNetbiosName:return code:%1",
        exit
      )

      exit = 0 if @xadTestMode

      exit
    end

    # Make sure there is not a duplicate netbios name.
    #
    # @return 0 if partitioned
    def CheckForExistingNetbiosName(ipAddress, netbiosName)
      Builtins.y2milestone(
        "Edirectory.CheckForExistingNetbiosName:checking ip:%1 for name %2",
        ipAddress,
        netbiosName
      )
      cmd = Builtins.sformat(
        "/opt/novell/xad/share/dcinit/provisionTools.sh netbios-query -p %1 -n %2",
        ipAddress,
        netbiosName
      )

      Builtins.y2milestone(
        "Edirectory.CheckForExistingNetbiosName:executing:%1",
        cmd
      )

      val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      exit = Ops.get_integer(val, "exit", -1)
      Builtins.y2milestone(
        "Edirectory.CheckForExistingNetbiosName:return code:%1",
        exit
      )

      exit
    end

    # Make sure there is not a duplicate netbios name in the subnet.
    #
    # @return 0 if partitioned
    def CheckForExistingNetbiosNameInSubnet(netbiosName)
      Builtins.y2milestone(
        "Edirectory.CheckForExistingNetbiosNameInSubnet:checking for netbios name %1",
        netbiosName
      )
      cmd = Builtins.sformat(
        "/opt/novell/xad/share/dcinit/provisionTools.sh netbios-query-in-subnet -n %1",
        netbiosName
      )

      Builtins.y2milestone(
        "Edirectory.CheckForExistingNetbiosNameInSubnet:executing:%1",
        cmd
      )

      val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      exit = Ops.get_integer(val, "exit", -1)
      Builtins.y2milestone(
        "Edirectory.CheckForExistingNetbiosNameInSubnet:return code:%1",
        exit
      )

      exit
    end

    # Make sure a container is partitioned for Domain Services for Windows.
    #
    # @return 0 if partitioned
    def CheckContainerPartitioning(container)
      treeName = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_TREE_NAME",
        ""
      )
      admin = NovellUtils.Ldap2Nds(
        Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
      )
      admPassword = Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_PASSWORD", "")
      ipAddress = Ops.get_string(
        @EdirSettings,
        "CONFIG_EDIR_REPLICA_SERVER",
        ""
      )
      domainName = Ops.get_string(@EdirSettings, "XAD_DOMAIN_NAME", "")

      cmd = Builtins.sformat(
        "TREE_NAME=%1 /opt/novell/xad/share/dcinit/provisionTools.sh partition-query -d '%2' -a '%3' -p %4 -c '%5'",
        treeName,
        domainName,
        admin,
        ipAddress,
        container
      )

      Builtins.y2milestone(
        "Edirectory.CheckContainerPartitioning:executing:%1",
        cmd
      )

      cmd = Ops.add(Ops.add(Ops.add("ADM_PASSWD='", admPassword), "' "), cmd)
      if @xadTestMode
        Builtins.y2milestone(
          "Edirectory.CheckContainerPartitioning:executing:%1",
          cmd
        )
      end

      val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      exit = Ops.get_integer(val, "exit", -1)
      Builtins.y2milestone(
        "Edirectory.CheckContainerPartitioning:return code:%1",
        exit
      )

      exit
    end

    # Make sure Domain Services for Windows is at the correct patch level for install
    #
    # @return .
    def DoXadVersionCheck(serverIP)
      Builtins.y2milestone(
        "Edirectory.DoXadVersionCheck:entering method with IP: %1",
        serverIP
      )
      cmd = "/opt/novell/xad/share/dcinit/ndsSchVersionCheck.sh"
      treeName = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_TREE_NAME",
        ""
      )

      cmd = Ops.add(
        Ops.add(Ops.add(Ops.add(cmd, " "), serverIP), " "),
        treeName
      )
      Builtins.y2milestone("Edirectory.DoXadVersionCheck:executing:%1", cmd)
      val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      exit = Ops.get_integer(val, "exit", -1)

      Builtins.y2milestone("Edirectory.DoXadVersionCheck:return code:%1", exit)

      exit
    end

    # Get the correct server context based on the XAD config type
    #
    # @return [String] containing fully qualified server context.
    def GetXadServerContext(domainType, domainName, adminName, adminPassword)
      if @xadTestMode
        Builtins.y2milestone(
          "Edir.GetXadServerContext:domain type %1, domain name %2, admin name %3, adminPassword %4",
          domainType,
          domainName,
          adminName,
          adminPassword
        )
        return "ou=OESSystemObjects.o=fakeGetXadServerContext"
      end

      ret = ""

      remote_server = NovellLDAP.GetAddressServer(
        Ops.get_string(@EdirSettings, "CONFIG_EDIR_REPLICA_SERVER", ""),
        nil
      )
      existingServerIP = Ops.get_string(
        remote_server,
        "CONFIG_LDAP_SERVER_IP",
        ""
      )
      remoteSecurePort = Ops.get_integer(
        remote_server,
        "CONFIG_LDAP_SECURE_PORT",
        636
      )

      existingServerIP = Builtins.sformat(
        "%1:%2",
        existingServerIP,
        remoteSecurePort
      )

      if adminPassword == nil || adminPassword == ""
        Builtins.y2milestone(
          "Edirectory.GetXadServerContext:EdirSettings[XAD_LDAP_ADMIN_PASSWORD] was empty. Falling back to ldap password."
        )
        adminPassword = Ops.get_string(
          NovellLDAP.Settings,
          "CONFIG_LDAP_ADMIN_PASSWORD",
          ""
        )
        if adminPassword == nil || adminPassword == ""
          Builtins.y2milestone(
            "Edirectory.GetXadServerContext:LDAP admin password was empty."
          )
        end
      end

      cmd = "/opt/novell/xad/share/dcinit/ndsConfigServerContext.sh"

      # Check the domain type to see how to build this command
      cmd = Ops.add(cmd, " --add-dc") if domainType == "controller"

      treeName = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_TREE_NAME",
        ""
      )
      treeVar = Ops.add(Ops.add("TREE_NAME='", treeName), "'")
      cmd = Ops.add(
        Ops.add(
          Ops.add(
            Ops.add(Ops.add(Ops.add(cmd, " '"), domainName), "' '"),
            adminName
          ),
          "' "
        ),
        existingServerIP
      )
      cmd = Ops.add(Ops.add(treeVar, " "), cmd)
      Builtins.y2milestone("Edirectory.GetXadServerContext:executing:%1", cmd)
      if @xadTestMode
        Builtins.y2milestone(
          "xad:GetXadServerContext:executing:%1",
          Builtins.sformat("ADM_PASSWD='%1' %2", adminPassword, cmd)
        )
      end
      val = Convert.to_map(
        SCR.Execute(
          path(".target.bash_output"),
          Builtins.sformat("ADM_PASSWD='%1' %2", adminPassword, cmd)
        )
      )
      exit = Ops.get_integer(val, "exit", -1)
      if exit == 0
        ret = Ops.get_string(val, "stdout", "")
        # remove the line feed from the stdout string
        ret = NovellUtils.StripTrailing(ret, "\n ")
      else
        if exit == 1
          Builtins.y2milestone(
            "Edirectory.GetXadServerContext:Server is not reachable using the given ip address:%1",
            existingServerIP
          )
        elsif exit == 2
          Builtins.y2milestone(
            "Edirectory.GetXadServerContext:Missing parameter."
          )
        else
          Builtins.y2milestone(
            "Edirectory.GetXadServerContext:Unknown error:%1",
            exit
          )
        end
      end

      Builtins.y2milestone(
        "Edirectory.GetXadServerContext:returning server context:%1",
        ret
      )
      ret
    end


    # Proposes the eDirectory server context and Admin name
    # based on the specified domain name
    #
    # @return [Hash] of proposed settings
    def ProposeXadContextSettings(domain_type, domain_name, forest_root)
      ret = {}

      domain_type = "forest" if domain_type == nil || domain_type == ""

      # server context should be based on DNS domain name
      split = Builtins.splitstring(Builtins.tolower(domain_name), ".")
      server_context = Ops.add(
        Ops.add(@oesContext, ".dc="),
        Builtins.mergestring(split, ".dc=")
      ) # add the dc= elements
      admin_context = Ops.add("dc=", Builtins.mergestring(split, ".dc=")) # add the dc= elements
      Ops.set(ret, "CONFIG_EDIR_SERVER_CONTEXT", server_context)

      # Check for name mapping
      if Ops.get_string(@EdirSettings, "XAD_CONVERT_EXISTING_CONTAINER", "no") == "yes"
        Ops.set(
          ret,
          "CONFIG_EDIR_SERVER_CONTEXT",
          Ops.add(
            Ops.add(@oesContext, "."),
            Ops.get_string(@EdirSettings, "XAD_EXISTING_CONTAINER", "")
          )
        )
      end

      Ops.set(
        ret,
        "CONFIG_LDAP_ADMIN_CONTEXT",
        Ops.add("cn=Administrator.cn=Users.", admin_context)
      )

      # admin context should use the xad provisioning user...
      if Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") != "existing"
        Ops.set(
          ret,
          "XAD_LDAP_ADMIN_CONTEXT",
          Builtins.sformat("cn=xad_provisioning_user.%1", admin_context)
        )
      elsif domain_type == "controller"
        # existing eDirectory tree
        split = Builtins.splitstring(forest_root, ".")
        Ops.set(
          ret,
          "XAD_LDAP_ADMIN_CONTEXT",
          Ops.add(
            "cn=Administrator.cn=Users.dc=",
            Builtins.mergestring(split, ".dc=")
          )
        ) # add the dc= elements
      else
        Ops.set(ret, "XAD_LDAP_ADMIN_CONTEXT", "") # cannot default this value, must be user specified
      end

      Builtins.y2milestone(
        "Edirectory::ProposeXadContextSettings(%1, %2, %3) returned: %4",
        domain_type,
        domain_name,
        forest_root,
        ret
      )

      deep_copy(ret)
    end


    # Proposes the Domain Services for Windows (XAD) settings
    # based on currently entered parameters
    #
    # @return [Hash] of proposed XAD settings
    def ProposeXadSettings
      ret = {}

      Ops.set(
        ret,
        "XAD_SERVICE_CONFIGURED",
        Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "")
      )
      if Ops.get_string(ret, "XAD_SERVICE_CONFIGURED", "") == nil ||
          Ops.get_string(ret, "XAD_SERVICE_CONFIGURED", "") == ""
        if @xad_packages_installed
          Ops.set(ret, "XAD_SERVICE_CONFIGURED", "yes")
        else
          Ops.set(ret, "XAD_SERVICE_CONFIGURED", "no")
        end
      end

      Ops.set(
        ret,
        "XAD_DOMAIN_TYPE",
        Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "forest")
      )

      Ops.set(
        ret,
        "XAD_DOMAIN_NAME",
        Ops.get_string(@EdirSettings, "XAD_DOMAIN_NAME", "")
      )
      if Ops.get_string(ret, "XAD_DOMAIN_NAME", "") == nil ||
          Ops.get_string(ret, "XAD_DOMAIN_NAME", "") == ""
        splitFQ = Hostname.SplitFQ(NovellUtils.GetDNSname)
        Ops.set(
          ret,
          "XAD_DOMAIN_NAME",
          Builtins.tolower(Ops.get(splitFQ, 1, ""))
        )
      end

      Ops.set(
        ret,
        "XAD_CONFIG_DNS",
        Ops.get_string(@EdirSettings, "XAD_CONFIG_DNS", "no")
      )
      Ops.set(
        ret,
        "XAD_WINS_SERVER",
        Ops.get_string(@EdirSettings, "XAD_WINS_SERVER", "")
      )
      Ops.set(
        ret,
        "XAD_SITE_NAME",
        Ops.get_string(@EdirSettings, "XAD_SITE_NAME", "")
      )
      if Ops.get_string(ret, "XAD_SITE_NAME", "") == nil ||
          Ops.get_string(ret, "XAD_SITE_NAME", "") == ""
        Ops.set(ret, "XAD_SITE_NAME", "Default-First-Subnet-Name")
      end

      Ops.set(
        ret,
        "XAD_NETBIOS",
        Ops.get_string(@EdirSettings, "XAD_NETBIOS", "")
      )
      if Ops.get_string(ret, "XAD_NETBIOS", "") == nil ||
          Ops.get_string(ret, "XAD_NETBIOS", "") == ""
        splitFQ = Hostname.SplitFQ(
          Ops.get_string(@EdirSettings, "XAD_DOMAIN_NAME", "")
        )
        Ops.set(ret, "XAD_NETBIOS", Builtins.toupper(Ops.get(splitFQ, 0, "")))
      end

      Ops.set(
        ret,
        "XAD_FOREST_ROOT",
        Ops.get_string(@EdirSettings, "XAD_FOREST_ROOT", "")
      )
      Builtins.y2milestone(
        "Edirectory.ProposeXadSettings:XAD_FOREST_ROOT:%1",
        Ops.get_string(ret, "XAD_FOREST_ROOT", "")
      )
      if Ops.get_string(ret, "XAD_FOREST_ROOT", "") == nil ||
          Ops.get_string(ret, "XAD_FOREST_ROOT", "") == ""
        if Ops.get_string(ret, "XAD_DOMAIN_TYPE", "") == "domain" ||
            Ops.get_string(ret, "XAD_DOMAIN_TYPE", "") == "controller"
          splitFQ = Hostname.SplitFQ(
            Ops.get_string(@EdirSettings, "XAD_DOMAIN_NAME", "")
          )
          Ops.set(
            ret,
            "XAD_FOREST_ROOT",
            Builtins.tolower(Ops.get(splitFQ, 1, ""))
          )
          Builtins.y2milestone(
            "Edirectory.ProposeXadSettings:XAD_FOREST_ROOT (2):%1",
            Ops.get_string(ret, "XAD_FOREST_ROOT", "")
          )
        else
          Ops.set(
            ret,
            "XAD_FOREST_ROOT",
            Ops.get_string(ret, "XAD_DOMAIN_NAME", "")
          )
        end
      end

      if @xad_packages_installed &&
          Ops.get_string(ret, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        # propose the Edirectory defaults....
        ret = Builtins.union(
          ret,
          ProposeXadContextSettings(
            Ops.get_string(ret, "XAD_DOMAIN_TYPE", ""),
            Ops.get_string(ret, "XAD_DOMAIN_NAME", ""),
            Ops.get_string(ret, "XAD_FOREST_ROOT", "")
          )
        )
      end

      Builtins.y2milestone("Edirectory::ProposeXadSettings() returned: %1", ret)
      deep_copy(ret)
    end

    def GetOES10dibLocation
      # If you can't find the dib then prompt and ask.

      dibPath = "/var/nds/dib"
      data_file = "/etc/nds.conf"
      stmp = []

      # First see if the file exists.
      if SCR.Read(path(".target.size"), data_file) == -1
        Builtins.y2milestone(
          "Edirectory.GetOES10dibLocation:/etc/nds.conf file not found. Returning dib path: %1",
          dibPath
        )
        return dibPath
      end

      # Read the file into memory
      ndsData = Convert.to_string(SCR.Read(path(".target.string"), data_file))
      if ndsData != nil && ndsData != ""
        # break up into individual lines
        stmp = Builtins.splitstring(ndsData, "\n")
      else
        Builtins.y2milestone(
          "Edirectory.GetOES10dibLocation:could not read /etc/nds.conf. Returning dib path: %1",
          dibPath
        )
        return dibPath
      end

      Builtins.foreach(stmp) do |line|
        # First split the name from the value
        name_value = Builtins.splitstring(line, "=")
        next if name_value == nil
        if Ops.get(name_value, 0, "") == "n4u.nds.dibdir"
          dibPath = Ops.get(name_value, 1, "")
          Builtins.y2milestone(
            "Edirectory.GetOES10dibLocation:dib path found: %1",
            dibPath
          )
          raise Break
        end
      end if stmp != nil

      Builtins.y2milestone(
        "Edirectory.GetOES10dibLocation:returning dib path: %1",
        dibPath
      )
      dibPath
    end


    # Verifies if a known DIB exists
    #
    # @return [Boolean] true if a DIB exists
    def DoesDIBExist
      # Does the edirectory DIB exist??
      dibFound = false

      # Establish the default location
      dibloc = @dibLocation

      # We look for the dib in the old location if we are upgrading.
      if !Mode.update && !Mode.autoupgrade
        # The output has a \n which we remove here
        cmd = Ops.add(
          Ops.add(@ndsconfig_bin, " get n4u.nds.dibdir"),
          " |  tr -d \"\\n\""
        )
        Builtins.y2milestone("eDirectory.DoesDIBExist:executing:%1", cmd)
        ret = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))

        # the exit status code from this command is meaningless
        out = Builtins.splitstring(Ops.get_string(ret, "stdout", ""), "=")
        if Ops.greater_than(Builtins.size(out), 1)
          dibloc = Ops.get(out, Ops.subtract(Builtins.size(out), 1), "")
          Builtins.y2milestone(
            "eDirectory.DoesDIBExist:ndsconfig reports the dib located at %1",
            dibloc
          )
          @dibLocation = dibloc
        end # we are in upgrade mode.
      else
        dibloc = Ops.get_string(
          @old_EdirSettings,
          "CONFIG_EDIR_DIB_LOCATION",
          ""
        )
        dibloc = "" if dibloc == nil
        Builtins.y2milestone(
          "eDirectory.DoesDIBExist:old config file reports dib located at %1",
          dibloc
        )

        dibloc = GetOES10dibLocation() if dibloc == ""

        @dibLocation = dibloc if dibloc != ""
      end
      dibSize = Convert.to_integer(
        SCR.Read(path(".target.size"), Ops.add(dibloc, "/nds.01"))
      )
      Builtins.y2milestone(
        "eDirectory.DoesDIBExist:eDirectory DIB at %2 has size %1",
        dibSize,
        dibloc
      )
      if dibSize != nil && Ops.greater_or_equal(dibSize, 0)
        dibFound = true
      else
        dibFound = false
      end

      dibFound
    end


    # GetTreeName
    #
    # Uses 'oes-install/util/get_tree_name' to fetch the name of the tree at the given IP address
    #
    # @param [String] ip string IP address of eDirectory server
    # @param [Fixnum] nport eDirectory NCP port
    # @return [String] tree name
    def GetTreeName(ip, nport)
      libPath = "/opt/novell/eDirectory/lib64"
      tmp = Builtins.sformat("/util/get_tree_name %1 %2", ip, nport)
      cmd = Ops.add(@oesinstall_dir, tmp)

      ret = {}
      if Arch.x86_64
        ret = Convert.to_map(
          SCR.Execute(
            path(".target.bash_output"),
            cmd,
            { "LD_LIBRARY_PATH" => libPath }
          )
        )
        Builtins.y2milestone(
          "edirectory.GetTreeName.executing:%1 with LD_LIBRARY_PATH: %2. Returned: %3",
          cmd,
          libPath,
          ret
        )
      else
        ret = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
        Builtins.y2milestone(
          "edirectory:GetTreeName.executing %1. Returned %2",
          cmd,
          ret
        )
      end
      exit = Ops.get_integer(ret, "exit", -1)
      if exit == 0
        treeName = Ops.get_string(ret, "stdout", "")
        return treeName
      else
        return ""
      end
    end


    # Check if tree exists
    #
    # @param [String] treeName eDirectory tree name
    # @return [Boolean] true if the tree name exists
    def DoesEdirectoryTreeExist(treeName)
      bin = Ops.add(@oesinstall_dir, "/util/does_tree_exist")

      Popup.ShowFeedback(
        _("Searching for eDirectory trees"),
        _("This may take a while")
      )
      ret = Convert.to_map(
        SCR.Execute(
          path(".target.bash_output"),
          Builtins.sformat("%1 --list '%2'", bin, treeName)
        )
      )
      Popup.ClearFeedback

      exit = Ops.get_integer(ret, "exit", -1)
      stdout = Ops.get_string(ret, "stdout", "")

      exit == 0
    end

    def CheckEdirUp(admin, pwd, ip, sport)
      edir_cmd = "ps -u 0 -o 'pid comm' | grep ndsd >> /dev/null"
      rc = Convert.to_integer(SCR.Execute(path(".target.bash"), edir_cmd))
      Service.Start("ndsd") if rc != 0

      edir_up = 1
      try_count = 1
      while edir_up != 0
        Builtins.sleep(15000) #sleep 15 seconds
        val = NovellValidators.ValidateCredentials(admin, pwd, ip, sport, false)
        if val != 0
          Builtins.y2debug("eDirectory did not respond... waiting...")
        else
          edir_up = 0
        end
        try_count = Ops.add(try_count, 1)
        break if Ops.greater_than(try_count, 4)
      end
      edir_up
    end

    # Make attempts every 15 seconds for 5 minutes to see if LDAP will bind
    # using the username/context, and password to the IP address spoecified
    # this is used as an indication that eDirectory is up and running
    #
    # @param [Fixnum] sport  secure ldap port
    # @param [String] admin admin fdn
    # @param [String] pwd admin password
    # @param [String] ip IP address of eDirectory LDAP server
    # @return [Fixnum] 0 on success
    def WaitForLDAPtoBind(sport, admin, pwd, ip)
      edir_up = -1
      if @xadTestMode == false
        Builtins.y2milestone(
          "Edirectory.WaitForLDAPtoBind:sport:%1, admin:%2, ip %3",
          sport,
          admin,
          ip
        )
        edir_up = CheckEdirUp(admin, pwd, ip, sport) # makes 4 attempts for a minute
      else
        Builtins.y2milestone(
          "xad:WaitForLDAPtoBind:sport:%1, admin:%2, pass:%3, ip %4",
          sport,
          admin,
          "****",
          ip
        )
        edir_up = 0
      end

      edir_up
    end

    # eDirRetryCleanup()
    #
    # We've failed one or more times - what do we clean up for a new trial?
    #
    # @return [Boolean] true on success
    def eDirRetryCleanup
      Builtins.y2milestone(
        "Edirectory::eDirRetryCleanup() - Cleaning up previous eDirectory attempt..."
      )
      removalSuccessful = false

      # Stop the daemon
      stopped = Service.Stop("ndsd")
      if !stopped
        # Now get a little more violent
        cmd2 = "killall -9 ndsd"
        Builtins.y2milestone("Executing: %1", cmd2)
        d = Convert.to_integer(SCR.Execute(path(".target.bash"), cmd2))
        if d != 0
          Builtins.y2error(
            "Edirectory:eDirRetryCleanup:killall -9 ndsd did not work"
          ) 
          # We will not return false here, since the daemon may not have been running at all.
        end
      end

      adminName = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_CONTEXT",
        ""
      )
      if Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        adminName = Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
      end

      # Do we know the admin context and password?
      # Sometimes yes at this point and sometime no!
      if Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_PASSWORD", "") != nil &&
          Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_PASSWORD", "") != "" &&
          adminName != nil &&
          adminName != ""
        # Try and Use NDSConfig to clean up existing server objects
        # in the directory
        # Remove the DIB - using ndsconfig rm - This requires knowing the
        # adminName and Password!!!!!
        adminName = NovellUtils.Ldap2Nds(adminName)
        adminPassword = Ops.get_string(
          NovellLDAP.Settings,
          "CONFIG_LDAP_ADMIN_PASSWORD",
          ""
        )
        cmd2 = Builtins.sformat("%1 rm -c -a '%2'", @ndsconfig_bin, adminName)
        Builtins.y2milestone("Executing: %1", cmd2)
        d = Convert.to_integer(
          SCR.Execute(
            path(".target.bash"),
            Builtins.sformat("ADM_PASSWD='%1' %2", adminPassword, cmd2)
          )
        )
        if d == 0
          removalSuccessful = true
          @dibExists = false
        else
          Builtins.y2error("Command failed: %1", cmd2)
        end
      end

      # If ndsconfig does not succeed, use a more forceful approach
      if !removalSuccessful
        #Leave directories and the _ndsdb.ini file
        cmd2 = Ops.add(Ops.add("rm -rf ", @dibLocation), "/nds.*")
        Builtins.y2milestone("Executing: %1", cmd2)
        d = Convert.to_integer(SCR.Execute(path(".target.bash"), cmd2))
        if d == 0
          @dibExists = false
          removalSuccessful = true
        else
          Builtins.y2error("Command failed: %1", cmd2)
          Report.Error(
            Builtins.sformat(
              _(
                "Unable to remove the Directory Information Base (DIB)\nRemove the DIB %1 manually and try again"
              ),
              @dibLocation
            )
          )
        end
      end

      # Remove the default conf file entry from "/etc/opt/novell/eDirectory/conf/.edir/instances.0" file.
      data_file = "/etc/opt/novell/eDirectory/conf/.edir/instances.0"

      cmd = "rm -f /etc/opt/novell/eDirectory/conf/.edir/instances.0"
      Builtins.y2milestone("Edirectory::eDirRetryCleanup():executing: %1", cmd)
      val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      Builtins.y2milestone("Edirectory::eDirRetryCleanup():ret %1", val)

      cmd = "touch /etc/opt/novell/eDirectory/conf/.edir/instances.0"
      Builtins.y2milestone("Edirectory::eDirRetryCleanup():executing: %1", cmd)
      val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      Builtins.y2milestone("Edirectory::eDirRetryCleanup():ret %1", val)

      Builtins.y2milestone(
        "Edirectory::eDirRetryCleanup() returned: %1",
        removalSuccessful
      )
      removalSuccessful
    end


    # Check to see if all known eDirectory dependencies have been installed
    #
    # @return [Boolean]
    def EdirDependenciesOK
      # verify the eDirectory pattern is installed...
      return true if @xadTestMode == true || @upgradeTestMode == true

      return false if @auto_clone

      if !NovellPatterns.EnsurePatternInstalled("novell-edirectory")
        return false
      end

      true
    end


    # ValidateNMASData ()
    #
    # Makes sure NMAS data is "yes" or "no" (ignore case)
    #
    def ValidateNMASData(val)
      return false if val == nil || val == ""

      val = NovellUtils.Strip(val, " ")
      val = Builtins.tolower(val)

      return true if val == "yes" || val == "no"

      false
    end


    def ValidateXadSettings
      ret = true

      if Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        ret = ret &&
          (Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "forest") == "forest" ||
            Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "forest") == "domain" ||
            Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "forest") == "controller")

        ret = ret &&
          Ops.get_string(@EdirSettings, "XAD_DOMAIN_NAME", "") != nil &&
            Ops.get_string(@EdirSettings, "XAD_DOMAIN_NAME", "") != ""

        ret = ret &&
          Ops.get_string(@EdirSettings, "XAD_NETBIOS", "") != nil &&
            Ops.get_string(@EdirSettings, "XAD_NETBIOS", "") != ""

        if Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "forest") == "domain" ||
            Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "forest") == "controller"
          ret = ret &&
            Ops.get_string(@EdirSettings, "XAD_FOREST_ROOT", "") != nil &&
              Ops.get_string(@EdirSettings, "XAD_FOREST_ROOT", "") != ""
        end
      end

      Builtins.y2milestone("Edirectory::ValidateXadSettings returned: %1", ret)
      ret
    end

    # ReadXadSettings ()
    #
    # Reads "Domain Services for Windows" (XAD) settings from the file /etc/sysconfig/novell/edirectory
    #
    def ReadXadSettings
      data = {}

      # Configure eDirectory with Domain Services for Windows?
      val = Builtins.tolower(
        Convert.to_string(
          SCR.Read(path(".sysconfig.novell.xad.SERVICE_CONFIGURED"))
        )
      )
      val = "no" if val != "yes"
      #	if (xad_packages_installed) {
      #		val = "yes";
      #	}
      Builtins.y2milestone(
        "edir.ReadXadSettings:setting xad_service_configured to %1",
        val
      )
      Ops.set(data, "XAD_SERVICE_CONFIGURED", val)

      if Ops.get_string(data, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        # Domain type ( forest, domain, or controller )
        val = Convert.to_string(
          SCR.Read(path(".sysconfig.novell.xad.XAD_DOMAIN_TYPE"))
        )
        val = "forest" if val != "domain" && val != "controller"
        Ops.set(data, "XAD_DOMAIN_TYPE", val)

        # DNS name for new domain
        val = Convert.to_string(
          SCR.Read(path(".sysconfig.novell.xad.XAD_DOMAIN_NAME"))
        )
        val = "" if val == nil # avoid nil value
        Ops.set(data, "XAD_DOMAIN_NAME", Builtins.tolower(val))

        # Configure this machine to be a primary DNS server?
        val = Builtins.tolower(
          Convert.to_string(
            SCR.Read(path(".sysconfig.novell.xad.XAD_CONFIG_DNS"))
          )
        )
        val = "no" if val != "yes"
        Ops.set(data, "XAD_CONFIG_DNS", Builtins.tolower(val)) # DNS names look better in lower case

        # Configure this machine with WINS Server?
        val = Builtins.tolower(
          Convert.to_string(
            SCR.Read(path(".sysconfig.novell.xad.XAD_WINS_SERVER"))
          )
        )
        val = "no" if val != "yes"
        Ops.set(data, "XAD_WINS_SERVER", Builtins.tolower(val))

        # Sites and Subnets
        val = Builtins.tolower(
          Convert.to_string(
            SCR.Read(path(".sysconfig.novell.xad.XAD_SITE_NAME"))
          )
        )
        val = "" if val == nil
        Ops.set(data, "XAD_SITE_NAME", val)

        # Domain NetBIOS name
        val = Convert.to_string(
          SCR.Read(path(".sysconfig.novell.xad.XAD_NETBIOS"))
        )
        val = "" if val == nil
        Ops.set(data, "XAD_NETBIOS", Builtins.toupper(val)) # NetBIOS should be uppercase

        # Forest root domain
        val = Convert.to_string(
          SCR.Read(path(".sysconfig.novell.xad.XAD_FOREST_ROOT"))
        )
        val = "" if val == nil
        Ops.set(data, "XAD_FOREST_ROOT", Builtins.tolower(val)) # DNS names look better in lower case

        # Parent Domain Admin Context
        val = Convert.to_string(
          SCR.Read(path(".sysconfig.novell.xad.XAD_PARENT_DOMAIN_ADMIN_CONTEXT"))
        )
        val = "" if val == nil # avoid nil value
        Ops.set(data, "XAD_PARENT_DOMAIN_ADMIN_CONTEXT", val)

        # Parent domain
        val = Convert.to_string(
          SCR.Read(path(".sysconfig.novell.xad.XAD_PARENT_DOMAIN"))
        )
        val = Ops.get_string(data, "XAD_FOREST_ROOT", "") if val == nil
        Ops.set(data, "XAD_PARENT_DOMAIN", Builtins.tolower(val)) # DNS names look better in lower case

        # Convert existing eDirectory container/partition to an XAD domain?
        val = Builtins.tolower(
          Convert.to_string(
            SCR.Read(
              path(".sysconfig.novell.xad.XAD_CONVERT_EXISTING_CONTAINER")
            )
          )
        )
        val = "no" if val != "yes"
        Ops.set(data, "XAD_CONVERT_EXISTING_CONTAINER", Builtins.tolower(val))

        # eDirectory container/partition to convert to an XAD domain (name-mapping)
        val = Convert.to_string(
          SCR.Read(path(".sysconfig.novell.xad.XAD_EXISTING_CONTAINER"))
        )
        val = "" if val == nil # avoid nil value
        Ops.set(data, "XAD_EXISTING_CONTAINER", Builtins.tolower(val))

        # replicate partion information for additional domain controllers
        val = Convert.to_string(
          SCR.Read(path(".sysconfig.novell.xad.XAD_REPLICATE_PARTITIONS"))
        )
        val = "no" if val == nil # avoid nil value
        Ops.set(data, "XAD_REPLICATE_PARTITIONS", Builtins.tolower(val))

        # retain existing novell password policies on users
        val = Convert.to_string(
          SCR.Read(path(".sysconfig.novell.xad.XAD_RETAIN_POLICIES"))
        )
        val = "no" if val == nil # avoid nil value
        Ops.set(data, "XAD_RETAIN_POLICIES", Builtins.tolower(val))

        #Reading DNS setting

        val = Convert.to_string(
          SCR.Read(path(".sysconfig.novell-dns.CONFIG_DNS_DOMAIN_NAME"))
        )
        val = "" if val == nil # avoid nil value
        Ops.set(data, "CONFIG_DNS_DOMAIN_NAME", val)

        val = Convert.to_string(
          SCR.Read(path(".sysconfig.novell-dns.CONFIG_DNS_GROUP_CONTEXT"))
        )
        val = "" if val == nil # avoid nil value
        Ops.set(data, "CONFIG_DNS_GROUP_CONTEXT", val)

        val = Convert.to_string(
          SCR.Read(path(".sysconfig.novell-dns.CONFIG_DNS_HOST_NAME"))
        )
        val = "" if val == nil # avoid nil value
        Ops.set(data, "CONFIG_DNS_HOST_NAME", val)

        val = Convert.to_string(
          SCR.Read(path(".sysconfig.novell-dns.CONFIG_DNS_LDAP_BASEDN"))
        )
        val = "" if val == nil # avoid nil value
        Ops.set(data, "CONFIG_DNS_LDAP_BASEDN", val)

        val = Convert.to_string(
          SCR.Read(path(".sysconfig.novell-dns.CONFIG_DNS_LDAP_SERVER"))
        )
        val = "" if val == nil # avoid nil value
        Ops.set(data, "CONFIG_DNS_LDAP_SERVER", val)

        val = Convert.to_string(
          SCR.Read(path(".sysconfig.novell-dns.CONFIG_DNS_LOCATOR_CONTEXT"))
        )
        val = "" if val == nil # avoid nil value
        Ops.set(data, "CONFIG_DNS_LOCATOR_CONTEXT", val)

        val = Convert.to_string(
          SCR.Read(path(".sysconfig.novell-dns.CONFIG_DNS_LDAP_USER_CONTEXT"))
        )
        val = "" if val == nil # avoid nil value
        Ops.set(data, "CONFIG_DNS_LDAP_USER_CONTEXT", val)

        val = Convert.to_string(
          SCR.Read(path(".sysconfig.novell-dns.CONFIG_DNS_SERVER_CONTEXT"))
        )
        val = "" if val == nil # avoid nil value
        Ops.set(data, "CONFIG_DNS_SERVER_CONTEXT", val)

        Ops.set(
          @DnsSettings,
          "CONFIG_DNS_DOMAIN_NAME",
          Ops.get_string(data, "CONFIG_DNS_DOMAIN_NAME", "")
        )
        Ops.set(
          @DnsSettings,
          "CONFIG_DNS_GROUP_CONTEXT",
          Ops.get_string(data, "CONFIG_DNS_GROUP_CONTEXT", "")
        )
        Ops.set(
          @DnsSettings,
          "CONFIG_DNS_HOST_NAME",
          Ops.get_string(data, "CONFIG_DNS_HOST_NAME", "")
        )
        Ops.set(
          @DnsSettings,
          "CONFIG_DNS_LDAP_BASEDN",
          Ops.get_string(data, "CONFIG_DNS_LDAP_BASEDN", "")
        )
        Ops.set(
          @DnsSettings,
          "CONFIG_DNS_LDAP_SERVER",
          Ops.get_string(data, "CONFIG_DNS_LDAP_SERVER", "")
        )
        Ops.set(
          @DnsSettings,
          "CONFIG_DNS_LOCATOR_CONTEXT",
          Ops.get_string(data, "CONFIG_DNS_LOCATOR_CONTEXT", "")
        )
        Ops.set(
          @DnsSettings,
          "CONFIG_DNS_LDAP_USER_CONTEXT",
          Ops.get_string(data, "CONFIG_DNS_LDAP_USER_CONTEXT", "")
        )
        Ops.set(
          @DnsSettings,
          "CONFIG_DNS_SERVER_CONTEXT",
          Ops.get_string(data, "CONFIG_DNS_SERVER_CONTEXT", "")
        )
      end

      deep_copy(data)
    end


    # ReadEdirSettings ()
    #
    # Reads settings from the file /etc/sysconfig/novell/edir
    #
    def ReadEdirSettings
      data = {}

      if Mode.update || Mode.autoupgrade
        Builtins.y2milestone(
          "eDirectory:ReadEdirSettings:Reading eDir data from old %1 file ",
          @upgrade_from
        )

        # Tree Type
        val = Ops.get_string(@old_EdirSettings, "CONFIG_EDIR_TREE_TYPE", "")
        val = "" if val == nil # make sure val is not nil
        Ops.set(data, "CONFIG_EDIR_TREE_TYPE", val)
        Builtins.y2milestone("Edirectory:ReadEdirSettings:Tree type:%1", val)

        if Ops.get_string(data, "CONFIG_EDIR_TREE_TYPE", "") == "existing"
          # Replica address if tree type is existing
          val2 = Ops.get_string(
            @old_EdirSettings,
            "CONFIG_EDIR_REPLICA_SERVER",
            ""
          )
          val2 = "" if val2 == nil # make sure val is not nil
          Ops.set(data, "CONFIG_EDIR_REPLICA_SERVER", val2)
          Builtins.y2milestone(
            "Edirectory:ReadEdirSettings:Replica address:%1",
            val2
          )
        end
        if Mode.update || Mode.autoupgrade

          if @xad_packages_installed
            Ops.set(
              data,
              "XAD_DOMAIN_TYPE",
              Ops.get_string(@old_XadSettings, "XAD_DOMAIN_TYPE", "")
            )
            Ops.set(
              data,
              "XAD_CONFIG_DNS",
              Ops.get_string(@old_XadSettings, "XAD_CONFIG_DNS", "")
            )
            Ops.set(
              data,
              "XAD_WINS_SERVER",
              Ops.get_string(@old_XadSettings, "XAD_WINS_SERVER", "")
            )
            Ops.set(
              data,
              "XAD_SITE_NAME",
              Ops.get_string(@old_XadSettings, "XAD_SITE_NAME", "")
            )
            Ops.set(
              data,
              "XAD_DOMAIN_NAME",
              Ops.get_string(@old_XadSettings, "XAD_DOMAIN_NAME", "")
            )
            Ops.set(
              data,
              "XAD_FOREST_ROOT",
              Ops.get_string(@old_XadSettings, "XAD_FOREST_ROOT", "")
            )

            if Ops.get_string(data, "CONFIG_EDIR_TREE_TYPE", "") == "existing"
              Ops.set(
                data,
                "XAD_LDAP_ADMIN_CONTEXT",
                Ops.get_string(
                  NovellLDAP.Settings,
                  "XAD_TREE_ADMIN_CONTEXT",
                  ""
                )
              )
            end

            Ops.set(data, "XAD_SERVICE_CONFIGURED", "yes") # always yes on an upgrade.
            Ops.set(
              @DnsSettings,
              "CONFIG_DNS_LOCATOR_CONTEXT",
              Ops.get_string(@old_DnsSettings, "CONFIG_DNS_LOCATOR_CONTEXT", "")
            )
            Ops.set(
              @DnsSettings,
              "CONFIG_DNS_GROUP_CONTEXT",
              Ops.get_string(@old_DnsSettings, "CONFIG_DNS_GROUP_CONTEXT", "")
            )
            Ops.set(
              @DnsSettings,
              "CONFIG_DNS_LDAP_SERVER",
              Ops.get_string(@old_DnsSettings, "CONFIG_DNS_LDAP_SERVER", "")
            )
            Ops.set(
              @DnsSettings,
              "CONFIG_DNS_LDAP_BASEDN",
              Ops.get_string(@old_DnsSettings, "CONFIG_DNS_LDAP_BASEDN", "")
            )
            Ops.set(
              @DnsSettings,
              "CONFIG_DNS_SERVER_CONTEXT",
              Ops.get_string(@old_DnsSettings, "CONFIG_DNS_SERVER_CONTEXT", "")
            )
            Ops.set(
              @DnsSettings,
              "CONFIG_DNS_USE_SECURE_PORT",
              Ops.get_string(@old_DnsSettings, "CONFIG_DNS_USE_SECURE_PORT", "")
            )
            Ops.set(
              @DnsSettings,
              "CONFIG_DNS_CREATE_SERVER_OBJECT",
              Ops.get_string(
                @old_DnsSettings,
                "CONFIG_DNS_CREATE_SERVER_OBJECT",
                "no"
              )
            )
            Ops.set(
              @DnsSettings,
              "CONFIG_DNS_HOST_NAME",
              Ops.get_string(@old_DnsSettings, "CONFIG_DNS_HOST_NAME", "")
            )
            Ops.set(
              @DnsSettings,
              "CONFIG_DNS_DOMAIN_NAME",
              Ops.get_string(@old_DnsSettings, "CONFIG_DNS_DOMAIN_NAME", "")
            )
            Ops.set(
              @DnsSettings,
              "CONFIG_DNS_GET_CONTEXT_FROM_EXISTING",
              Ops.get_string(
                @old_DnsSettings,
                "CONFIG_DNS_GET_CONTEXT_FROM_EXISTING",
                ""
              )
            )
            Ops.set(
              @DnsSettings,
              "CONFIG_DNS_EXISTING_DNS_IP",
              Ops.get_string(@old_DnsSettings, "CONFIG_DNS_EXISTING_DNS_IP", "")
            )
            Ops.set(
              @DnsSettings,
              "CONFIG_DNS_STORE_CREDENTIAL_IN_OCS",
              Ops.get_string(
                @old_DnsSettings,
                "CONFIG_DNS_STORE_CREDENTIAL_IN_OCS",
                "yes"
              )
            )
            Ops.set(
              @DnsSettings,
              "CONFIG_DNS_LDAP_USER_CONTEXT",
              Ops.get_string(
                @old_DnsSettings,
                "CONFIG_DNS_LDAP_USER_CONTEXT",
                ""
              )
            )
          end
        end
    
        # Server Context
        val = Ops.get_string(
          @old_EdirSettings,
          "CONFIG_EDIR_SERVER_CONTEXT",
          ""
        )
        val = "" if val == nil # make sure val is not nil
        Ops.set(data, "CONFIG_EDIR_SERVER_CONTEXT", val)
        Builtins.y2milestone(
          "Edirectory:ReadEdirSettings:Server Context:%1",
          val
        )

        # DIB Location
        val = Ops.get_string(@old_EdirSettings, "CONFIG_EDIR_DIB_LOCATION", "")
        val = "" if val == nil # make sure val is not nil
        Ops.set(data, "CONFIG_EDIR_DIB_LOCATION", val)
        Builtins.y2milestone("Edirectory:ReadEdirSettings:dib location:%1", val)

        # HTTP Ports
        intval = Builtins.tointeger(
          Ops.get_string(@old_EdirSettings, "CONFIG_EDIR_HTTP_PORT", "")
        )
        intval = 8028 if intval == nil || Ops.less_or_equal(intval, 0) # make sure val is not nil
        Ops.set(data, "CONFIG_EDIR_HTTP_PORT", intval)
        Builtins.y2milestone("Edirectory:ReadEdirSettings:HTTP port:%1", intval)
        intval = Builtins.tointeger(
          Ops.get_string(@old_EdirSettings, "CONFIG_EDIR_HTTPS_PORT", "")
        )
        intval = 8030 if intval == nil || Ops.less_or_equal(intval, 0) # make sure val is not nil
        Ops.set(data, "CONFIG_EDIR_HTTPS_PORT", intval)
        Builtins.y2milestone(
          "Edirectory:ReadEdirSettings:HTTPS port:%1",
          intval
        )

        # NTP Server
        val = Ops.get_string(@old_EdirSettings, "CONFIG_EDIR_NTP_SERVERS", "")
        val = "" if val == nil # make sure val is not nil
        val = GetNTPServer(0) if val == ""

        if val == "Local Clock" || val == _("Local Clock")
          Ops.set(data, "CONFIG_EDIR_NTP_SERVERS", []) # local clock is now represented by an []
        else
          timeserver_list = Builtins.splitstring(val, ",")
          Ops.set(data, "CONFIG_EDIR_NTP_SERVERS", timeserver_list)
        end

        if Ops.get_list(data, "CONFIG_EDIR_NTP_SERVERS", []) == []
          Ops.set(data, "CONFIG_EDIR_NTP_USE_LOCAL_CLOCK", "yes")
        else
          Ops.set(data, "CONFIG_EDIR_NTP_USE_LOCAL_CLOCK", "no")
        end
        Builtins.y2milestone(
          "Edirectory:ReadEdirSettings:ntp server:%1, use local clock:%2",
          Ops.get_list(data, "CONFIG_EDIR_NTP_SERVERS", []),
          Ops.get_string(data, "CONFIG_EDIR_NTP_USE_LOCAL_CLOCK", "")
        )

        # SLP Mode
        val = Ops.get_string(@old_EdirSettings, "CONFIG_EDIR_SLP_MODE", "")
        val = "" if val == nil # make sure val is not nil
        val = "multicast" if val == "none"
        Ops.set(data, "CONFIG_EDIR_SLP_MODE", val)

        # SLP DA
        slpDAString = Ops.get_string(
          @old_EdirSettings,
          "CONFIG_EDIR_SLP_DA",
          ""
        )
        slpDAString = "" if slpDAString == nil

        slpconf_DAString = Convert.to_string(
          SCR.Read(path(".oes.slp.value.\"net.slp.DAAddresses\""))
        )
        if slpconf_DAString != nil
          slpDAString = Ops.add(Ops.add(slpDAString, ","), slpconf_DAString)
        end

        slpDA_list = []
        slpDA_list = Builtins.splitstring(slpDAString, ",")
        slpDA_list = Builtins.filter(slpDA_list) { |f| f != nil && f != "" } # remove empty list items
        slpDA_list = Builtins.maplist(slpDA_list) do |val2|
          String.CutBlanks(val2)
        end # trim white space around values
        slpDA_list = Builtins.toset(slpDA_list) # remove duplicate entries

        Ops.set(data, "CONFIG_EDIR_SLP_DA", slpDA_list)

        # SLP SCOPES
        useScopes = Ops.get_string(
          @old_EdirSettings,
          "CONFIG_EDIR_SLP_SCOPES",
          ""
        )
        useScopes = "" if useScopes == nil

        slpconf_useScopes = Convert.to_string(
          SCR.Read(path(".oes.slp.value.\"net.slp.useScopes\""))
        )
        if slpconf_useScopes != nil
          useScopes = Ops.add(Ops.add(useScopes, ","), slpconf_useScopes)
        end

        useScopes_list = Builtins.splitstring(useScopes, ",")
        useScopes_list = Builtins.filter(useScopes_list) do |f|
          f != nil && f != ""
        end # remove empty list items
        useScopes_list = Builtins.maplist(useScopes_list) do |val2|
          String.CutBlanks(val2)
        end # trim white space around values
        useScopes_list = Builtins.toset(useScopes_list) # remove duplicate entries

        Ops.set(
          data,
          "CONFIG_EDIR_SLP_SCOPES",
          Builtins.mergestring(useScopes_list, ",")
        )

        Ops.set(
          data,
          "CONFIG_EDIR_EXISTING_NCP_PORT",
          Builtins.tointeger(
            Ops.get_string(
              @old_EdirSettings,
              "CONFIG_EDIR_EXISTING_NCP_PORT",
              "524"
            )
          )
        )
        Ops.set(
          data,
          "CONFIG_EDIR_TLS_FOR_SIMPLE_BINDS",
          Ops.get_string(
            @old_EdirSettings,
            "CONFIG_EDIR_TLS_FOR_SIMPLE_BINDS",
            ""
          )
        )

        inst_method = Ops.get_string(
          @old_EdirSettings,
          "CONFIG_EDIR_CONFIGURE_UNIVERSALSTORE",
          ""
        )
        inst_method = "no" if inst_method == "" || inst_method == nil
        Ops.set(data, "CONFIG_EDIR_CONFIGURE_UNIVERSALSTORE", inst_method)

        inst_method = Ops.get_string(
          @old_EdirSettings,
          "CONFIG_EDIR_CONFIGURE_SECRETSTORE",
          ""
        )
        inst_method = "no" if ValidateNMASData(inst_method) == false
        Ops.set(data, "CONFIG_EDIR_CONFIGURE_SECRETSTORE", inst_method)

        # NMAS Login Methods
        inst_method = Ops.get_string(
          @old_EdirSettings,
          "CONFIG_EDIR_NMAS_CERTMUTUAL",
          ""
        )
        inst_method = "no" if ValidateNMASData(inst_method) == false
        Ops.set(data, "CONFIG_EDIR_NMAS_CERTMUTUAL", inst_method)

        inst_method = Ops.get_string(
          @old_EdirSettings,
          "CONFIG_EDIR_NMAS_CHLG_RESPONSE",
          ""
        )
        inst_method = "yes" if ValidateNMASData(inst_method) == false
        Ops.set(data, "CONFIG_EDIR_NMAS_CHLG_RESPONSE", inst_method)

        inst_method = Ops.get_string(
          @old_EdirSettings,
          "CONFIG_EDIR_NMAS_DIGEST_MD5",
          ""
        )
        inst_method = "no" if ValidateNMASData(inst_method) == false
        Ops.set(data, "CONFIG_EDIR_NMAS_DIGEST_MD5", inst_method)

        inst_method = Ops.get_string(
          @old_EdirSettings,
          "CONFIG_EDIR_NMAS_NDS",
          ""
        )
        inst_method = "yes" if ValidateNMASData(inst_method) == false
        Ops.set(data, "CONFIG_EDIR_NMAS_NDS", inst_method)

        inst_method = Ops.get_string(
          @old_EdirSettings,
          "CONFIG_EDIR_NMAS_SIMPWD",
          ""
        )
        inst_method = "no" if ValidateNMASData(inst_method) == false
        Ops.set(data, "CONFIG_EDIR_NMAS_SIMPWD", inst_method)

        inst_method = Ops.get_string(
          @old_EdirSettings,
          "CONFIG_EDIR_NMAS_GSSAPI",
          ""
        )
        inst_method = "no" if ValidateNMASData(inst_method) == false
        Ops.set(data, "CONFIG_EDIR_NMAS_GSSAPI", inst_method)

        if Mode.update || Mode.autoupgrade
          Ops.set(
            data,
            "CONFIG_EDIR_OVERWRITE_CERT_FILES",
            Ops.get_string(
              @old_EdirSettings,
              "CONFIG_EDIR_OVERWRITE_CERT_FILES",
              ""
            )
          )
        end

      else
        Builtins.y2milestone(
          "eDirectory:ReadEdirSettings:Reading eDir data from sysconfig file"
        )

        # Tree Type
        val = Convert.to_string(
          SCR.Read(path(".sysconfig.edirectory.CONFIG_EDIR_TREE_TYPE"))
        )
        val = "" if val == nil # make sure val is not nil
        Ops.set(data, "CONFIG_EDIR_TREE_TYPE", val)

        # If eDir is already configured, then read the configured value.
        val = Convert.to_string(
          SCR.Read(path(".sysconfig.edirectory.SERVICE_CONFIGURED"))
        )
        if val == "yes"
          # Use eDir cert files for HTTP services
          val = Convert.to_string(
            SCR.Read(
              path(".sysconfig.edirectory.CONFIG_EDIR_OVERWRITE_CERT_FILES")
            )
          )
          val = "yes" if val == nil # make sure val is not nil
          Ops.set(data, "CONFIG_EDIR_OVERWRITE_CERT_FILES", val) # default to yes for both new and post installs.
        else
          Ops.set(data, "CONFIG_EDIR_OVERWRITE_CERT_FILES", "yes") # new install defaults to "yes"
        end

        # Domain Services for Windows (XAD)
        if @xad_packages_installed
          Builtins.y2milestone("edir.ReadEdirSettings:calling ReadXadSettings.")
          data = Builtins.union(data, ReadXadSettings())
        else
          Builtins.y2milestone(
            "edir.ReadEdirSettings:xad_packages_installed was false."
          )
        end

        # Require TLS for simple binds
        val = Convert.to_string(
          SCR.Read(
            path(".sysconfig.edirectory.CONFIG_EDIR_TLS_FOR_SIMPLE_BINDS")
          )
        )
        val = "yes" if val == nil # make sure val is not nil
        Ops.set(data, "CONFIG_EDIR_TLS_FOR_SIMPLE_BINDS", val)

        # Install SecretStore
        val = Convert.to_string(
          SCR.Read(
            path(".sysconfig.edirectory.CONFIG_EDIR_CONFIGURE_SECRETSTORE")
          )
        )
        val = "yes" if val == nil # make sure val is not nil
        Ops.set(data, "CONFIG_EDIR_CONFIGURE_SECRETSTORE", val)

        # Install Universal password
        val = Convert.to_string(
          SCR.Read(
            path(".sysconfig.edirectory.CONFIG_EDIR_CONFIGURE_UNIVERSALSTORE")
          )
        )
        val = "no" if val == nil # make sure val is not nil
        Ops.set(data, "CONFIG_EDIR_CONFIGURE_UNIVERSALSTORE", val)

        # Server Context
        val = Convert.to_string(
          SCR.Read(path(".sysconfig.edirectory.CONFIG_EDIR_SERVER_CONTEXT"))
        )
        val = "" if val == nil # make sure val is not nil
        Ops.set(data, "CONFIG_EDIR_SERVER_CONTEXT", val)

        # DIB Location
        val = Convert.to_string(
          SCR.Read(path(".sysconfig.edirectory.CONFIG_EDIR_DIB_LOCATION"))
        )
        val = "" if val == nil # make sure val is not nil
        Ops.set(data, "CONFIG_EDIR_DIB_LOCATION", val)
        if val == ""
          Ops.set(
            data,
            "CONFIG_EDIR_DIB_LOCATION",
            "/var/opt/novell/eDirectory/data/dib"
          )
        end

        # HTTP Ports
        intval = Builtins.tointeger(
          Convert.to_string(
            SCR.Read(path(".sysconfig.edirectory.CONFIG_EDIR_HTTP_PORT"))
          )
        )
        intval = 8028 if intval == nil || Ops.less_or_equal(intval, 0) # make sure val is not nil
        Ops.set(data, "CONFIG_EDIR_HTTP_PORT", intval)
        intval = Builtins.tointeger(
          Convert.to_string(
            SCR.Read(path(".sysconfig.edirectory.CONFIG_EDIR_HTTPS_PORT"))
          )
        )
        intval = 8030 if intval == nil || Ops.less_or_equal(intval, 0) # make sure val is not nil
        Ops.set(data, "CONFIG_EDIR_HTTPS_PORT", intval)

        # NTP Server
        # First read any servers in the conf file -- there will probably be none here on a new install.
        timeServerString = Convert.to_string(
          SCR.Read(path(".sysconfig.edirectory.CONFIG_EDIR_NTP_SERVERS"))
        )
        timeServerString = "" if timeServerString == nil # make sure val is not nil

        # Now, get the existing list of time servers from the ntp.conf file.
        ntpConfList = GetNTPServerList()

        # Change to comma separated list in order be compatible with list read from sysconfig file.
        ntpConfStrList = ntpConfList.join(", ")
        if !ntpConfList.empty?

          # Put the two strings together
          timeServerString = Ops.add(
            Ops.add(timeServerString, ","),
            ntpConfStrList
          )
        end

        timeServer_list = []
        timeServer_list = Builtins.splitstring(timeServerString, ",")
        timeServer_list = Builtins.filter(timeServer_list) do |f|
          f != nil && f != ""
        end # remove empty list items
        timeServer_list = Builtins.maplist(timeServer_list) do |val2|
          String.CutBlanks(val2)
        end # trim white space around values
        timeServer_list = Builtins.toset(timeServer_list) # remove duplicate entries
        Ops.set(data, "CONFIG_EDIR_NTP_SERVERS", timeServer_list)

        val = Convert.to_string(
          SCR.Read(
            path(".sysconfig.edirectory.CONFIG_EDIR_NTP_USE_LOCAL_CLOCK")
          )
        )
        val = "no" if val == nil # make sure val is not nil
        Ops.set(data, "CONFIG_EDIR_NTP_USE_LOCAL_CLOCK", Builtins.tolower(val))

        # SLP Mode
        val = Convert.to_string(
          SCR.Read(path(".sysconfig.edirectory.CONFIG_EDIR_SLP_MODE"))
        )
        val = "" if val == nil # make sure val is not nil
        Ops.set(data, "CONFIG_EDIR_SLP_MODE", val)

        # SLP DA
        slpDAString = Convert.to_string(
          SCR.Read(path(".sysconfig.edirectory.CONFIG_EDIR_SLP_DA"))
        )
        slpDAString = "" if slpDAString == nil
        slpconf_DAString = Convert.to_string(
          SCR.Read(path(".oes.slp.value.\"net.slp.DAAddresses\""))
        )
        if slpconf_DAString != nil
          slpDAString = Ops.add(Ops.add(slpDAString, ","), slpconf_DAString)
        end

        slpDA_list = []
        slpDA_list = Builtins.splitstring(slpDAString, ",")
        slpDA_list = Builtins.filter(slpDA_list) { |f| f != nil && f != "" } # remove empty list items
        slpDA_list = Builtins.maplist(slpDA_list) do |val2|
          String.CutBlanks(val2)
        end # trim white space around values
        slpDA_list = Builtins.toset(slpDA_list) # remove duplicate entries
        Ops.set(data, "CONFIG_EDIR_SLP_DA", slpDA_list)

        # SLP SCOPES
        useScopes = Convert.to_string(
          SCR.Read(path(".sysconfig.edirectory.CONFIG_EDIR_SLP_SCOPES"))
        )
        useScopes = "" if useScopes == nil
        slpconf_useScopes = Convert.to_string(
          SCR.Read(path(".oes.slp.value.\"net.slp.useScopes\""))
        )
        if slpconf_useScopes != nil
          if useScopes != "DEFAULT"
            useScopes = Ops.add(Ops.add(useScopes, ","), slpconf_useScopes)
          else
            useScopes = slpconf_useScopes
          end
        end

        useScopes_list = Builtins.splitstring(useScopes, ",")
        useScopes_list = Builtins.filter(useScopes_list) do |f|
          f != nil && f != ""
        end # remove empty list items
        useScopes_list = Builtins.maplist(useScopes_list) do |val2|
          String.CutBlanks(val2)
        end # trim white space around values
        useScopes_list = Builtins.toset(useScopes_list) # remove duplicate entries
        Ops.set(
          data,
          "CONFIG_EDIR_SLP_SCOPES",
          Builtins.mergestring(useScopes_list, ",")
        )

        val = Convert.to_string(
          SCR.Read(path(".sysconfig.edirectory.CONFIG_EDIR_DASYNC"))
        )
        val = "no" if val == nil # make sure val is not nil
        Ops.set(data, "CONFIG_EDIR_DASYNC", val)

        val = Convert.to_string(
          SCR.Read(path(".sysconfig.edirectory.CONFIG_EDIR_SLP_BACKUP"))
        )
        val = "yes" if val == nil # make sure val is not nil
        Ops.set(data, "CONFIG_EDIR_SLP_BACKUP", val)

        val = Convert.to_string(
          SCR.Read(
            path(".sysconfig.edirectory.CONFIG_EDIR_SLP_BACKUP_INTERVAL")
          )
        )
        val = "900" if val == nil # make sure val is not nil
        Ops.set(
          data,
          "CONFIG_EDIR_SLP_BACKUP_INTERVAL",
          Builtins.sformat("%1", val)
        )

        # NMAS Login Methods
        inst_method = Convert.to_string(
          SCR.Read(path(".sysconfig.edirectory.CONFIG_EDIR_NMAS_CERTMUTUAL"))
        )
        inst_method = "no" if ValidateNMASData(inst_method) == false
        Ops.set(data, "CONFIG_EDIR_NMAS_CERTMUTUAL", inst_method)

        inst_method = Convert.to_string(
          SCR.Read(path(".sysconfig.edirectory.CONFIG_EDIR_NMAS_CHLG_RESPONSE"))
        )
        inst_method = "yes" if ValidateNMASData(inst_method) == false
        Ops.set(data, "CONFIG_EDIR_NMAS_CHLG_RESPONSE", inst_method)

        inst_method = Convert.to_string(
          SCR.Read(path(".sysconfig.edirectory.CONFIG_EDIR_NMAS_DIGEST_MD5"))
        )
        inst_method = "no" if ValidateNMASData(inst_method) == false
        Ops.set(data, "CONFIG_EDIR_NMAS_DIGEST_MD5", inst_method)

        inst_method = Convert.to_string(
          SCR.Read(path(".sysconfig.edirectory.CONFIG_EDIR_NMAS_NDS"))
        )
        inst_method = "yes" if ValidateNMASData(inst_method) == false
        Ops.set(data, "CONFIG_EDIR_NMAS_NDS", inst_method)

        inst_method = Convert.to_string(
          SCR.Read(path(".sysconfig.edirectory.CONFIG_EDIR_NMAS_SIMPWD"))
        )
        inst_method = "no" if ValidateNMASData(inst_method) == false
        Ops.set(data, "CONFIG_EDIR_NMAS_SIMPWD", inst_method)

        inst_method = Convert.to_string(
          SCR.Read(path(".sysconfig.edirectory.CONFIG_EDIR_NMAS_GSSAPI"))
        )
        inst_method = "no" if ValidateNMASData(inst_method) == false
        Ops.set(data, "CONFIG_EDIR_NMAS_GSSAPI", inst_method)
      end

      # DONE
      Builtins.y2debug("Edir Read() complete %1", data)
      deep_copy(data)
    end


    # SaveXadSettings()
    #
    # Writes Xad settings for the local system
    # to /etc/sysconfig/novell/edir
    def SaveXadSettings(data)
      data = deep_copy(data)
      Builtins.y2milestone(
        "eDirectory::SaveXadSettings writing XAD configuration information..."
      )

      ret = true

      ret = ret &&
        SCR.Write(
          path(".sysconfig.novell.xad.SERVICE_CONFIGURED"),
          Builtins.tolower(Ops.get_string(data, "XAD_SERVICE_CONFIGURED", "no"))
        )
      ret = ret &&
        SCR.Write(
          path(".sysconfig.novell.xad.XAD_DOMAIN_TYPE"),
          Builtins.tolower(Ops.get_string(data, "XAD_DOMAIN_TYPE", "forest"))
        )
      ret = ret &&
        SCR.Write(
          path(".sysconfig.novell.xad.XAD_DOMAIN_NAME"),
          Builtins.tolower(Ops.get_string(data, "XAD_DOMAIN_NAME", ""))
        )
      ret = ret &&
        SCR.Write(
          path(".sysconfig.novell.xad.XAD_CONFIG_DNS"),
          Builtins.tolower(Ops.get_string(data, "XAD_CONFIG_DNS", "no"))
        )
      ret = ret &&
        SCR.Write(
          path(".sysconfig.novell.xad.XAD_WINS_SERVER"),
          Builtins.tolower(Ops.get_string(data, "XAD_WINS_SERVER", ""))
        )
      ret = ret &&
        SCR.Write(
          path(".sysconfig.novell.xad.XAD_SITE_NAME"),
          Builtins.tolower(Ops.get_string(data, "XAD_SITE_NAME", ""))
        )
      ret = ret &&
        SCR.Write(
          path(".sysconfig.novell.xad.XAD_NETBIOS"),
          Builtins.toupper(Ops.get_string(data, "XAD_NETBIOS", ""))
        )

      ret = ret &&
        SCR.Write(
          path(".sysconfig.novell.xad.XAD_FOREST_ROOT"),
          Builtins.tolower(Ops.get_string(data, "XAD_FOREST_ROOT", ""))
        )
      ret = ret &&
        SCR.Write(
          path(".sysconfig.novell.xad.XAD_PARENT_DOMAIN"),
          Builtins.tolower(Ops.get_string(data, "XAD_PARENT_DOMAIN", ""))
        )
      ret = ret &&
        SCR.Write(
          path(".sysconfig.novell.xad.XAD_CONVERT_EXISTING_CONTAINER"),
          Builtins.tolower(
            Ops.get_string(data, "XAD_CONVERT_EXISTING_CONTAINER", "no")
          )
        )
      ret = ret &&
        SCR.Write(
          path(".sysconfig.novell.xad.XAD_EXISTING_CONTAINER"),
          Builtins.tolower(Ops.get_string(data, "XAD_EXISTING_CONTAINER", ""))
        )

      ret = ret &&
        SCR.Write(
          path(".sysconfig.novell.xad.XAD_REPLICATE_PARTITIONS"),
          Builtins.tolower(
            Ops.get_string(data, "XAD_REPLICATE_PARTITIONS", "yes")
          )
        )
      ret = ret &&
        SCR.Write(
          path(".sysconfig.novell.xad.XAD_RETAIN_POLICIES"),
          Builtins.tolower(Ops.get_string(data, "XAD_RETAIN_POLICIES", ""))
        )

      #1120027
      ret = ret &&
        SCR.Write(
          path(".sysconfig.novell.xad.XAD_PARENT_DOMAIN_ADMIN_CONTEXT"),
          Builtins.tolower(Ops.get_string(data, "XAD_PARENT_DOMAIN_ADMIN_CONTEXT", ""))
        )

      if Ops.get_string(data, "XAD_CONFIG_DNS", "") == "no"
       SCR.Write(
         path(".sysconfig.novell-dns.CONFIG_DNS_LOCATOR_CONTEXT"),
         NovellUtils.Nds2Ldap(
           Ops.get_string(@DnsSettings, "CONFIG_DNS_LOCATOR_CONTEXT", "")
         )
       )
       SCR.Write(
         path(".sysconfig.novell-dns.CONFIG_DNS_GROUP_CONTEXT"),
         NovellUtils.Nds2Ldap(
           Ops.get_string(@DnsSettings, "CONFIG_DNS_GROUP_CONTEXT", "")
         )
       )
      end

      # Flush the cache
      ret = ret && SCR.Write(path(".sysconfig.novell.xad"), nil)

      Builtins.y2milestone("Edirectory::SaveXadSettings returned: %1", ret)
      ret
    end


    # SaveEdirSettings()
    #
    # Writes eDirectory settings for the local system
    # to /etc/sysconfig/novell/edir
    def SaveEdirSettings(data)
      data = deep_copy(data)
      Builtins.y2milestone(
        "eDirectory:SaveEdirSettings:Writing eDirectory configuration information"
      )
      # Tree Type
      SCR.Write(
        path(".sysconfig.edirectory.CONFIG_EDIR_TREE_TYPE"),
        Ops.get_string(data, "CONFIG_EDIR_TREE_TYPE", "")
      )

      if Ops.get_string(data, "CONFIG_EDIR_TREE_TYPE", "") == "existing"
        # Replica address if tree type is existing.
        SCR.Write(
          path(".sysconfig.edirectory.CONFIG_EDIR_REPLICA_SERVER"),
          Ops.get_string(data, "CONFIG_EDIR_REPLICA_SERVER", "")
        )
      end

      # Use eDir certificates for HTTP services
      SCR.Write(
        path(".sysconfig.edirectory.CONFIG_EDIR_OVERWRITE_CERT_FILES"),
        Ops.get_string(data, "CONFIG_EDIR_OVERWRITE_CERT_FILES", "")
      )

      # Require TLS for Simple Binds with Password
      SCR.Write(
        path(".sysconfig.edirectory.CONFIG_EDIR_TLS_FOR_SIMPLE_BINDS"),
        Ops.get_string(data, "CONFIG_EDIR_TLS_FOR_SIMPLE_BINDS", "")
      )

      # Install SecretStore
      SCR.Write(
        path(".sysconfig.edirectory.CONFIG_EDIR_CONFIGURE_SECRETSTORE"),
        Ops.get_string(data, "CONFIG_EDIR_CONFIGURE_SECRETSTORE", "")
      )

      # Install Universal password
      SCR.Write(
        path(".sysconfig.edirectory.CONFIG_EDIR_CONFIGURE_UNIVERSALSTORE"),
        Ops.get_string(data, "CONFIG_EDIR_CONFIGURE_UNIVERSALSTORE", "")
      )

      # Server Context
      SCR.Write(
        path(".sysconfig.edirectory.CONFIG_EDIR_SERVER_CONTEXT"),
        Ops.get_string(data, "CONFIG_EDIR_SERVER_CONTEXT", "")
      )

      # Migrate Option
      SCR.Write(
        path(".sysconfig.edirectory.CONFIG_EDIR_MIGRATE_OPTION"),
        Ops.get_string(data, "CONFIG_EDIR_MIGRATE_OPTION", "")
      )

      # DIB Location
      SCR.Write(
        path(".sysconfig.edirectory.CONFIG_EDIR_DIB_LOCATION"),
        Ops.get_string(
          data,
          "CONFIG_EDIR_DIB_LOCATION",
          "/var/opt/novell/eDirectory/data/dib"
        )
      )

      # HTTP Ports
      SCR.Write(
        path(".sysconfig.edirectory.CONFIG_EDIR_HTTP_PORT"),
        Builtins.sformat(
          "%1",
          Ops.get_integer(data, "CONFIG_EDIR_HTTP_PORT", -1)
        )
      )
      SCR.Write(
        path(".sysconfig.edirectory.CONFIG_EDIR_HTTPS_PORT"),
        Builtins.sformat(
          "%1",
          Ops.get_integer(data, "CONFIG_EDIR_HTTPS_PORT", -1)
        )
      )

      # NTP Settings
      timeServerString = ""
      timeServerList = Ops.get_list(data, "CONFIG_EDIR_NTP_SERVERS", [])

      Builtins.foreach(timeServerList) do |s|
        if Ops.greater_than(Builtins.size(timeServerString), 0)
          timeServerString = Ops.add(timeServerString, ",")
        end
        timeServerString = Ops.add(timeServerString, s)
      end
      SCR.Write(
        path(".sysconfig.edirectory.CONFIG_EDIR_NTP_SERVERS"),
        timeServerString
      )

      SCR.Write(
        path(".sysconfig.edirectory.CONFIG_EDIR_NTP_USE_LOCAL_CLOCK"),
        Ops.get_string(data, "CONFIG_EDIR_NTP_USE_LOCAL_CLOCK", "")
      )

      # SLP Settings
      slpMode = Ops.get_string(data, "CONFIG_EDIR_SLP_MODE", "none")
      SCR.Write(path(".sysconfig.edirectory.CONFIG_EDIR_SLP_MODE"), slpMode)

      #    if (slpMode == "none")
      #    {
      #	SCR::Write(.sysconfig.edirectory.CONFIG_EDIR_SLP_DA,"");
      #	SCR::Write(.sysconfig.edirectory.CONFIG_EDIR_SLP_SCOPES,"DEFAULT");
      #   }
      if slpMode == "multicast"
        SCR.Write(path(".sysconfig.edirectory.CONFIG_EDIR_SLP_DA"), "")
        SCR.Write(
          path(".sysconfig.edirectory.CONFIG_EDIR_SLP_SCOPES"),
          Ops.get_string(data, "CONFIG_EDIR_SLP_SCOPES", "DEFAULT")
        )
      elsif slpMode == "da_server"
        SCR.Write(
          path(".sysconfig.edirectory.CONFIG_EDIR_DASYNC"),
          Ops.get_string(data, "CONFIG_EDIR_DASYNC", "")
        )
        slpDAString = ""
        slpdaList = Ops.get_list(data, "CONFIG_EDIR_SLP_DA", [])

        Builtins.foreach(slpdaList) do |s|
          if Ops.greater_than(Builtins.size(slpDAString), 0)
            slpDAString = Ops.add(slpDAString, ",")
          end
          slpDAString = Ops.add(slpDAString, s)
        end
        SCR.Write(path(".sysconfig.edirectory.CONFIG_EDIR_SLP_DA"), slpDAString)

        SCR.Write(
          path(".sysconfig.edirectory.CONFIG_EDIR_SLP_BACKUP"),
          Ops.get_string(data, "CONFIG_EDIR_SLP_BACKUP", "")
        )
        if Ops.get_string(data, "CONFIG_EDIR_SLP_BACKUP", "") == "yes"
          SCR.Write(
            path(".sysconfig.edirectory.CONFIG_EDIR_SLP_BACKUP_INTERVAL"),
            Ops.get_string(data, "CONFIG_EDIR_SLP_BACKUP_INTERVAL", "")
          )
        end
        SCR.Write(
          path(".sysconfig.edirectory.CONFIG_EDIR_SLP_SCOPES"),
          Ops.get_string(data, "CONFIG_EDIR_SLP_SCOPES", "DEFAULT")
        )
      else
        slpDAString = ""
        slpdaList = Ops.get_list(data, "CONFIG_EDIR_SLP_DA", [])

        Builtins.foreach(slpdaList) do |s|
          if Ops.greater_than(Builtins.size(slpDAString), 0)
            slpDAString = Ops.add(slpDAString, ",")
          end
          slpDAString = Ops.add(slpDAString, s)
        end
        SCR.Write(path(".sysconfig.edirectory.CONFIG_EDIR_SLP_DA"), slpDAString)
        SCR.Write(
          path(".sysconfig.edirectory.CONFIG_EDIR_SLP_SCOPES"),
          Ops.get_string(data, "CONFIG_EDIR_SLP_SCOPES", "DEFAULT")
        )
      end

      # NMAS Login Methods
      SCR.Write(
        path(".sysconfig.edirectory.CONFIG_EDIR_NMAS_CERTMUTUAL"),
        Ops.get_string(data, "CONFIG_EDIR_NMAS_CERTMUTUAL", "no")
      )

      SCR.Write(
        path(".sysconfig.edirectory.CONFIG_EDIR_NMAS_CHLG_RESPONSE"),
        Ops.get_string(data, "CONFIG_EDIR_NMAS_CHLG_RESPONSE", "yes")
      )

      SCR.Write(
        path(".sysconfig.edirectory.CONFIG_EDIR_NMAS_DIGEST_MD5"),
        Ops.get_string(data, "CONFIG_EDIR_NMAS_DIGEST_MD5", "no")
      )

      SCR.Write(
        path(".sysconfig.edirectory.CONFIG_EDIR_NMAS_NDS"),
        Ops.get_string(data, "CONFIG_EDIR_NMAS_NDS", "yes")
      )

      SCR.Write(
        path(".sysconfig.edirectory.CONFIG_EDIR_NMAS_SIMPWD"),
        Ops.get_string(data, "CONFIG_EDIR_NMAS_SIMPWD", "no")
      )

      SCR.Write(
        path(".sysconfig.edirectory.CONFIG_EDIR_NMAS_GSSAPI"),
        Ops.get_string(data, "CONFIG_EDIR_NMAS_GSSAPI", "no")
      )

      # Flush the cache
      SCR.Write(path(".sysconfig.edirectory"), nil)

      true
    end


    # Set the desired tuning parameters before ndsconfig is run.
    #
    # @return true on success
    def setTuningParameters
      # Set the default cache buffer size to 64k using the ndsdb.ini file
      # which is colocated with the DIB
      dibLoc = Ops.get_string(@EdirSettings, "CONFIG_EDIR_DIB_LOCATION", "")
      iniFileName = Ops.add(dibLoc, "/_ndsdb.ini")
      #    string defaultCacheBufferSizeEntry = "cache=67108864\n";
      defaultCacheBufferSizeEntry = "cache=209715200\n"
      defaultMaxThreads = "max-threads=256"
      preallocate = "preallocatecache=true"

      # Create the directory in case it does not exist.
      SCR.Execute(path(".target.mkdir"), dibLoc)

      # This file may exist especially on an upgrade
      fileContent = ""
      iniFileSize = Convert.to_integer(
        SCR.Read(path(".target.size"), iniFileName)
      )
      if iniFileSize != nil && Ops.greater_than(iniFileSize, 0)
        fileContent = Convert.to_string(
          SCR.Read(path(".target.string"), iniFileName)
        )
        fileContent = "" if fileContent == nil
      end

      # Append to the existing fileContent
      fileContent = Ops.add(fileContent, "\n")
      fileContent = Ops.add(fileContent, defaultCacheBufferSizeEntry)
      fileContent = Ops.add(fileContent, "\n")
      # fileContent = fileContent + defaultMaxThreads;
      #  fileContent = fileContent + "\n";
      if Mode.update || Mode.autoupgrade
        fileContent = Ops.add(fileContent, preallocate)
        fileContent = Ops.add(fileContent, "\n\n")
      end

      ret = SCR.Write(path(".target.string"), iniFileName, fileContent)
      if !ret
        Builtins.y2milestone(
          "eDirectory:SetTuningParameters:Failed to write cache size and max-threads to %1",
          iniFileName
        )
        return ret
      end
      Builtins.y2milestone(
        "eDirectory:SetTuningParameters:Wrote cache size and max-threads to %1",
        iniFileName
      )
      ret
    end


    # Read all edirectory settings
    #
    # @return true on success
    def Read
      Builtins.y2milestone("eDirectory:Read:Entering eDirectory::Read()")

      Ops.set(@EdirSettings, "CONFIG_EDIR_USER_ENTERED_PASSWORD", "no")

      result = :next

      @xad_packages_installed = true if @xadTestMode == true

      # Edirectory read dialog caption
      caption = _("Initializing eDirectory Configuration")

      sl = 1000
      Builtins.sleep(sl)

      stages = [
        _("Read LDAP server settings"),
        _("Read eDirectory Settings"),
        _("Checking current eDirectory configuration state")
      ]

      steps = Ops.add(Builtins.size(stages), 1)

      # We do not set help text here, because it was set outside
      Progress.New(
        caption,
        _("Read eDirectory configuration information"),
        steps,
        stages,
        stages,
        ""
      )

      Progress.NextStage
      # read current settings LDAP
      progress_orig = Progress.set(false)
      NovellLDAP.Read
      Builtins.y2milestone("edir:just did a NovellLDAP::Read()")
      Builtins.y2milestone(
        "edir:ldap tree name %1",
        Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_TREE_NAME", "")
      )

      Builtins.y2milestone(
        "edir.read:xad_service_configured: %1",
        Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "")
      )
      Progress.set(progress_orig)

      Progress.NextStage
      Builtins.sleep(sl)

      # read current settings eDirectory
      @EdirSettings = ReadEdirSettings()

      Builtins.y2milestone(
        "edir.read:xad_service_configured 2: %1",
        Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "")
      )

      Progress.NextStage
      Builtins.sleep(sl)

      Ops.set(@EdirSettings, "DoConfiguration", "DoIT")

      @upgrade_from = NovellUtils.UpgradeIsFrom
      if (Mode.update || Mode.autoupgrade) &&  @upgrade_from != ""
        @old_EdirSettings = NovellUtils.GetOldSysconfigMap("edirectory")
        if @xad_packages_installed
          @old_XadSettings = NovellUtils.GetOldSysconfigMap("xad")
          @old_DnsSettings = NovellUtils.GetOldSysconfigMap("novell-dns")
        end
      end

      @dibExists = DoesDIBExist()
      @dibExists = true if @upgradeTestMode

      if Mode.update || Mode.autoupgrade
        if !@dibExists
          Builtins.y2milestone(
            "Edirectory::Read.upgrade mode was detected but no dib was found. Will do new install instead."
          ) # read the settings again in light of upgrade mode
        else
          @EdirSettings = ReadEdirSettings()
          Ops.set(@EdirSettings, "DoConfiguration", "DoIT")
        end
      end

      @eDirRunning = NovellUtils.IseDirRunning
      @eDirInstalled = SoftwareInstalled()
      @eDirInstalled = true if @upgradeTestMode

      Builtins.y2milestone(
        "eDirectory:ReadeDirectory upgrade/reconfigure data: 
        dibExists = #{@dibExists},
        eDirRunning = #{@eDirRunning},
        upgradeFrom = #{@upgrade_from},
        eDirInstalled = #{@eDirInstalled},
        xad_packages_installed = #{@xad_packages_installed}"
      )

      Ops.set(@EdirSettings, "CONFIG_EDIR_DO_XAD", "false")
      if @xad_packages_installed
        Ops.set(@EdirSettings, "CONFIG_EDIR_DO_XAD", "true")
      end

      if !EdirDependenciesOK()
        Builtins.y2milestone("edirectory.Read:EdirDependencies were not OK.")
        result = :abort
      elsif @eDirInstalled && !@dibExists # new install case
        result = :next
      elsif @eDirInstalled && @dibExists && !Mode.update && !Mode.autoupgrade && Mode.normal
        # DON'T CHANGE TO STAGE::NORMAL reconfigure case
        # Since we cannot install XAD in reconfigure mode, we will turn it off here.
        @xad_packages_installed = false
        Ops.set(@EdirSettings, "CONFIG_EDIR_DO_XAD", "false")

        # The DIB exists - Do they want to reinstall?
        whatnext = Popup.AnyQuestion3(
          _("eDirectory database (DIB) found"),
          _(
            "eDirectory has been previously installed and configured on this system.\n" +
              "If you select reconfigure then existing eDirectory information will be\n" +
              "removed and eDirectory will be reconfigured from scratch.\n" +
              "Otherwise select upgrade to upgrade eDirectory to the current version."
          ),
          _("&Reconfigure"),
          _("&Upgrade"),
          _("&Abort"),
          :focus_no
        )
        if whatnext == :yes # Reconfigure Selection
          goon = Popup.YesNoHeadline(
            _("eDirectory Reconfiguration"),
            _(
              "You have chosen the option to reconfigure eDirectory on this system from scratch.\n" +
                "If you continue the eDirectory database on this system will be removed.\n" +
                "If any part of that database is not replicated on other eDirectory servers it will be lost.\n" +
                "Do you want to reconfigure eDirectory on this system from scratch?"
            )
          )
          if goon
            result = :abort if !eDirRetryCleanup
          else
            result = :abort
          end
        elsif whatnext == :no # Upgrade Selection
          Ops.set(@EdirSettings, "CONFIG_EDIR_DO_XAD", "false")
          result = :upgrade # Abort selection
        else
          Ops.set(@EdirSettings, "CONFIG_EDIR_DO_XAD", "false")
          result = :abort
        end
      elsif @eDirInstalled && @dibExists && !Mode.update && !Mode.autoupgrade && !Mode.normal
          # New or post install with dib found of edir installed outside of OES.
        Builtins.y2milestone(
          "edirectory.Read:dib was found for nds installed ousided of OES."
        )
        Ops.set(@EdirSettings, "CONFIG_EDIR_DO_XAD", "false")
      elsif @eDirInstalled && @dibExists &&
          (Mode.update || Mode.autoupgrade) &&
          @channelUpgrade == false # OES 2.0 upgrade case
        Builtins.y2milestone("edirectory.Read:entering upgradeMode")

        # The old OES 2.0 DIB exists and we are in upgrade mode - Do they want to upgrade?
        upgStr = _(
          "eDirectory has been previously installed and configured on this system.\nSelect upgrade to upgrade eDirectory to the current version."
        )
        if @xad_packages_installed
          upgStr = _(
            "eDirectory and DSFW have been previously installed and configured on this system.\nSelect upgrade to upgrade eDirectory/DSFW to the current version."
          )
        end
        oesEdir_info = ""
        if @upgrade_from == "OES11SP2" || @upgrade_from == "OES11SP3"
          oesEdir_info = _(
            "OES 11 eDirectory database (DIB) and config file found"
          )
        elsif @upgrade_from == "OES2015" || @upgrade_from == "OES2015SP1"
          oesEdir_info = _(
            "OES 2015 eDirectory database (DIB) and config file found"
          )
        elsif @upgrade_from == "OES2018" || @upgrade_from == "OES2018SP1" || @upgrade_from == "OES2018SP2" || @upgrade_from == "OES2018SP3"
          oesEdir_info = _(
            "OES 2018 eDirectory database (DIB) and config file found"
          )
        else
          oesEdir_info = _(
            "eDirectory database (DIB) and config file found"
          )
        end
        doUpgrade = Popup.AnyQuestion(
          oesEdir_info,
          upgStr,
          _("&Upgrade"),
          _("&Abort"),
          :focus_yes
        )
        if doUpgrade # They have selected upgrade from OES 1.0
          result = :upgrade # Abort selection
        else
          result = :abort
          @EdirSettings = ReadEdirSettings() # read the settings again with upgradeMode = false;
        end
        Builtins.y2milestone(
          "edirectory.Read:result from upgrade choice is %1",
          result
        )
      elsif @eDirInstalled && @dibExists && (Mode.update || Mode.autoupgrade) && @channelUpgrade == true
          # OES 2.0 upgrade case (channel upgrade)
        result = :upgrade
      end

      Progress.NextStage

      @globals_configured = true
      Progress.Title(_("Finished"))
      Progress.Finish
      Builtins.sleep(sl)
      Builtins.y2milestone(
        "eDirectory:ReadEdirectory::Read() returning %1",
        result
      )
      result
    end


    def SSRootCert
      ret = true
      existingIpAddr = ""

      pwd = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_PASSWORD",
        ""
      )
      adminName = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_CONTEXT",
        ""
      )

      if !NovellPatterns.IsPatternInstalled("novell-edirectory")
        ipAddr = Ops.get_string(NovellLDAP.Settings,"CONFIG_LDAP_REMOTE_SERVER_IP","")
      else
        ipAddr = NovellUtils.GetIPAddr
        # fall back to this address if the original does not work
        existingIpAddr = Ops.get_string(
          @EdirSettings,
          "CONFIG_EDIR_REPLICA_SERVER",
          ""
        )
        existingIpAddr = "" if existingIpAddr == nil

        if Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
          adminName = Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
          if Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "existing"
            pwd = Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_PASSWORD", "")
          end
        end
      end

      getSSRootCert = Ops.add(@oesinstall_dir, "/util/getSSCert")
      cmd_no_pass = Ops.add(
        Ops.add(
          Ops.add(
            Ops.add(
              Ops.add(
                Ops.add(
                  Ops.add(
                    Ops.add(getSSRootCert, " -t '"),
                    Ops.get_string(
                      NovellLDAP.Settings,
                      "CONFIG_LDAP_TREE_NAME",
                      ""
                    )
                  ),
                  "'"
                ),
                " -u '"
              ),
              NovellUtils.Ldap2Nds(adminName)
            ),
            "'"
          ),
          " -a "
        ),
        ipAddr
      )

      execute_cmd = Ops.add(
        Ops.add(Ops.add("ADM_PWD=" + "'", pwd), "' "),
        cmd_no_pass
      )

      Builtins.y2milestone("Edirectory.SSRootCert:Executing %1", cmd_no_pass)
      Builtins.y2milestone("Executing %1", cmd_no_pass)
      if @xadTestMode
        Builtins.y2milestone("xad:SSRootCert:Executing %1", execute_cmd)
      end

      retval = Convert.to_integer(
        SCR.Execute(path(".target.bash"), execute_cmd)
      )
      if retval != 0 && existingIpAddr != "" # this time try with the address of the mother ship.
        cmd_no_pass = Ops.add(
          Ops.add(
            Ops.add(
              Ops.add(
                Ops.add(
                  Ops.add(
                    Ops.add(
                      Ops.add(getSSRootCert, " -t '"),
                      Ops.get_string(
                        NovellLDAP.Settings,
                        "CONFIG_LDAP_TREE_NAME",
                        ""
                      )
                    ),
                    "'"
                  ),
                  " -u '"
                ),
                NovellUtils.Ldap2Nds(adminName)
              ),
              "'"
            ),
            " -a "
          ),
          existingIpAddr
        )

        execute_cmd = Ops.add(
          Ops.add(Ops.add("ADM_PWD=" + "'", pwd), "' "),
          cmd_no_pass
        )

        Builtins.y2milestone(
          "Edirectory.SSRootCert:Retry executing with master IP: %1",
          cmd_no_pass
        )
        if @xadTestMode
          Builtins.y2milestone("xad:SSRootCert:Retry:Executing %1", execute_cmd)
        end

        retval = Convert.to_integer(
          SCR.Execute(path(".target.bash"), execute_cmd)
        )
      end
      if retval != 0
        Builtins.y2error(
          "failed to retrieve the self-signed root certificate: %1",
          retval
        )
      else
        # generate a base64 encoded version of the self-sgined root
        # certificate
        execute_cmd = "openssl x509 -in " +
          "/etc/opt/novell/certs/SSCert.der -inform DER" +
          " > /etc/opt/novell/certs/SSCert.pem"
        retval = Convert.to_integer(
          SCR.Execute(path(".target.bash"), execute_cmd)
        )
        if retval != 0
          Builtins.y2error(
            "failed to generate the base64 encoded version of the tree CA self- signed certificate"
          )
          ret = false
        end
      end
      ret
    end


    # Call ndsconfig to configure all known (or in the future selected)
    # IP addresses
    #
    # This can and is done before eDirectory is initialized
    #
    # @return [Fixnum] 0 on success
    def ConfigIPAddresses
      # Some time change this to use CONFIG_EDIR_STATIC_IP_LIST

      params = ""
      ipaddrs = Convert.convert(
        NovellUtils.GetAllStaticIPAddrs,
        :from => "list",
        :to   => "list <string>"
      )
      Builtins.foreach(ipaddrs) do |ip|
        if params == "" # params does not contain any ip addresses
          params = Ops.add(
            Ops.add(ip, "@"),
            Ops.get_integer(@EdirSettings, "CONFIG_EDIR_EXISTING_NCP_PORT", 524)
          ) # params contains at least on ip address.
        else
          params = Ops.add(
            Ops.add(Ops.add(Ops.add(params, ","), ip), "@"),
            Ops.get_integer(@EdirSettings, "CONFIG_EDIR_EXISTING_NCP_PORT", 524)
          ) # comma seperate the ip addresses
        end
      end

      cmd = Builtins.sformat(
        "touch %2 ; %1 set n4u.server.interfaces=%3 --config-file %2",
        @ndsconfig_bin,
        Ops.get_string(
          @EdirSettings,
          "CONFIG_EDIR_CONFIG_FILE",
          "/etc/opt/novell/eDirectory/conf/nds.conf"
        ),
        params
      ) # touch the cfg file before ndsconfig to be sure the file exists

      Builtins.y2milestone(
        "NDSconfg command to establish IP addresses: '%1'",
        cmd
      )

      # Execute the command to initialize the nds.conf file with
      # the interfaces
      retval = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))

      Builtins.y2milestone(
        "Establish IP addresses via ndsconfig returned: %1",
        retval
      )
      @ndsConfigFailureMap = deep_copy(retval)
      Ops.set(@ndsConfigFailureMap, "cmd", cmd)
      Ops.get_integer(retval, "exit", -1)
    end


    # SaveSysconfigFiles - save date to files in /etc/sysconfig/novell
    #
    # @return [Boolean] true on success
    def SaveSysconfigFiles
      ret = true
      if @EdirSettings != nil &&
          Ops.greater_than(Builtins.size(@EdirSettings), 0)
        ret = ret && SaveEdirSettings(@EdirSettings)
        Builtins.y2milestone("Edirectory::SaveEdirSettings returned: %1", ret)
      end

      if Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        ret = ret && SaveXadSettings(@EdirSettings)

        Builtins.y2milestone("Edirectory::SaveXadSettings returned: %1", ret)
      end

      Builtins.y2milestone("Edirectory::SaveSysconfigFiles returned: %1", ret)
      ret
    end


    #
    # 1. Modifies /etc/slp.conf
    # 2. Configures slpd to run on reboot
    # 3. Starts slpd
    #
    # @return [Boolean] true
    def ConfigureAndStartSLP
      # Handle the specific SLP setting
      #    if ((EdirSettings["CONFIG_EDIR_SLP_MODE"]:"") == "none")
      #  {
      #	return true;
      #   }

      # Configure SLP daemon
      if Service.Enable("slpd")
        Builtins.y2milestone("eDir: SLP daemon service enabled successfully.")
      else
        Builtins.y2error(
          "eDir:Unable to ensure that the SLP daemon (slpd) will restart on boot."
        )
        Report.Warning(
          _("Unable to ensure that the SLP daemon (slpd) will restart on boot")
        )
      end

      # make sure slpd is running
      rval = Service.Active("slpd")
      if !rval
        Service.Start("slpd")
        rval = Service.Active("slpd")
        if !rval
          Builtins.y2milestone("Unable to start the slp daemon (slpd).")
          Report.Warning(_("Unable to start the slp daemon (slpd)"))
          return false
        end
      end

      return true if @xadTestMode

      if Ops.get_string(@EdirSettings, "CONFIG_EDIR_SLP_MODE", "") == "multicast"
        # If we know one interface is enabled we
        # conclude we should be happy.
        oneEnabled = false

        # See if multicast is already enabled on any interface
        enabledInterfaces = []
        cmd = "ip route | grep 224.0.0.0 | tr -s ' ' | cut -d ' ' -f3 | tr '\n' ';'"
        result = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
        if Ops.get_integer(result, "exit", -1) == 0
          output = Ops.get_string(result, "stdout", "")
          if output != nil && output != ""
            Builtins.y2milestone(
              "Search yielded the following multi-cast enabled interfaces \"%1\"",
              output
            )
            enabledInterfaces = Builtins.splitstring(output, ";")
          end
        end

        Builtins.y2milestone(
          "Detected already multi-cast enabled interfaces %1",
          enabledInterfaces
        )

        if enabledInterfaces != nil &&
            Ops.greater_than(Builtins.size(enabledInterfaces), 0)
          oneEnabled = true
        end

        # Start multicast
        # On all network devices not already enabled
        ipAddrs = NovellLDAP.GetAddresses(NovellLDAP.GetLocalServers(nil))
        device = ""
        Builtins.foreach(ipAddrs) do |ip|
          if ip != nil && ip != ""
            device = NovellUtils.MapIPAddrToDevice(ip)
            if device != nil && device != ""
              if Builtins.contains(enabledInterfaces, device)
                #			Popup::Message(sformat(_("Multicast has already been enabled on interface %1"), device));
                Builtins.y2milestone(
                  "Multicast has already been enabled on interface %1",
                  device
                )
              else
                cmd = Builtins.sformat(
                  "ip route add 224.0.0.0/4 dev %1",
                  device
                )
                rval2 = Convert.to_integer(
                  SCR.Execute(path(".target.bash"), cmd)
                )
                if rval2 != 0
                  cmd = Builtins.sformat(
                    "ip route append 224.0.0.0/4 dev %1",
                    device
                  )
                  rval2 = Convert.to_integer(
                    SCR.Execute(path(".target.bash"), cmd)
                  )
                elsif rval2 == 0
                  Builtins.y2milestone(
                    "Multicast has been enabled on %1",
                    device
                  )
                  oneEnabled = true
                else
                  err = Ops.add(
                    Builtins.sformat(
                      _(
                        "The attempt to enable multicast on device %1 failed.\n"
                      ),
                      device
                    ),
                    _(
                      "Enable multicast on this device after the system has been installed"
                    )
                  )
                  Popup.Message(err)
                end
              end
            end
          end
        end

        return oneEnabled
      end

      # handle the "use da server" case
      writeOk = false
      slpScopes = Ops.get_string(@EdirSettings, "CONFIG_EDIR_SLP_SCOPES", "")
      if slpScopes != nil && slpScopes != ""
        Builtins.y2milestone(
          "Write() SCR::Write(.oes.slp.value.\"net.slp.useScopes\", %1)",
          slpScopes
        )
        writeOk = SCR.Write(
          path(".oes.slp.value.\"net.slp.useScopes\""),
          slpScopes
        )
        if !writeOk
          Builtins.y2error(
            "Failed to update /etc/slp.conf with the specified SLP scopes"
          )
        else
          Builtins.y2milestone(
            "Wrote \"net.slp.useScopes = %1\" to /etc/slp.conf",
            slpScopes
          )
        end
      end

      if Ops.get_string(@EdirSettings, "CONFIG_EDIR_SLP_MODE", "") == "da" # use DA case
        # Handle net.slp.DAAddresses
        slpDAString = ""
        slpDAList = Ops.get_list(@EdirSettings, "CONFIG_EDIR_SLP_DA", [])
        if slpDAList != nil && Ops.greater_than(Builtins.size(slpDAList), 0)
          Builtins.foreach(slpDAList) do |s|
            if s != nil && s != ""
              if Ops.greater_than(Builtins.size(slpDAString), 0)
                slpDAString = Ops.add(slpDAString, ",")
              end
              slpDAString = Ops.add(slpDAString, s)
            end
          end
        end

        if slpDAString != nil && slpDAString != ""
          Builtins.y2milestone(
            "Write() SCR::Write(.oes.slp.value.\"net.slp.DAAddresses\", %1)",
            slpDAString
          )
          writeOk = SCR.Write(
            path(".oes.slp.value.\"net.slp.DAAddresses\""),
            slpDAString
          )
          if !writeOk
            Builtins.y2error(
              "Failed to update /etc/slp.conf with the specified DA addresses"
            )
          else
            Builtins.y2milestone(
              "Wrote \"net.slp.DAAddresses = %1\" to /etc/slp/conf",
              slpDAString
            )
          end
        end
      end

      if Ops.get_string(@EdirSettings, "CONFIG_EDIR_SLP_MODE", "") == "da_server"
        Builtins.y2milestone("Creating DA server.")

        doDASyncReg = Ops.get_string(@EdirSettings, "CONFIG_EDIR_DASYNC", "no")
        if doDASyncReg == "yes"
          doDASyncReg = "true"
        else
          doDASyncReg = "false"
        end

        do_backup = Ops.get_string(
          @EdirSettings,
          "CONFIG_EDIR_SLP_BACKUP",
          "yes"
        )
        if do_backup == "yes"
          do_backup = "true"
        else
          do_backup = "false"
        end

        backupInterval = Ops.get_string(
          @EdirSettings,
          "CONFIG_EDIR_SLP_BACKUP_INTERVAL",
          "900"
        )

        # Uncomment the slp line in slp.conf to make it a DA server
        #Command executed from command line: sed -ie 's/^;net.slp.isDA/net.slp.isDA/' /etc/slp.conf

        # net.slp.isDA
        Builtins.y2milestone(
          "Write() SCR::Write(.oes.slp.value.\"net.slp.isDA\", %1)",
          "true"
        )
        writeOk = SCR.Write(path(".oes.slp.value.\"net.slp.isDA\""), "true")
        if !writeOk
          Builtins.y2error(
            "Failed to update /etc/slp.conf with the specified isDA attribute"
          )
        else
          Builtins.y2milestone(
            "Wrote \"net.slp.isDA = %1\" to /etc/slp/conf",
            true
          )
        end

        # net.slp.DASyncReg
        Builtins.y2milestone(
          "Write() SCR::Write(.oes.slp.value.\"net.slp.DASyncReg\", %1)",
          doDASyncReg
        )
        writeOk = SCR.Write(
          path(".oes.slp.value.\"net.slp.DASyncReg\""),
          doDASyncReg
        )
        if !writeOk
          Builtins.y2error(
            "Failed to update /etc/slp.conf with the specified DASyncReg attribute"
          )
        else
          Builtins.y2milestone(
            "Wrote \"net.slp.DASyncReg = %1\" to /etc/slp/conf",
            doDASyncReg
          )
        end

        #	if( doDASyncReg == "true" )
        #	{
        # Handle net.slp.DAAddresses
        slpDAString = ""
        slpDAList = Ops.get_list(@EdirSettings, "CONFIG_EDIR_SLP_DA", [])
        if slpDAList != nil && Ops.greater_than(Builtins.size(slpDAList), 0)
          Builtins.foreach(slpDAList) do |s|
            if s != nil && s != ""
              if Ops.greater_than(Builtins.size(slpDAString), 0)
                slpDAString = Ops.add(slpDAString, ",")
              end
              slpDAString = Ops.add(slpDAString, s)
            end
          end
        end

        if slpDAString != nil && slpDAString != ""
          Builtins.y2milestone(
            "Write() SCR::Write(.oes.slp.value.\"net.slp.DAAddresses\", %1)",
            slpDAString
          )
          writeOk = SCR.Write(
            path(".oes.slp.value.\"net.slp.DAAddresses\""),
            slpDAString
          )
          if !writeOk
            Builtins.y2error(
              "Failed to update /etc/slp.conf with the specified DA addresses"
            )
          else
            Builtins.y2milestone(
              "Wrote \"net.slp.DAAddresses = %1\" to /etc/slp/conf",
              slpDAString
            )
          end
        end
        #	}

        # net.slp.isDABackup
        Builtins.y2milestone(
          "Write() SCR::Write(.oes.slp.value.\"net.slp.isDABackup\", %1)",
          do_backup
        )
        writeOk = SCR.Write(
          path(".oes.slp.value.\"net.slp.isDABackup\""),
          do_backup
        )
        if !writeOk
          Builtins.y2error(
            "Failed to update /etc/slp.conf with the specified isDABackup attribute"
          )
        else
          Builtins.y2milestone(
            "Wrote \"net.slp.isDABackup = %1\" to /etc/slp/conf",
            do_backup
          )
        end

        # net.slp.DABackupLocalReg
        Builtins.y2milestone(
          "Write() SCR::Write(.oes.slp.value.\"net.slp.DABackupLocalReg\", %1)",
          do_backup
        )
        writeOk = SCR.Write(
          path(".oes.slp.value.\"net.slp.DABackupLocalReg\""),
          do_backup
        )
        if !writeOk
          Builtins.y2error(
            "Failed to update /etc/slp.conf with the specified DABackupLocalReg attribute"
          )
        else
          Builtins.y2milestone(
            "Wrote \"net.slp.DABackupLocalReg = %1\" to /etc/slp/conf",
            do_backup
          )
        end

        if do_backup == "true"
          # net.slp.DABackupInterval
          Builtins.y2milestone(
            "Write() SCR::Write(.oes.slp.value.\"net.slp.DABackupInterval\", %1)",
            backupInterval
          )
          writeOk = SCR.Write(
            path(".oes.slp.value.\"net.slp.DABackupInterval\""),
            backupInterval
          )
          if !writeOk
            Builtins.y2error(
              "Failed to update /etc/slp.conf with the specified DABackupInterval attribute"
            )
          else
            Builtins.y2milestone(
              "Wrote \"net.slp.DABackupInterval = %1\" to /etc/slp/conf",
              backupInterval
            )
          end
        end
      end

      # Add the broadcast only flag ** JR Brown reported on 12/17/04
      # that this should remain set to false;
      # Handle net.slp.isBroadcastOnly
      #    string value = (string) SCR::Read(.oes.slp.value."net.slp.isBroadcastOnly");
      #    y2milestone("Reading of net.slp.isBroadcastOnly provide value = %1", value);
      broadcast = "false"
      Builtins.y2milestone(
        "Write() SCR::Write(.oes.slp.value.\"net.slp.isBroadcastOnly\", %1)",
        broadcast
      )
      writeOk = SCR.Write(
        path(".oes.slp.value.\"net.slp.isBroadcastOnly\""),
        broadcast
      )
      if !writeOk
        Builtins.y2error("eDir:Failed to turn off broadcast in /etc/slp.conf")
      else
        Builtins.y2milestone(
          "Wrote \"net.slp.isBroadcastOnly = %1\" to /etc/slp.conf",
          broadcast
        )
      end

      # Flush the cache
      SCR.Write(path(".oes.slp"), nil)


      true
    end


    # Copy the NICI foundation key from /opt/novell/oes-install/nici to /var/opt/novell/nici/nicifk
    #
    # @return [Boolean] true on success
    def CopyNICIFK
      destination = "/var/opt/novell/nici/nicifk"
      source = "/opt/novell/oes-install/nici/*.nfk"
      ret = Convert.to_integer(
        SCR.Execute(
          path(".target.bash"),
          Builtins.sformat("cp %1 %2", source, destination)
        )
      )

      ret = 0 if @xadTestMode

      return false if ret != 0
      true
    end


    # Extend Schema - Perform Base Schema Additions not provided by ndsconfig
    #
    # @return [Boolean] true on success
    def ExtendSchema
      allOK = true

      # Extend schema for various products.
      Popup.ShowFeedback(
        _("Extending eDirectory schema"),
        _("This may take a while")
      )

      password = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_PASSWORD",
        ""
      )
      local_server = Ops.get(NovellLDAP.GetLocalServers(nil), 0, {})
      local_host = Ops.get_string(local_server, "CONFIG_LDAP_SERVER_IP", "")
      local_port = Ops.get_integer(local_server, "CONFIG_LDAP_SECURE_PORT", 636)

      remote_server = NovellLDAP.GetAddressServer(
        Ops.get_string(@EdirSettings, "CONFIG_EDIR_REPLICA_SERVER", ""),
        nil
      )
      remote_host = Ops.get_string(remote_server, "CONFIG_LDAP_SERVER_IP", "")
      remote_port = Ops.get_integer(
        remote_server,
        "CONFIG_LDAP_SECURE_PORT",
        636
      )

      remote_host = "" if remote_host == local_host # don't fall back to the same address.


      admin = NovellUtils.Ldap2Nds(
        Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_CONTEXT", "")
      )
      if Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        admin = NovellUtils.Ldap2Nds(
          Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
        )
        if Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "existing"
          password = Ops.get_string(
            @EdirSettings,
            "XAD_LDAP_ADMIN_PASSWORD",
            ""
          )
        end
      end

      ndssch_file = "/opt/novell/eDirectory/bin/ndssch"

      #
      # nspm.sch
      #
      sch_file = "/opt/novell/sch/nspm.sch"
      cmd = Ops.add(
        Ops.add(
          Ops.add(
            Ops.add(
              Ops.add(
                Ops.add(
                  Ops.add(
                    Ops.add(Ops.add(ndssch_file, " -h "), local_host),
                    " -F '"
                  ),
                  @schemaLogPath
                ),
                "' '"
              ),
              admin
            ),
            "'"
          ),
          " "
        ),
        sch_file
      )
      Builtins.y2milestone("Edirectory:Executing %1", cmd)
      if @xadTestMode
        Builtins.y2milestone(
          "xad:ExtendSchema:executing:%1",
          Ops.add(Ops.add(Ops.add("ADM_PASSWD='", password), "' "), cmd)
        )
      end
      rmap = Convert.to_map(
        SCR.Execute(
          path(".target.bash_output"),
          Ops.add(Ops.add(Ops.add("ADM_PASSWD='", password), "' "), cmd)
        )
      )
      if Ops.get_integer(rmap, "exit", -1) != 0
        if remote_host != ""
          cmd = Ops.add(
            Ops.add(
              Ops.add(
                Ops.add(
                  Ops.add(
                    Ops.add(
                      Ops.add(
                        Ops.add(Ops.add(ndssch_file, " -h "), remote_host),
                        " -F '"
                      ),
                      @schemaLogPath
                    ),
                    "' '"
                  ),
                  admin
                ),
                "'"
              ),
              " "
            ),
            sch_file
          )
          Builtins.y2milestone(
            "eDir:Retry of schema extension with fallback IP address:Executing %1",
            cmd
          )
          if @xadTestMode
            Builtins.y2milestone(
              "xad:ExtendSchema:executing:%1",
              Ops.add(Ops.add(Ops.add("ADM_PASSWD='", password), "' "), cmd)
            )
          end

          rmap = Convert.to_map(
            SCR.Execute(
              path(".target.bash_output"),
              Ops.add(Ops.add(Ops.add("ADM_PASSWD='", password), "' "), cmd)
            )
          )
        end
        if Ops.get_integer(rmap, "exit", -1) != 0
          Builtins.y2milestone(
            "eDir:extend password policy:failed extending schema: %1 using file %2",
            Ops.get_integer(rmap, "exit", -1),
            sch_file
          )
          Builtins.y2milestone("Failed to apply the schema file: %1", sch_file)
          allOK = false
        end
      end

      #
      # nsimpm.sch
      #
      sch_file = "/opt/novell/sch/nsimpm.sch"
      cmd = Ops.add(
        Ops.add(
          Ops.add(
            Ops.add(
              Ops.add(
                Ops.add(
                  Ops.add(
                    Ops.add(Ops.add(ndssch_file, " -h "), local_host),
                    " -F '"
                  ),
                  @schemaLogPath
                ),
                "' '"
              ),
              admin
            ),
            "'"
          ),
          " "
        ),
        sch_file
      )
      Builtins.y2milestone("eDir:Executing %1", cmd)
      if @xadTestMode
        Builtins.y2milestone(
          "xad:ExtendSchema:executing:%1",
          Ops.add(Ops.add(Ops.add("ADM_PASSWD='", password), "' "), cmd)
        )
      end

      rmap = Convert.to_map(
        SCR.Execute(
          path(".target.bash_output"),
          Ops.add(Ops.add(Ops.add("ADM_PASSWD='", password), "' "), cmd)
        )
      )
      if Ops.get_integer(rmap, "exit", -1) != 0
        if remote_host != ""
          cmd = Ops.add(
            Ops.add(
              Ops.add(
                Ops.add(
                  Ops.add(
                    Ops.add(
                      Ops.add(
                        Ops.add(Ops.add(ndssch_file, " -h "), remote_host),
                        " -F '"
                      ),
                      @schemaLogPath
                    ),
                    "' '"
                  ),
                  admin
                ),
                "'"
              ),
              " "
            ),
            sch_file
          )
          Builtins.y2milestone(
            "eDir:Retry of schema extension with fallback IP address:Executing %1",
            cmd
          )
          if @xadTestMode
            Builtins.y2milestone(
              "xad:ExtendSchema:executing:%1",
              Ops.add(Ops.add(Ops.add("ADM_PASSWD='", password), "' "), cmd)
            )
          end

          rmap = Convert.to_map(
            SCR.Execute(
              path(".target.bash_output"),
              Ops.add(Ops.add(Ops.add("ADM_PASSWD='", password), "' "), cmd)
            )
          )
        end
        if Ops.get_integer(rmap, "exit", -1) != 0
          Builtins.y2milestone(
            "eDir:extend password policy:failed extending schema: %1 using file %2",
            Ops.get_integer(rmap, "exit", -1),
            sch_file
          )
          Builtins.y2milestone("Failed to apply the schema file: %1", sch_file)
          allOK = false
        end
      end

      #
      # notf.sch
      #
      sch_file = "/opt/novell/sch/notf.sch"
      cmd = Ops.add(
        Ops.add(
          Ops.add(
            Ops.add(
              Ops.add(
                Ops.add(
                  Ops.add(
                    Ops.add(Ops.add(ndssch_file, " -h "), local_host),
                    " -F '"
                  ),
                  @schemaLogPath
                ),
                "' '"
              ),
              admin
            ),
            "'"
          ),
          " "
        ),
        sch_file
      )
      Builtins.y2milestone("eDir:Executing %1", cmd)
      if @xadTestMode
        Builtins.y2milestone(
          "xad:ExtendSchema:executing:%1",
          Ops.add(Ops.add(Ops.add("ADM_PASSWD='", password), "' "), cmd)
        )
      end

      rmap = Convert.to_map(
        SCR.Execute(
          path(".target.bash_output"),
          Ops.add(Ops.add(Ops.add("ADM_PASSWD='", password), "' "), cmd)
        )
      )
      if Ops.get_integer(rmap, "exit", -1) != 0
        if remote_host != ""
          cmd = Ops.add(
            Ops.add(
              Ops.add(
                Ops.add(
                  Ops.add(
                    Ops.add(
                      Ops.add(
                        Ops.add(Ops.add(ndssch_file, " -h "), remote_host),
                        " -F '"
                      ),
                      @schemaLogPath
                    ),
                    "' '"
                  ),
                  admin
                ),
                "'"
              ),
              " "
            ),
            sch_file
          )
          Builtins.y2milestone(
            "eDir:Retry of schema extension with fallback IP address:Executing %1",
            cmd
          )
          if @xadTestMode
            Builtins.y2milestone(
              "xad:ExtendSchema:executing:%1",
              Ops.add(Ops.add(Ops.add("ADM_PASSWD='", password), "' "), cmd)
            )
          end

          rmap = Convert.to_map(
            SCR.Execute(
              path(".target.bash_output"),
              Ops.add(Ops.add(Ops.add("ADM_PASSWD='", password), "' "), cmd)
            )
          )
        end
        if Ops.get_integer(rmap, "exit", -1) != 0
          Builtins.y2milestone(
            "eDir:extend password policy:failed extending schema: %1 using file %2",
            Ops.get_integer(rmap, "exit", -1),
            sch_file
          )
          Builtins.y2milestone("Failed to apply the schema file: %1", sch_file)
          allOK = false
        end
      end

      Popup.ClearFeedback
      allOK
    end


    # Configure and start NTP
    #
    # @param timeServer Address of the NTP server to sync with (ntpdate)
    # @return [Boolean] true on success
    def ConfigureAndStartNTP(timeServers, useLocalClock)
      NtpClient.Read
      Builtins.y2milestone("edir:just did a NtpClient.Read")

      timeServers = deep_copy(timeServers)
      return true if @xadTestMode

      retval = false
      Builtins.y2milestone(
        "Edirectory:timeServers:%1, useLocalClock:%2",
        timeServers,
        useLocalClock
      )
      ntp_service = "chronyd"
      # Is NTP running
      running = Service.Status(ntp_service)

      use_local_clock = true
      use_local_clock = false if useLocalClock != "yes"

      currentTimeServerList = GetNTPServerList()
      Builtins.y2milestone("current time server: %1", currentTimeServerList)

      if timeServers != nil && timeServers != [] || use_local_clock != false
        # Stop the ntp service since it will block
        # ntpdate from running
        if running == 0
          Service.Stop(ntp_service)
          Builtins.sleep(500)
          Service.Start(ntp_service)
        end
        if use_local_clock == false
          Builtins.foreach(timeServers) do |timeServer|
              # See if this time server is already in the file
              if !Builtins.contains(currentTimeServerList, timeServer)
                # time server is not in the /etc/chrony.conf file
                rval = NtpClient.ntp_conf.add_pool(timeServer)
                Service.Restart(ntp_service)
                Builtins.y2milestone("Return Value of NtpClient.ntp_conf.add_pool is %1",rval)
                if rval == false
                  err = Builtins.sformat(
                    _(
                      "Unable to add server %1 as a time source to /etc/chrony.conf"
                    ),
                    timeServer
                  )
                  Report.Warning(err)
                  if Builtins.size(currentTimeServerList) == 0
                    retval = false
                  else
                    retval = true
                  end
                else
                  retval = true
                end
              else
                retval = true
              end
            end
        else
          # Time service is generated by the local clock
          retval = true
        end
        Service.Enable(ntp_service)
        if retval
          NtpClient.Write
          Builtins.y2milestone("Enable %1", timeServers)
          Service.Restart(ntp_service)
        end
      end
      retval
    end


    #---------------------------------------------------------------------------
    # Determine if an object already exists at the proposed location
    # for the new server object (applies only in the existing tree case
    # If the object exists offer to remove it before continuing
    # Step #5
    # Returns `continue if no conflicts are found or conflict was resolved
    # Returns `maybe some error prevented the determination of conflicting objects.
    # Returns `abort if conflicts were found and not resolved
    #---------------------------------------------------------------------------
    def CheckForConflictingObjects
      # If new tree -> no worrries
      if Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "new"
        return :continue
      end

      # What context did the user specify
      serverContext = Ops.get_string(
        @EdirSettings,
        "CONFIG_EDIR_SERVER_CONTEXT",
        ""
      )

      if serverContext == ""
        Builtins.y2milestone(
          "No server context was specified for the new directory server"
        )
        return :maybe
      end
      hostname = NovellUtils.GetHostname
      return :maybe if hostname == "" || hostname == nil
      cnName = Ops.add("cn=", hostname)

      # Search for an object at the target location for the new
      # server object
      admin_dn = NovellUtils.Ldap2Nds(
        Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_CONTEXT", "")
      )
      passwd = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_PASSWORD",
        ""
      )
      if Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        admin_dn = NovellUtils.Ldap2Nds(
          Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
        )
        if Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "existing"
          passwd = Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_PASSWORD", "")
        end
      end

      replica_server = NovellLDAP.GetAddressServer(
        Ops.get_string(@EdirSettings, "CONFIG_EDIR_REPLICA_SERVER", ""),
        nil
      )
      replica_address = Ops.get_string(
        replica_server,
        "CONFIG_LDAP_SERVER_IP",
        ""
      )
      replica_port = Ops.get_integer(
        replica_server,
        "CONFIG_LDAP_SECURE_PORT",
        636
      )
      object = Ops.add(
        Ops.add(cnName, "."),
        NovellUtils.Ldap2Nds(serverContext)
      )

      objectClass = "ncpServer"
      # Check for a conflicting object of type ncpServer
      conflict = false
      Builtins.y2milestone("edirectory:new object check code.")
      if @xadTestMode
        Builtins.y2milestone(
          "xad:check for existing objects:admin:%1, passwd:%2, replica:%3, port:%4, object:%5, objectClass:%6",
          admin_dn,
          passwd,
          replica_address,
          replica_port,
          object,
          objectClass
        )
      else
        conflict = EdirUtils.DoesDirectoryObjectExist(
          admin_dn,
          passwd,
          replica_address,
          replica_port,
          object,
          objectClass
        )
        while conflict
          retryAbort = Popup.AnyQuestion(
            _("Conflicting NCP Server object found"),
            Builtins.sformat(
              _(
                "Remove the conflicting objects. For more information, see section\n" +
                  "\"Deleting the Existing eDirectory Objects when Reinstalling the OES Server\n" +
                  "or Reconfiguring the eDirectory\" in the OES Installation Guide and then retry."
              )
            ),
            _("&Retry"),
            _("&Abort Installation"),
            :focus_yes
          )
          if retryAbort
            conflict = EdirUtils.DoesDirectoryObjectExist(
              admin_dn,
              passwd,
              replica_address,
              replica_port,
              object,
              objectClass
            )

            next if conflict
          else
            return :abort
          end
        end
      end
      return :continue if !conflict

      nil
    end


    def ConfigureNMASLogin(admin, tree, password)
      if @xadTestMode
        Builtins.y2milestone(
          "xad:ConfigureNMASLogin:tree:%1, admin:%2, pass:%3",
          tree,
          admin,
          password
        )
      end

      Builtins.y2milestone("eDir:Entering ConfigureNMASLogin.")
      # FIXME - the tree was passed in -- why look it up???
      tree = Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_TREE_NAME", "")

      local_server = Ops.get(NovellLDAP.GetLocalServers(nil), 0, {})
      localIP = Ops.get_string(local_server, "CONFIG_LDAP_SERVER_IP", "")
      localIP = NovellUtils.GetIPAddr if localIP == nil || localIP == ""

      cert_mutual = Ops.get_string(
        @EdirSettings,
        "CONFIG_EDIR_NMAS_CERTMUTUAL",
        "no"
      )
      challenge_response = Ops.get_string(
        @EdirSettings,
        "CONFIG_EDIR_NMAS_CHLG_RESPONSE",
        "yes"
      )
      digest_md5 = Ops.get_string(
        @EdirSettings,
        "CONFIG_EDIR_NMAS_DIGEST_MD5",
        "no"
      )
      nds = Ops.get_string(@EdirSettings, "CONFIG_EDIR_NMAS_NDS", "yes")
      simple_password = Ops.get_string(
        @EdirSettings,
        "CONFIG_EDIR_NMAS_SIMPWD",
        "no"
      )
      sasl_gssapi = Ops.get_string(
        @EdirSettings,
        "CONFIG_EDIR_NMAS_GSSAPI",
        "no"
      )

      # Call nmasinst FIRST TIME (Reconfigure AFTER other Schema Extensions)
      cmd = Builtins.sformat(
        "/opt/novell/eDirectory/bin/nmasinst -i '%1' '%2' -h %3 -checkversion",
        admin,
        tree,
        localIP
      )
      retcode = 0
      Builtins.y2milestone("eDir:Executing %1", cmd)
      rmap = Convert.to_map(
        SCR.Execute(
          path(".target.bash_output"),
          Ops.add(Ops.add(Ops.add("OES_DATA='", password), "' "), cmd)
        )
      )
      if Ops.get_integer(rmap, "exit", -1) != 0
        Builtins.y2milestone(
          "eDir:Could not run nmasinst: %1",
          Ops.get_integer(rmap, "exit", -1)
        )
        return false
      end

      # Install the selected NMAS Login Methods
      nmaspath = ""

      if cert_mutual == "yes"
        nmaspath = "/opt/novell/nmas/nmasmthd/CertMutual/config.txt"
        cmd = Builtins.sformat(
          "/opt/novell/eDirectory/bin/nmasinst -addmethod '%1' '%2' %3 -h %4 -checkversion",
          admin,
          tree,
          nmaspath,
          localIP
        )
        Builtins.y2milestone("eDir:Executing %1", cmd)
        rmap = Convert.to_map(
          SCR.Execute(
            path(".target.bash_output"),
            Ops.add(Ops.add(Ops.add("OES_DATA='", password), "' "), cmd)
          )
        )
        if Ops.get_integer(rmap, "exit", -1) != 0
          Builtins.y2milestone(
            "eDir:Could not run nmasinst for CertMutual: %1",
            Ops.get_integer(rmap, "exit", -1)
          )
          retcode = -1
        end
      end

      if challenge_response == "yes"
        nmaspath = "/opt/novell/nmas/nmasmthd/ChallengeResponse/config.txt"
        cmd = Builtins.sformat(
          "/opt/novell/eDirectory/bin/nmasinst -addmethod '%1' '%2' %3 -h %4 -checkversion",
          admin,
          tree,
          nmaspath,
          localIP
        )
        Builtins.y2milestone("eDir:Executing %1", cmd)
        rmap = Convert.to_map(
          SCR.Execute(
            path(".target.bash_output"),
            Ops.add(Ops.add(Ops.add("OES_DATA='", password), "' "), cmd)
          )
        )
        if Ops.get_integer(rmap, "exit", -1) != 0
          Builtins.y2milestone(
            "eDir:Could not run nmasinst for Challenge Response: %1",
            Ops.get_integer(rmap, "exit", -1)
          )
          retcode = -1
        end
      end

      if digest_md5 == "yes"
        nmaspath = "/opt/novell/nmas/nmasmthd/DigestMD5/config.txt"
        cmd = Builtins.sformat(
          "/opt/novell/eDirectory/bin/nmasinst -addmethod '%1' '%2' %3 -h %4 -checkversion",
          admin,
          tree,
          nmaspath,
          localIP
        )
        Builtins.y2milestone("eDir:Executing %1", cmd)
        rmap = Convert.to_map(
          SCR.Execute(
            path(".target.bash_output"),
            Ops.add(Ops.add(Ops.add("OES_DATA='", password), "' "), cmd)
          )
        )
        if Ops.get_integer(rmap, "exit", -1) != 0
          Builtins.y2milestone(
            "eDir:Could not run nmasinst for DIGEST-MD5: %1",
            Ops.get_integer(rmap, "exit", -1)
          )
          retcode = -1
        end
      end

      if nds == "yes"
        nmaspath = "/opt/novell/nmas/nmasmthd/NDS/config.txt"
        cmd = Builtins.sformat(
          "/opt/novell/eDirectory/bin/nmasinst -addmethod '%1' '%2' %3 -h %4 -checkversion",
          admin,
          tree,
          nmaspath,
          localIP
        )
        Builtins.y2milestone("eDir:Executing %1", cmd)
        rmap = Convert.to_map(
          SCR.Execute(
            path(".target.bash_output"),
            Ops.add(Ops.add(Ops.add("OES_DATA='", password), "' "), cmd)
          )
        )
        if Ops.get_integer(rmap, "exit", -1) != 0
          Builtins.y2milestone(
            "eDir:Could not run nmasinst for NDS: %1",
            Ops.get_integer(rmap, "exit", -1)
          )
          retcode = -1
        end
      end

      if simple_password == "yes"
        nmaspath = "/opt/novell/nmas/nmasmthd/SimplePassword/config.txt"
        cmd = Builtins.sformat(
          "/opt/novell/eDirectory/bin/nmasinst -addmethod '%1' '%2' %3 -h %4 -checkversion",
          admin,
          tree,
          nmaspath,
          localIP
        )
        Builtins.y2milestone("eDir:Executing %1", cmd)
        rmap = Convert.to_map(
          SCR.Execute(
            path(".target.bash_output"),
            Ops.add(Ops.add(Ops.add("OES_DATA='", password), "' "), cmd)
          )
        )
        if Ops.get_integer(rmap, "exit", -1) != 0
          Builtins.y2milestone(
            "eDir:Could not run nmasinst for Simple Password: %1",
            Ops.get_integer(rmap, "exit", -1)
          )
          retcode = -1
        end
      end

      if sasl_gssapi == "yes"
        nmaspath = "/opt/novell/nmas/nmasmthd/GSSAPI/config.txt"
        cmd = Builtins.sformat(
          "/opt/novell/eDirectory/bin/nmasinst -addmethod '%1' '%2' %3 -h %4 -checkversion",
          admin,
          tree,
          nmaspath,
          localIP
        )
        Builtins.y2milestone("eDir:Executing %1", cmd)
        rmap = Convert.to_map(
          SCR.Execute(
            path(".target.bash_output"),
            Ops.add(Ops.add(Ops.add("OES_DATA='", password), "' "), cmd)
          )
        )
        if Ops.get_integer(rmap, "exit", -1) != 0
          Builtins.y2milestone(
            "eDir:Could not run nmasinst for SASL GSSAPI: %1",
            Ops.get_integer(rmap, "exit", -1)
          )
          retcode = -1
        end
      end

      return false if retcode != 0

      true
    end

    # PerformEdirAbort()
    #
    # The user requested an abort of the Edirectory install
    #
    # This routine handles the aboirt, by disabling future proposals
    # (which clears out all the OES stuff (in mode cont) or exits inte
    # edirectory install (if in mode normal)
    def PerformEdirAbort
      # Disable our proposal screen AND all other proposal screens
      #    ProductControl::DisabledModules = add(ProductControl::DisabledModules,"proposal");
      ProductControl.DisableModule("proposal")
      Progress.Finish
      SCR.Write(path(".sysconfig.novell-common.ABORT_OES_INSTALL"), "yes")

      :next
    end

    def WriteEdirFailedFile
      # Start out with a blank file.
      ret = SCR.Write(
        path(".target.string"),
        "/opt/novell/oes-install/edirretryfailure",
        ""
      )
      Builtins.y2milestone(
        "Edirectory.WriteEdirFailedFile:writing out /opt/novell/oes-install/edirretryfailure file."
      )
      ret = SCR.Write(
        path(".target.string"),
        "/opt/novell/oes-install/edirretryfailure",
        "Edir retry:\n"
      )
      if ret != true
        Builtins.y2milestone(
          "Edirectory.WriteEdirFailedFile:Failed to write to /opt/novell/oes-install/edirretryfailure"
        )
      end

      # Flush the buffer
      SCR.Write(
        path(".target.string"),
        "/opt/novell/oes-install/edirretryfailure",
        nil
      )

      true
    end

    # symbol EdirFailed()
    #
    # Provide the user options in the case that Edirectory failed
    # to configure start or provide secure LDAP services
    #
    # Return values:
    #
    #    `continue - Option #1 clean up and restart ndsconfig
    #    `again    - Option #2 restart the GUI to reset eDirectory options
    #    `again_up - Option #2 restart the upgrade GUI to reset eDirectory upgrade options
    #    `next     - Cancel -  Skip configuration at this time and do it later
    #
    # This routine is called after a failure in
    #
    #    Step #7 - ConfigureAndStartEdirectory
    #    Step #8 - WaitForEdirToComeUp
    def EdirFailed
      WriteEdirFailedFile()

      @retryInProgress = true # tells us to disable back button on new or existing tree dialog.

      abortRetryAttempt = false

      errorMessage = _("ndsconfig failed to configure and start eDirectory.\n")

      if Mode.update || Mode.autoupgrade
        errorMessage = _("ndsconfig failed to upgrade and start eDirectory.\n")
      end

      NovellUtils.PopupErrorDetails(
        errorMessage,
        @ndsConfigFailureMap,
        Ops.get_string(@ndsConfigFailureMap, "cmd", "")
      )

      whatnext = nil
      doUpgradeRetry = false

      if Mode.update || Mode.autoupgrade

        doUpgradeRetry = Popup.AnyQuestion(
          _("eDirectory Upgrade Failure"),
          _(
            "eDirectory has encountered an error during upgrade.\nSelect Retry Upgrade to check data and try again."
          ),
          _("&Retry Upgrade"),
          _("&Abort"),
          :focus_yes
        )
      else
        whatnext = Popup.AnyQuestion3(
          _("Retry eDirectory configuration"),
          _(
            "We can now retry eDirectory configuration, but if you cannot determine\n"
          ) +
            _(
              "and fix the reason for this failure a retry is not likely to succeed\n"
            ) +
            _("\n") +
            _(
              "Without eDirectory operational most Open Enterprise Server components\n"
            ) +
            _(
              "cannot be configured. If you do not retry and succeed in getting eDirectory\n"
            ) +
            _(
              "operational, configuration of all OES components will be skipped and\n"
            ) +
            _(
              "can be completed after the operating system installation is complete.\n"
            ) +
            _("\n") +
            _("There are 2 retry options available:\n") +
            _(
              "Option #1 - Re-enter eDirectory configuration parameters from scratch.\n"
            ) +
            _(
              "Option #2 - Cleanup the failed attempt and retry eDirectory configuration\n"
            ) +
            _(
              "using the parameters already entered. This option is suitable for cases where\n"
            ) +
            _(
              "you have manually resolved the problem that caused the failure.\n"
            ) +
            _("Select option 1 or option 2 or abort configuration below\n"),
          _("O&ption 1"),
          _("Op&tion 2"),
          _("&Abort eDirectory configuration"),
          :focus_yes
        )
      end

      if Mode.update || Mode.autoupgrade
        if doUpgradeRetry
          if Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "existing"
            replica_address = Ops.get_string(
              @EdirSettings,
              "CONFIG_EDIR_REPLICA_SERVER",
              ""
            )
            replica_address = NovellLDAPUI.UpgradeReplicaAddressdDialog(
              replica_address
            )
            Ops.set(
              @EdirSettings,
              "CONFIG_EDIR_REPLICA_SERVER",
              replica_address
            )

            Builtins.y2milestone(
              "Edirectory::EdirFailed() returning: %1, user verified IP is %2",
              :again_up,
              Ops.get_string(@EdirSettings, "CONFIG_EDIR_REPLICA_SERVER", "")
            )
          end
          return :again_up
        else
          Builtins.y2milestone("Edirectory::EdirFailed() returned: %1", :abort)
          return :abort
        end
      else
        if whatnext == :yes # Option 1 selected
          if !eDirRetryCleanup
            Report.Error(
              _(
                "Unable to perform cleanup required to attempt a retry of eDirectory configuration.\n"
              ) +
                _(" Aborting the attempt")
            )
            abortRetryAttempt = true
          else
            Builtins.y2milestone(
              "Edirectory::EdirFailed() returned: %1",
              :again
            )
            return :again
          end
        end
        if whatnext == :no # Option 2 selected
          if !eDirRetryCleanup
            Report.Error(
              _(
                "Unable to perform cleanup required to attempt a retry of eDirectory configuration.\n"
              ) +
                _(" Aborting the attempt")
            )
            abortRetryAttempt = true
          else
            Builtins.y2milestone(
              "Edirectory::EdirFailed() returned: %1",
              :continue
            )
            return :continue
          end # Option 3 - thrid button was selected
        else
          abortRetryAttempt = true
        end
        if abortRetryAttempt
          Builtins.y2milestone("Edirectory::EdirFailed() returned: %1", :abort)
          return :abort
        end
      end

      Builtins.y2milestone("Edirectory::EdirFailed() returned: %1", nil) # FIXME: we really should be returning something here!!!!

      nil
    end

    # integer RunNDSconfigUpgrade()
    #
    # Call ndsconfig to upgrade eDir 8.7 to 8.8
    #
    # return
    #    integer - returned by ndsconfig
    def RunNDSconfigUpgrade
      Popup.ShowFeedback(
        _("Upgrading eDirectory DIB"),
        _("This will take a while..........")
      )

      cmd = Builtins.sformat(
        "%1 upgrade -c -a '%2' --config-file %3",
        @ndsconfig_bin,
        NovellUtils.Typeful2Typeless(
          NovellUtils.Ldap2Nds(
            Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_CONTEXT", "")
          )
        ),
        Ops.get_string(
          @EdirSettings,
          "CONFIG_EDIR_CONFIG_FILE",
          "/etc/opt/novell/eDirectory/conf/nds.conf"
        )
      )

      Builtins.y2milestone("Executing %1", cmd)

      #map retval = (map)SCR::Execute(.target.bash_output, execute_cmd);
      mkd = Convert.to_integer(
        SCR.Execute(
          path(".target.bash"),
          "mkdir -p /etc/opt/novell/eDirectory/conf/.edir"
        )
      )
      mkd = Convert.to_integer(
        SCR.Execute(
          path(".target.bash"),
          "chmod 1777 /etc/opt/novell/eDirectory/conf/.edir"
        )
      )

      retval = Convert.to_map(
        SCR.Execute(
          path(".target.bash_output"),
          Builtins.sformat(
            "ADM_PASSWD='%1' %2",
            Ops.get_string(
              NovellLDAP.Settings,
              "CONFIG_LDAP_ADMIN_PASSWORD",
              ""
            ),
            cmd
          )
        )
      )

      Builtins.y2milestone("SK:Map Value:\n%1", retval)

      Popup.ClearFeedback
      @ndsConfigFailureMap = deep_copy(retval)
      Ops.set(@ndsConfigFailureMap, "cmd", cmd)
      Ops.get_integer(retval, "exit", -1)
    end

    # integer RunNDSconfigRemove()
    #
    # Call ndsconfig to
    #
    # return
    #    integer - returned by ndsconfig
    def RunNDSconfigRemove
      Popup.ShowFeedback(
        _("Removing eDirectory Instance"),
        _("This will take a while..........")
      )

      admin_dn = NovellUtils.Ldap2Nds(
        Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_CONTEXT", "")
      )
      if Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        admin_dn = NovellUtils.Ldap2Nds(
          Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
        )
      end

      cmd = Builtins.sformat(
        "%1 rm -c -a '%2' --config-file %3",
        @ndsconfig_bin,
        NovellUtils.Typeful2Typeless(admin_dn),
        Ops.get_string(
          @EdirSettings,
          "CONFIG_EDIR_CONFIG_FILE",
          "/etc/opt/novell/eDirectory/conf/nds.conf"
        )
      )

      Builtins.y2milestone("Executing %1", cmd)

      #map retval = (map)SCR::Execute(.target.bash_output, execute_cmd);
      retval = Convert.to_map(
        SCR.Execute(
          path(".target.bash_output"),
          Builtins.sformat(
            "ADM_PASSWD='%1' %2",
            Ops.get_string(
              NovellLDAP.Settings,
              "CONFIG_LDAP_ADMIN_PASSWORD",
              ""
            ),
            cmd
          )
        )
      )

      Builtins.y2milestone("SK:Map Value:\n%1", retval)

      Popup.ClearFeedback
      @ndsConfigFailureMap = deep_copy(retval)
      Ops.set(@ndsConfigFailureMap, "cmd", cmd)
      Ops.get_integer(retval, "exit", -1)
    end

    # Upgrade 873 DIB
    # @return true on success
    def ndsconfigUpgrade
      Builtins.y2milestone("Begin ndsconfigUpgrade()")
      # Edirectory read dialog caption
      caption = _("eDirectory DIB Upgrade")

      sl = 50
      Builtins.sleep(sl)

      stages = [
        _("Save configuration information"),
        _("Start and upgrade eDirectory DIB using \"ndsconfig\"")
      ]

      steps = Builtins.size(stages)

      # We do not set help text here, because it was set outside
      Progress.New(
        caption,
        _("Save configuration information"),
        steps,
        stages,
        stages,
        ""
      )

      stepOK = false
      err = ""

      # Call this or stage 1 information is skipped
      Progress.NextStage
      # Step #1
      stepOK = SaveSysconfigFiles()
      if !stepOK
        err = _("Error saving configuration information to /etc/sysconfig")
        Report.Error(err)
      end

      Progress.NextStage

      ndsCfgUpg = RunNDSconfigUpgrade()
      if ndsCfgUpg != 0
        err = _("Unable to upgrade eDirectory DIB.")
        Report.Error(err)
      end
      Progress.Finish
      :next
    end

    # Remove Instance
    # @return true on success
    def ndsconfigRemove
      Builtins.y2milestone("Begin ndsconfigRemove()")
      # Edirectory read dialog caption
      caption = _("eDirectory Remove Instance")

      sl = 50
      Builtins.sleep(sl)

      stages = [
        _("Save configuration information"),
        _("Deconfigure and stop eDirectory instance using \"ndsconfig\"")
      ]

      steps = Builtins.size(stages)

      # We do not set help text here, because it was set outside
      Progress.New(
        caption,
        _("Save configuration information"),
        steps,
        stages,
        stages,
        ""
      )

      stepOK = false
      err = ""

      # Call this or stage 1 information is skipped
      Progress.NextStage
      # Step #1
      stepOK = SaveSysconfigFiles()
      if !stepOK
        err = _("Error saving configuration information to /etc/sysconfig")
        Report.Error(err)
      end

      Progress.NextStage

      ndsCfgRem = RunNDSconfigRemove()
      if ndsCfgRem != 0
        err = _("Unable to Remove eDirectory Instance.")
        Report.Error(err)
      end

      Progress.Finish
      :next
    end

    # See if we should use the default container of "ou=OESSystemObject" or the older "ou=novell"
    def ContainerIsDefault
      if @xadTestMode
        SCR.Write(path(".sysconfig.novell-common.CHANGED_OES_CONTEXT"), "no")
        return true
      end

      ret = true
      cmd = "/opt/novell/xad/share/dcinit/provisionTools.sh get-default-container"
      Builtins.y2milestone("Edirectory.ContainerIsDefault:executing:%1", cmd)

      # Can take 30 seconds
      Popup.ShowFeedback(
        _("Getting DSFW Default Container"),
        _("This may take a while")
      )
      val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      Popup.ClearFeedback

      Builtins.y2milestone("Edirectory.ContainerIsDefault:std is:%1", val)
      workStr = Ops.get_string(val, "stdout", "")

      if workStr != nil && workStr != ""
        pos = Builtins.search(workStr, "ou=novell")
        if pos != nil && Ops.greater_or_equal(pos, 0)
          ret = false
          SCR.Write(path(".sysconfig.novell-common.CHANGED_OES_CONTEXT"), "yes")
        else
          SCR.Write(path(".sysconfig.novell-common.CHANGED_OES_CONTEXT"), "no")
        end
      end
      ret
    end

    #string GetCorrectOesContainer( string container )
    #{
    #    string retStr = container;

    #    string cmd = "/opt/novell/xad/share/dcinit/provisionTools.sh get-default-container";
    #    y2milestone("Edirectory.GetCorrectOesContainer:executing:%1", cmd);
    #    map val = (map)SCR::Execute(.target.bash_output, cmd);
    #    y2milestone("Edirectory.GetCorrectOesContainer:std is:%1", val);
    #    string workStr = val["stdout"]:"";

    #    if( workStr != nil && workStr != "" )
    #    {
    #        integer pos = search(workStr, "ou=novell");
    #        if (pos != nil && pos >= 0)
    #	{
    #            // replace the ou=OESSystemObjects with ou=novell since we are joining an old DSFW tree
    #	    retStr = String::Replace( retStr, "ou=OESSystemObjects", "ou=novell");
    #	    y2milestone("Edirectory.GetCorrectOesContainer:replacing 'ou=OESSystemObjects' with 'ou=novell'");
    #            SCR::Write(.sysconfig.novell-common.CHANGED_OES_CONTEXT, "yes");
    #	}
    #	else
    #	{
    #            SCR::Write(.sysconfig.novell-common.CHANGED_OES_CONTEXT, "no");
    #	}
    #    }
    #    return retStr;
    #}

    # integer RunNDSconfig()
    #
    # Call ndsconfig to configure and attempt to start eDirectory
    #
    # return
    #    integer - returned by ndsconfig
    def RunNDSconfig(upgrade)
      SCR.Write(path(".sysconfig.novell-common.NDSCONFIG_THIS_SESSION"), "yes")
      Builtins.y2milestone(
        "Edirectory.RunNDSconfig:setting NDSCONFIG_THIS_SESSION to yes"
      )

      if upgrade
        Popup.ShowFeedback(
          _("Upgrading eDirectory"),
          _("This will take a while..........")
        )
      else
        Popup.ShowFeedback(
          _("Configuring and starting eDirectory"),
          _("This will take a while..........")
        )
      end
      base_cmd = Builtins.sformat("%1 ", @ndsconfig_bin) # NOTE there is an intential space char after the %1

      installSecretStore = Ops.get_string(
        @EdirSettings,
        "CONFIG_EDIR_CONFIGURE_SECRETSTORE",
        "yes"
      )
      secretStoreParam = ""
      if Builtins.tolower(installSecretStore) == "no"
        secretStoreParam = " -m no_ss"
      end

      if upgrade
        #base_cmd = Ops.add(base_cmd, "upgrade -c --configure-eba-now no ")
        base_cmd = Ops.add(base_cmd, "upgrade -c ")
      else
        if Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "new"
          base_cmd = Ops.add(base_cmd, "new -c -t ")
        else
          base_cmd = Ops.add(base_cmd, "add -c -t ")
        end
        base_cmd = Ops.add(
          Ops.add(
            Ops.add(base_cmd, "'"),
            Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_TREE_NAME", "")
          ),
          "'"
        )

        base_cmd = Ops.add(
          Ops.add(
            Ops.add(base_cmd, " -n '"),
            NovellUtils.Ldap2Nds(
              Ops.get_string(@EdirSettings, "CONFIG_EDIR_SERVER_CONTEXT", "")
            )
          ),
          "'"
        )
      end

      admin_dn = NovellUtils.Ldap2Nds(
        Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_CONTEXT", "")
      )
      if Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        admin_dn = NovellUtils.Ldap2Nds(
          Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
        )
      end

      base_cmd = Ops.add(
        Ops.add(Ops.add(base_cmd, " -a '"), NovellUtils.Ldap2Nds(admin_dn)),
        "'"
      )

      if !upgrade
        #base_cmd = base_cmd + " -w %1";
        if Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "existing"
          remote_server = NovellLDAP.GetAddressServer(
            Ops.get_string(@EdirSettings, "CONFIG_EDIR_REPLICA_SERVER", ""),
            nil
          )
          remoteIP = Ops.get_string(remote_server, "CONFIG_LDAP_SERVER_IP", "")
          if remoteIP == nil || remoteIP == ""
            remoteIP = Ops.get_string(
              @EdirSettings,
              "CONFIG_EDIR_REPLICA_SERVER",
              ""
            )
          end
          base_cmd = Ops.add(
            Ops.add(Ops.add(Ops.add(base_cmd, " -p "), remoteIP), ":"),
            Ops.get_integer(@EdirSettings, "CONFIG_EDIR_EXISTING_NCP_PORT", 524)
          )
        end

        local_server = Ops.get(NovellLDAP.GetLocalServers(nil), 0, {})
        base_cmd = Ops.add(
          Ops.add(base_cmd, " -d "),
          Ops.get_string(
            @EdirSettings,
            "CONFIG_EDIR_DIB_LOCATION",
            "/var/opt/novell/eDirectory/data/dib"
          )
        )
        base_cmd = Ops.add(
          Ops.add(base_cmd, " -D "),
          Ops.get_string(
            @EdirSettings,
            "CONFIG_EDIR_INSTANCE_PATH",
            "/var/opt/novell/eDirectory"
          )
        )

        base_cmd = Ops.add(base_cmd, secretStoreParam)

        ipaddrs = Convert.convert(
          NovellUtils.GetAllStaticIPAddrs,
          :from => "list",
          :to   => "list <string>"
        )
        params = ""
        Builtins.foreach(ipaddrs) do |ip|
          if params == "" # params does not contain any ip addresses
            params = Ops.add(
              Ops.add(ip, "@"),
              Ops.get_integer(
                @EdirSettings,
                "CONFIG_EDIR_EXISTING_NCP_PORT",
                524
              )
            ) # params contains at least on ip address.
          else
            params = Ops.add(
              Ops.add(Ops.add(Ops.add(params, ","), ip), "@"),
              Ops.get_integer(
                @EdirSettings,
                "CONFIG_EDIR_EXISTING_NCP_PORT",
                524
              )
            ) # comma seperate the ip addresses
          end
        end

        base_cmd = Ops.add(Ops.add(base_cmd, " -B "), params)
        base_cmd = Ops.add(
          Ops.add(base_cmd, " -L "),
          Ops.get_integer(local_server, "CONFIG_LDAP_PORT", 389)
        )
        base_cmd = Ops.add(
          Ops.add(base_cmd, " -l "),
          Ops.get_integer(local_server, "CONFIG_LDAP_SECURE_PORT", 636)
        )
        base_cmd = Ops.add(
          Ops.add(base_cmd, " -o "),
          Ops.get_integer(@EdirSettings, "CONFIG_EDIR_HTTP_PORT", 8028)
        )
        base_cmd = Ops.add(
          Ops.add(base_cmd, " -O "),
          Ops.get_integer(@EdirSettings, "CONFIG_EDIR_HTTPS_PORT", 8030)
        )

        if !upgrade
          if Ops.get_string(
              @EdirSettings,
              "CONFIG_EDIR_TLS_FOR_SIMPLE_BINDS",
              "yes"
            ) != "yes"
            base_cmd = Ops.add(base_cmd, " -e")
          end # must have -e for DSFW.  This is enforeced in the GUI with checkbox control.
        end
        if Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes" || @migration_pattern_installed
          if Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "existing"
            base_cmd = Ops.add(base_cmd, " -R") # NOTE: special case! XAD needs the ndsconfig -R option to avoid getting any default replica on this server
          end # Also, Migration does not want a replica for that case
        end
	#base_cmd = Ops.add(base_cmd," --configure-eba-now no")

        base_cmd = Ops.add(
          Ops.add(base_cmd, " --config-file "),
          Ops.get_string(
            @EdirSettings,
            "CONFIG_EDIR_CONFIG_FILE",
            "/etc/opt/novell/eDirectory/conf/nds.conf"
          )
        ) # for all types of upgrades - upgrade and upgradeMode)
      else
        base_cmd = Ops.add(
          Ops.add(base_cmd, secretStoreParam),
          " -j --config-file "
        )
        base_cmd = Ops.add(
          base_cmd,
          Ops.get_string(
            @EdirSettings,
            "CONFIG_EDIR_OLD_NDSCONF_FILE",
            "/etc/nds.conf"
          )
        )
      end

      Builtins.y2milestone("eDirectory:RunNDSconfig:Executing %1", base_cmd)
      mkd = Convert.to_integer(
        SCR.Execute(
          path(".target.bash"),
          "mkdir -p /etc/opt/novell/eDirectory/conf/.edir"
        )
      )
      mkd = Convert.to_integer(
        SCR.Execute(
          path(".target.bash"),
          "chmod 1777 /etc/opt/novell/eDirectory/conf/.edir"
        )
      )

      pWord = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_PASSWORD",
        ""
      )

      if Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        if Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") != "new"
          pWord = Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_PASSWORD", "")
        end
      end

      if pWord == nil || pWord == ""
        Builtins.y2milestone("eDirectory.RunNDSconfig:password was empty!!")
      end
      if @xadTestMode
        Builtins.y2milestone(
          "xad:executing:%1",
          Ops.add(Ops.add(Ops.add("ADM_PASSWD='", pWord), "' "), base_cmd)
        )
      end
      retval = Convert.to_map(
        SCR.Execute(
          path(".target.bash_output"),
          Ops.add(Ops.add(Ops.add("ADM_PASSWD='", pWord), "' "), base_cmd)
        )
      )

      # It is now safe to print the output map of ndsconfig since the password is no longer printed. Bugzilla 245362.
      Builtins.y2milestone(
        "eDirectory:RunNDSconfig:ndsconfig output:Map Value:\n%1",
        retval
      )

      Popup.ClearFeedback
      @ndsConfigFailureMap = deep_copy(retval)
      Ops.set(@ndsConfigFailureMap, "cmd", base_cmd)
      Ops.get_integer(retval, "exit", -1)
    end

    # WaitForEdirToComeUp()
    #
    # We attempt a secureLDAP bind to determin if eDirectory is
    # is fully ready.
    #
    # If there were any problems in getting secureLDAP running this
    # routine will return a non-ZERO value
    #
    # This constitutes the guts of step #8
    def WaitForEdirToComeUp
      Popup.ShowFeedback(
        _("Waiting for eDirectory to come up"),
        _("This may take a while")
      )
      local_server = Ops.get(NovellLDAP.GetLocalServers(nil), 0, {})
      ip = Ops.get_string(local_server, "CONFIG_LDAP_SERVER_IP", "")
      Builtins.y2milestone("lth:WaitForEdirToComeUp:ip is '%1'", ip)
      # experimental debug code below
      if ip == ""
        local_server = Ops.get(NovellLDAP.GetLocalServers(nil), 1, {})
        ip = Ops.get_string(local_server, "CONFIG_LDAP_SERVER_IP", "")
        Builtins.y2milestone("lth:WaitForEdirToComeUp:backup ip is '%1'", ip)
      end

      pwd = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_PASSWORD",
        ""
      )
      admin = NovellUtils.Ldap2Nds(
        Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_CONTEXT", "")
      )
      if Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        admin = NovellUtils.Ldap2Nds(
          Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
        )
        if Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "existing"
          pwd = Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_PASSWORD", "")
        end
      end
      port = Ops.get_integer(local_server, "CONFIG_LDAP_SECURE_PORT", 636)
      ret = WaitForLDAPtoBind(port, admin, pwd, ip)
      Popup.ClearFeedback
      if ret != 0
        err = _(
          "eDirectory authentication failed.\nPossible causes: Trees are not in sync or network latency issues."
        )
        Report.Error(err)
      end
      ret
    end

    # symbol ConfigureAndStartEdirectory()
    #
    # Performs Steps #7 and #8 with retries
    # offered after failure of either step
    def ConfigureAndStartEdirectory(dibExists)
      # Set upgrade correctly
      upgrade = false
      upgrade = true if dibExists

      if !Mode.test
        while true
          # Step #7 RunNDSconfig()
          ndsCfg = RunNDSconfig(upgrade)

          ndsCfg = 0 if @xadTestMode

          if ndsCfg != 0
            if @channelUpgrade == true
              if ndsCfg == 59
                return :again_up
              else
                errorMessage = _(
                  "ndsconfig failed to upgrade and start eDirectory.\n" +
                    "This may be due to an incorrect LDAP admin password.\n" +
                    "The online upgrade will be aborted.\n" +
                    "Check your passwords and try again."
                )
                NovellUtils.PopupErrorDetails(
                  errorMessage,
                  @ndsConfigFailureMap,
                  Ops.get_string(@ndsConfigFailureMap, "cmd", "")
                )
                return :channel_abort
              end
            end

            dn = EdirFailed()
            if dn == :continue
              next
            elsif dn == :abort
              return PerformEdirAbort()
            else
              return dn
            end
          end
          Progress.NextStage
          Builtins.y2milestone(
            "Edirectory::Write()-Step #7 Edir Started complete"
          )

          # Step #8 Wait for eDir to come up
          running = WaitForEdirToComeUp()
          running = 0 if @xadTestMode
          if running != 0
            dn = EdirFailed()
            if dn == :continue
              next
            elsif dn == :abort
              return PerformEdirAbort()
            else
              return dn
            end
          end
          Progress.NextStage
          Builtins.y2milestone(
            "Edirectory::Write()-Step #8 secure LDAP running complete"
          )
          break
        end # end while loop
      end # end  !Mode::Test()
      :goon
    end

    # Run 'ndsdcinit' to configure Domain Services for Windows (XAD)
    #
    # @return [Boolean] true on success
    def ConfigureAndStartXad(retryConfig)
      ret = true
      Builtins.y2milestone("Configuring XAD for eDirectory....")

      retainPolicies = ""

      if Mode.update || Mode.autoupgrade
        Popup.ShowFeedback(
          _("Upgrading Domain Services for Windows"),
          _("This will take a while..........")
        )
      else
        Popup.ShowFeedback(
          _("Configuring Domain Services for Windows"),
          _("This will take a while..........")
        )
      end

      # generate the ndsdcinit command with params....
      #Usage: ndsdcinit [--dns] [--replica] [Dns-Domain] [Netbios-Domain] [Forest-Root-Domain] [Parent-Domain] [Mapped-Domain-Naming-Context]
      cmd = @ndsdcinit_bin

      # add the retry parameter if this is a retry attempt.
      cmd = Ops.add(cmd, " retry") if retryConfig

      # if this is an upgrade, add the upgrade parameter
      if Mode.update || Mode.autoupgrade
        cmd = Ops.add(cmd, " upgrade")
      end

      # Get the command type set up at the beginning of the command string
      if Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "forest") != "controller"
        cmd = Ops.add(cmd, " domain")
      else
        repStr = " replica"
        if Ops.get_string(@EdirSettings, "XAD_REPLICATE_PARTITIONS", "yes") == "yes"
          repStr = " full-replica"
        end
        cmd = Ops.add(cmd, repStr)
      end

      # handle the DNS server option
      configDns = false
      if Ops.get_string(@EdirSettings, "XAD_CONFIG_DNS", "no") == "yes"
        cmd = Ops.add(cmd, " -s")
        configDns = true
      end

      cmd = Builtins.sformat(
        "%1 -d '%2'",
        cmd,
        Ops.get_string(@EdirSettings, "XAD_DOMAIN_NAME", "")
      ) # add Dns-Domain param

      # add-on the DNS parameters
      cmd = Ops.add(
        Ops.add(
          Ops.add(
            Ops.add(
              Ops.add(cmd, " -l '"),
              NovellUtils.Nds2Ldap(
                Ops.get_string(@DnsSettings, "CONFIG_DNS_LOCATOR_CONTEXT", "")
              )
            ),
            "' -g '"
          ),
          NovellUtils.Nds2Ldap(
            Ops.get_string(@DnsSettings, "CONFIG_DNS_GROUP_CONTEXT", "")
          )
        ),
        "'"
      )

      if Ops.get_string(@EdirSettings, "XAD_CONFIG_DNS", "no") == "yes"
        cmd = Ops.add(
          Ops.add(
            Ops.add(cmd, " -e '"),
            NovellUtils.Nds2Ldap(
              Ops.get_string(@EdirSettings, "CONFIG_EDIR_SERVER_CONTEXT", "")
            )
          ),
          "'"
        )
      end

      if Ops.get_string(@EdirSettings, "XAD_WINS_SERVER", "") == "yes"
        cmd = Ops.add(cmd, " -w ")
      end

      if Ops.get_string(@EdirSettings, "XAD_SITE_NAME", "") != ""
        cmd = Builtins.sformat(
          "%1 -z '%2'",
          cmd,
          Ops.get_string(@EdirSettings, "XAD_SITE_NAME", "")
        )
      end

      if !Mode.update && !Mode.autoupgrade
        # Everything but "controller" gets the netbios name.
        if Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "forest") != "controller"
          cmd = Builtins.sformat(
            "%1 -n '%2'",
            cmd,
            Ops.get_string(@EdirSettings, "XAD_NETBIOS", "")
          )
        end # add Netbios-Domain param if not controller
      end

      # add Forest-Root-Domain param and Parent-Domain param
      forest_root = Ops.get_string(@EdirSettings, "XAD_FOREST_ROOT", "")
      if Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "") == "forest"
        forest_root = Ops.get_string(@EdirSettings, "XAD_DOMAIN_NAME", "") # forest root is same as Dns-Domain name if this is a new XAD forest
        Ops.set(@EdirSettings, "XAD_FOREST_ROOT", forest_root)
      end
      cmd = Builtins.sformat("%1 -f '%2'", cmd, forest_root)

      if !Mode.update && !Mode.autoupgrade
        # add Parent-Domain
        parent_domain = Ops.get_string(@EdirSettings, "XAD_PARENT_DOMAIN", "")
        xad_domain_p = Ops.get_string(@EdirSettings, "XAD_DOMAIN_NAME", "")
        if Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "forest") != "domain"
          # Get in only for ADCs of child or grandchild domains
          if xad_domain_p != forest_root
            parent_domain = Builtins.substring(
              xad_domain_p,
              Ops.add(Builtins.findfirstof(xad_domain_p, "."), 1),
              Ops.subtract(Builtins.size(xad_domain_p), 1)
            )
          else
            parent_domain = xad_domain_p
          end
        end
        cmd = Builtins.sformat("%1 -p '%2'", cmd, parent_domain)

        # add Mapped-Domain-Naming-Context
        if Ops.get_string(@EdirSettings, "XAD_CONVERT_EXISTING_CONTAINER", "no") == "yes"
          retainPolicies = "XADRETAINPOLICIES="
          if Ops.get_string(@EdirSettings, "XAD_RETAIN_POLICIES", "no") == "yes"
            retainPolicies = Ops.add(retainPolicies, "'yes' ")
          else
            retainPolicies = Ops.add(retainPolicies, "'no' ")
          end

          cmd = Builtins.sformat(
            "%1 -m '%2'",
            cmd,
            Ops.get_string(@EdirSettings, "XAD_EXISTING_CONTAINER", "")
          )
          if Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "") == "forest"
            cmd = Builtins.sformat(
              "ROOT_SERVER=%1 %2",
              Ops.get_string(@EdirSettings, "CONFIG_EDIR_REPLICA_SERVER", ""),
              cmd
            )
          end
        end
      end
      admPass = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_PASSWORD",
        ""
      )
      if Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "existing" &&
          Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "") == "forest"
        admPass = Ops.get_string(@EdirSettings, "XAD_ADMIN_PASSWORD", "")
      end

      # Add the ndsconfig admin and password to the command.
      ndsPassword = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_PASSWORD",
        ""
      )
      if Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "") != "forest" &&
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") != "new" ||
          Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "") == "forest" &&
            Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") != "new"
        ndsPassword = Ops.get_string(
          @EdirSettings,
          "XAD_LDAP_ADMIN_PASSWORD",
          ""
        )
      end

      # Add the -o option for the remote DNS server
      if configDns == false
        dnsIP = Ops.get_string(@DnsSettings, "CONFIG_DNS_EXISTING_DNS_IP", "")
        dnsIP = GetNameServer() if dnsIP == ""

        cmd = Ops.add(Ops.add(cmd, " -o "), dnsIP)
      end

      domainAdmin = NovellUtils.Ldap2Nds(
        Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_CONTEXT", "")
      )
      parentDomainAdmin = ""

      if Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "forest") == "domain"
        parentDomainAdmin = NovellUtils.Ldap2Nds(
          Ops.get_string(@EdirSettings, "XAD_PARENT_DOMAIN_ADMIN_CONTEXT", "")
        )
      end

      if !Mode.update && !Mode.autoupgrade
        # Add the -t option if tls required
        if Ops.get_string(
            @EdirSettings,
            "CONFIG_EDIR_TLS_FOR_SIMPLE_BINDS",
            "yes"
          ) == "yes"
          cmd = Ops.add(cmd, " -t")
        end

        # add the current passwords and other data to the command
        cmd_with_passwd = Builtins.sformat(
          "XADDOMAINADMINNAME='%1' XADPARENTDOMAINADMIN='%2' ADM_PASSWD='%3' %4",
          domainAdmin,
          parentDomainAdmin,
          admPass,
          cmd
        )

        # add the eDirectory admin creds and the parent domain password...
        admName = NovellUtils.Ldap2Nds(
          Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
        )
        if Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") != "existing" # nnm frd case
          admName = domainAdmin

          cmd_with_passwd = Builtins.sformat(
            "%1ADM_PASSWD_PARENT='%2' %3",
            retainPolicies,
            Ops.get_string(
              @EdirSettings,
              "XAD_PARENT_DOMAIN_ADMIN_PASSWORD",
              ""
            ),
            cmd_with_passwd
          ) # existing tree case
        else
          cmd_with_passwd = Builtins.sformat(
            "%1NDSEXISTINGADMINNAME='%2' NDSEXISTINGADMINPASSWD='%3' ADM_PASSWD_PARENT='%4' %5",
            retainPolicies,
            admName,
            ndsPassword,
            Ops.get_string(
              @EdirSettings,
              "XAD_PARENT_DOMAIN_ADMIN_PASSWORD",
              ""
            ),
            cmd_with_passwd
          )
        end # upgrade case
      else
        # add the current passwords and other data to the command
        cmd_with_passwd = Builtins.sformat(
          "XADDOMAINADMINNAME='%1' XADPARENTDOMAINADMIN='%2' ADM_PASSWD='%3' %4",
          domainAdmin,
          parentDomainAdmin,
          admPass,
          cmd
        )
        # add the eDirectory admin creds and the parent domain password...
        cmd_with_passwd = Builtins.sformat(
          "NDSEXISTINGADMINNAME='%1' NDSEXISTINGADMINPASSWD='%2' ADM_PASSWD_PARENT='%3' %4",
          NovellUtils.Ldap2Nds(
            Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
          ),
          ndsPassword,
          Ops.get_string(@EdirSettings, "XAD_PARENT_DOMAIN_ADMIN_PASSWORD", ""),
          cmd_with_passwd
        )
      end

      # execute the ndsdcinit command.
      if @xadTestMode
        Builtins.y2milestone("xad:executing:%1", cmd_with_passwd)
        Builtins.sleep(2000) # sleep 4 seconds to simulate configuration
      else
        Builtins.y2milestone(
          "Edirectory:Executing: %1XADDOMAINADMINNAME='%2' XADPARENTDOMAINADMIN='%3' %4",
          retainPolicies,
          domainAdmin,
          parentDomainAdmin,
          cmd
        )
      end
      retmap = Convert.to_map(
        SCR.Execute(path(".target.bash_output"), cmd_with_passwd)
      )
      Builtins.y2milestone(
        "xad:exit code for ndsdcinit.pl is %1",
        Ops.get_integer(retmap, "exit", -1)
      )

      SCR.Write(path(".sysconfig.novell-common.ABORT_OES_INSTALL"), "no")
      if Mode.update || Mode.autoupgrade
        # if we get an error code of 2 returned, we have a bad domain admin password.
        if Ops.get_integer(retmap, "exit", -1) == 2
          while Ops.get_integer(retmap, "exit", -1) == 2
            Builtins.y2milestone(
              "ndsdcinit returned with error code of 2. Invalid domain admin password."
            )
            Popup.Message(
              _(
                "An incorrect Domain Admin Password has been specified.\nEnter the correct password in the dialog which follows."
              )
            )
            domainAdminPassword = NovellLDAPUI.XadDomainAdminPasswordDialog

            if @xadTestMode
              Builtins.y2milestone("xad:executing:%1", cmd_with_passwd)
              Builtins.sleep(1000) # sleep 4 seconds to simulate configuration
            else
              Builtins.y2milestone(
                "Edirectory:Executing: %1XADDOMAINADMINNAME='%2' XADPARENTDOMAINADMIN='%3' %4",
                retainPolicies,
                domainAdmin,
                parentDomainAdmin,
                cmd
              )
            end

            # add the current passwords and other data to the command
            cmd_with_passwd = Builtins.sformat(
              "XADDOMAINADMINNAME='%1' XADPARENTDOMAINADMIN='%2' ADM_PASSWD='%3' %4",
              domainAdmin,
              parentDomainAdmin,
              domainAdminPassword,
              cmd
            )
            # add the eDirectory admin creds and the parent domain password...
            cmd_with_passwd = Builtins.sformat(
              "NDSEXISTINGADMINNAME='%1' NDSEXISTINGADMINPASSWD='%2' ADM_PASSWD_PARENT='%3' %4",
              NovellUtils.Ldap2Nds(
                Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
              ),
              ndsPassword,
              Ops.get_string(
                @EdirSettings,
                "XAD_PARENT_DOMAIN_ADMIN_PASSWORD",
                ""
              ),
              cmd_with_passwd
            )

            if @xadTestMode
              Builtins.y2milestone(
                "xad:executing (domain admin password change retry):%1",
                cmd_with_passwd
              )
            end

            retmap = Convert.to_map(
              SCR.Execute(path(".target.bash_output"), cmd_with_passwd)
            )
            Builtins.y2milestone(
              "xad:exit code for ndsdcinit.pl is %1 (domain admin password retry)",
              Ops.get_integer(retmap, "exit", -1)
            )

            Ops.set(retmap, "exit", 0) if @xadTestMode
          end
        end
        #1161386
        if Ops.get_integer(retmap, "exit", -1) == 3
          Builtins.y2milestone(
            "ndsdcinit returned with error code of 3.  Domain admin password is expired.")  
          Report.Error(NovellUtils.domainPasswordExpireMsg)
          NovellUtils.channelUpgrade_abort = true
          return false
        end
      end
      if Ops.get_integer(retmap, "exit", -1) == 25
        if Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "existing"
          Popup.Message(
            _(
              "Unable to set the administrator password for DSfW domain Administrator. Set the password using iManager before starting the provisioning."
            )
          )
          Ops.set(retmap, "exit", 0)
        else
          Report.Error(
            _(
              "Unable to set the administrator password for DSfW domain Administrator. Aborting the installation."
            )
          )
          # set a signal to abort the OES install
          SCR.Write(path(".sysconfig.novell-common.ABORT_OES_INSTALL"), "yes")
          return false
        end
      end

      Popup.ClearFeedback

      Builtins.y2milestone(
        "ndsdcinit cmd output exit code: %1",
        Ops.get_integer(retmap, "exit", 0)
      )
      Builtins.y2milestone(
        "ndsdcinit cmd output exit srdout: %1",
        Ops.get_string(retmap, "stdout", "")
      )
      Builtins.y2milestone(
        "ndsdcinit cmd output exit stderr: %1",
        Ops.get_string(retmap, "srderr", "")
      )

      if @xadTestMode
        Ops.set(retmap, "exit", 0)
        ret = true
      end

      if Ops.get_integer(retmap, "exit", -1) != 0
        Builtins.y2error("Failed to configure XAD!")
        NovellUtils.PopupErrorDetails(
          _("Failed to configure Domain Services for Windows"),
          retmap,
          cmd
        )
        ret = false
      end

      if ret
        # enable(chkconfig) all the XAD services
        #		list<string> xad_services = ["novell-named", "nscd", "ndsd", "xad-krb5kdc", "xad-kpasswdd", "rpcd", "xadsd", "ntp", "smb", "nmb", "winbind", "rsyncd", "sshd"];
        xad_services = [
          "novell-named",
          "nscd",
          "ndsd",
          "chronyd",
          "smb",
          "nmb",
          "rsyncd",
          "sshd"
        ]

        Builtins.foreach(xad_services) do |service|
          Builtins.y2milestone(
            "Edirectory.ConfigureAndStartXad:enabling service:%1",
            service
          )
          success = Service.Enable(service)
          if !success
            Builtins.y2error(
              "Edirectory::ConfigureAndStartXad() - Failed to enable service: %1",
              service
            )
          end
        end

        SCR.Write(path(".sysconfig.novell-common.START_XTIER"), "yes")
        SCR.Write(path(".sysconfig.novell-common.START_DNS"), "yes")

        if Mode.update || Mode.autoupgrade
          # If we are upgrading, we need to call an additional script. We will set a flag for that here.
          SCR.Write(path(".sysconfig.novell-common.START_DSFW_UPGRADE"), "yes")

          # We need to write out the file that tells the congratulate message code to not pop up the provisioning message.
          cmd = "touch /opt/novell/oes-install/xad_provisioned"
          Builtins.y2milestone(
            "Edirectory.ConfigureAndStartXad:executing %1",
            cmd
          )
          retmap = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
          Builtins.y2milestone(
            "Edirectory.ConfigureAndStartXad:std is %1",
            retmap
          )
        else
          # Copy the desktop file so that provisioning is launched on logins
          cmd = "cp /opt/novell/oes-install/util/start-xad-provisioning.desktop /etc/xdg/autostart/."
          Builtins.y2milestone(
            "Edirectory.ConfigureAndStartXad:executing %1",
            cmd
          )
          retmap = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
          Builtins.y2milestone(
            "Edirectory.ConfigureAndStartXad:std is %1",
            retmap
          )
        end
      end

      Builtins.y2milestone(
        "Edirectory::ConfigureAndStartXad() returned: %1",
        ret
      )

      ret = true if @xadTestMode

      ret
    end

    #  /opt/novell/eDirectory/bin/ldapconfig set "ldapInterfaces=ldaps://:1636" -a admin.novell -w novell
    def Set1636and1389forDSFW
      retCode = true
      Builtins.y2milestone("edirectory:Set1636and1389forDSFW:entering.")

      if Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        admin = NovellUtils.Ldap2Nds(
          Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
        )
        admin = NovellUtils.Typeful2Typeless(admin)

        password = Ops.get_string(
          NovellLDAP.Settings,
          "CONFIG_LDAP_ADMIN_PASSWORD",
          ""
        )

        if Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "") != "forest" &&
            Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") != "new" ||
            Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "") == "forest" &&
              Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") != "new"
          password = Ops.get_string(
            @EdirSettings,
            "XAD_LDAP_ADMIN_PASSWORD",
            ""
          )
        end

        cmd = Builtins.sformat(
          "/opt/novell/eDirectory/bin/ldapconfig get \"ldapInterfaces\" -a '%1' -w '%2' | grep -i 'ldapInterfaces' |cut -d' ' -f2- | tr '\\n' ' ' | sed 's/ \\+/ /g' | tr ' ' '\\n'| sort | uniq | tr '\\n' ' ' | sed 's/ \\+/,/g' | sed 's/^,//g' | sed 's/,$//g'",
          admin,
          password
        )

        log_cmd = Builtins.sformat(
          "/opt/novell/eDirectory/bin/ldapconfig get \"ldapInterfaces\" -a '%1' -w **** | grep -i 'ldapInterfaces' |cut -d' ' -f2- | tr '\\n' ' ' | sed 's/ \\+/ /g' | tr ' ' '\\n'| sort | uniq | tr '\\n' ' ' | sed 's/ \\+/,/g' | sed 's/^,//g' | sed 's/,$//g'",
          admin
        )
        Builtins.y2milestone(
          "edirectory.Set1636and1389forDSFW:executing: %1",
          log_cmd
        )
        val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
        val_out = NovellUtils.CleanUpString(Ops.get_string(val, "stdout", ""))
        Builtins.y2milestone(
          "edirectory.Set1636and1389forDSFW:available interfaces: %1",
          val_out
        )
        if val_out == "" || val_out == ""
          val_out = "ldaps://:1636,ldap://:1389"
        else
          val_out = Ops.add(Ops.add(val_out, ","), "ldaps://:1636,ldap://:1389")
        end

        Builtins.y2milestone(
          "edirectory.Set1636and1389forDSFW:all interfaces: %1",
          val_out
        )

        # FIX FIX get password off the command line and out of the log file.

        cmd = Builtins.sformat(
          "/opt/novell/eDirectory/bin/ldapconfig set \"ldapInterfaces=%1\" -a '%2' -w '%3'",
          val_out,
          admin,
          password
        )
        log_cmd = Builtins.sformat(
          "/opt/novell/eDirectory/bin/ldapconfig set \"ldapInterfaces=%1\" -a '%2' -w ****",
          val_out,
          admin
        )
        Builtins.y2milestone(
          "edirectory.Set1636and1389forDSFW:executing: %1",
          log_cmd
        )
        val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))

        exit = Ops.get_integer(val, "exit", -1)
        retCode = false if exit != 0

        Builtins.y2milestone(
          "Edirectory.Set1636forIprint:ldapconfig:return code:%1",
          exit
        )
        ret = Ops.get_string(val, "stdout", "")
        ret = "" if ret == nil

        Builtins.y2milestone("Edirectory.Set1636and1389forDSFW:stdout:%1", ret)
      end
      retCode
    end

    # insufficient_rights_error()
    #
    # Checks a string for output indicating insufficient rights.
    def insufficient_rights_error(msg)
      return false if msg == nil || msg == ""

      idx = Builtins.search(msg, "Insufficient access")
      return true if Ops.greater_or_equal(idx, 0)

      idx = Builtins.search(msg, "no access (-672)")
      return true if Ops.greater_or_equal(idx, 0)

      false
    end

    # For configuring local DNS, use "2" for useCase. For configuring remote DNS use "3" for useCase.
    def GetContextInfo(dnsIP, useCase)
      # dns-getctx.pl -s 164.99.100.123 -p 636 -l 1 -a 'cn=admin,o=novell' -d 164.99.100.123  -u 2

      contexts = []

      keyIP = Ops.get_string(@EdirSettings, "CONFIG_EDIR_REPLICA_SERVER", "")
      if keyIP == nil || keyIP == ""
        servers = NovellLDAP.GetLocalServers(nil)
        keyIP = Ops.get_string(
          Ops.get(servers, 0, {}),
          "CONFIG_LDAP_SERVER_IP",
          ""
        )
      end
      server_list = Ops.get_list(
        NovellLDAP.Settings,
        "CONFIG_LDAP_SERVERS_LIST",
        []
      )
      our_server = NovellLDAP.GetAddressServer(keyIP, server_list)

      secure_port = Ops.get_integer(our_server, "CONFIG_LDAP_SECURE_PORT", 636)
      if secure_port == nil || Ops.less_or_equal(secure_port, 0)
        secure_port = 636
      end

      ldapIP = Ops.get_string(our_server, "CONFIG_LDAP_SERVER_IP", "")
      remoteServerIsDsfw = NovellUtils.ServerIsDsfwServer(ldapIP)

      ldapPort = Builtins.sformat("%1", secure_port)
      ldapPort = "1636" if remoteServerIsDsfw

      useSSL = "1"

      adminDn = NovellUtils.Ldap2Nds(
        Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
      )
      adminPassword = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_PASSWORD",
        ""
      )
      xad_tree_admin_context = Ops.get_string(
        NovellLDAP.Settings,
        "XAD_TREE_ADMIN_CONTEXT",
        ""
      )
      Builtins.y2milestone(
        "edirectory:XAD_TREE_ADMIN_CONTEXT:%1",
        xad_tree_admin_context
      )
      if xad_tree_admin_context != nil && xad_tree_admin_context != ""
        adminPassword = Ops.get_string(
          NovellLDAP.Settings,
          "XAD_TREE_ADMIN_PASSWORD",
          ""
        )
      end

      cmd = Builtins.sformat(
        "perl /opt/novell/named/bin/dns-getctx.pl -s %1 -p %2 -l %3 -a '%4' -d %5 -u %6",
        ldapIP,
        ldapPort,
        useSSL,
        NovellUtils.Nds2Ldap(adminDn),
        dnsIP,
        useCase
      )

      if @xadTestMode
        Builtins.y2milestone(
          "edirectory.GetContextInfo:executing: %1",
          Ops.add(Ops.add(Ops.add("OES_DATA='", adminPassword), "' "), cmd)
        )
      else
        Builtins.y2milestone("edirectory.GetContextInfo:executing: %1", cmd)
      end

      rmap = Convert.to_map(
        SCR.Execute(
          path(".target.bash_output"),
          Ops.add(Ops.add(Ops.add("OES_DATA='", adminPassword), "' "), cmd)
        )
      )
      if Ops.get_integer(rmap, "exit", -1) != 0
        Builtins.y2milestone(
          "edirectory.GetContextInfo:could not get DNS contexts. Error: %1",
          Ops.get_integer(rmap, "exit", -1)
        )
        contexts = nil
      else
        contextFile = "/opt/novell/named/bin/dns-ctx"
        if Ops.greater_than(SCR.Read(path(".target.size"), contextFile), 0)
          contextData = Convert.to_string(
            SCR.Read(path(".target.string"), contextFile)
          )
          contexts = Builtins.splitstring(contextData, "\n")
          Builtins.y2milestone(
            "edirectory.GetContextInfo:contexts: %1",
            contexts
          )
        else
          Builtins.y2milestone(
            "edirectory.GetContextInfo:script call to dns-getctx did not return an error, but the file '/opt/novell/named/bin/dns-ctx' is missing."
          )
          contexts = nil
        end
      end

      if @xadTestMode
        if useCase == "3"
          contexts = Builtins.splitstring("o=locator\no=group", "\n")
        else
          contexts = Builtins.splitstring("o=locator\no=base\no=group", "\n")
        end
      end

      deep_copy(contexts)
    end

    def ConfigureDNS
      SCR.Write(path(".sysconfig.novell-dns.SERVICE_CONFIGURED"), "no")

      cmd = ""
      rval = 0

      # determine IP addresses
      server_list = Ops.get_list(
        NovellLDAP.Settings,
        "CONFIG_LDAP_SERVERS_LIST",
        []
      )
      primary_server = NovellLDAP.GetAddressServer(
        Ops.get_string(@DnsSettings, "CONFIG_DNS_LDAP_SERVER", ""),
        server_list
      )
      fallback_list = NovellLDAP.GetFallbackServerList(
        Ops.get_string(@DnsSettings, "CONFIG_DNS_LDAP_SERVER", ""),
        server_list
      )
      Builtins.y2milestone("Primary server: %1", primary_server)
      Builtins.y2milestone("Fallback server_list: %1", fallback_list)

      full_admin_context = NovellUtils.Ldap2Nds(
        Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
      )
      admin_pwd = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_PASSWORD",
        ""
      )

      if Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") != "new"
        admin_pwd = Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_PASSWORD", "")
      end

      Builtins.y2milestone("NovellDns(edir):admin:%1", full_admin_context)
      if @xadTestMode
        Builtins.y2milestone("NovellDns(edir):pword:%1", admin_pwd)
      end

      Popup.ShowFeedback(
        _("Configuring OES DNS"),
        _("This may take a while..........")
      )

      # Extend DNS Services schema.
      insufficient_rights = false
      schema_file = "/opt/novell/sch/DNIP.SCH"
      ndssch_file = "/opt/novell/eDirectory/bin/ndssch"
      cmd = Ops.add(
        Ops.add(
          Ops.add(
            Ops.add(
              Ops.add(
                Ops.add(
                  Ops.add(
                    Ops.add(
                      Ops.add(ndssch_file, " -h "),
                      Ops.get_string(
                        primary_server,
                        "CONFIG_LDAP_SERVER_IP",
                        ""
                      )
                    ),
                    " -F '"
                  ),
                  @schemaLogPath
                ),
                "' '"
              ),
              full_admin_context
            ),
            "'"
          ),
          " "
        ),
        schema_file
      )
      if @xadTestMode
        Builtins.y2milestone(
          "NovellDns(edir):executing: %1",
          Ops.add(Ops.add(Ops.add("ADM_PASSWD='", admin_pwd), "' "), cmd)
        )
      else
        Builtins.y2milestone("novelldns(edir):Executing %1", cmd)
      end

      rmap = Convert.to_map(
        SCR.Execute(
          path(".target.bash_output"),
          Ops.add(Ops.add(Ops.add("ADM_PASSWD='", admin_pwd), "' "), cmd)
        )
      )
      if Ops.get_integer(rmap, "exit", -1) != 0
        if insufficient_rights_error(Ops.get_string(rmap, "stderr", "")) == true
          insufficient_rights = true
        end

        Builtins.y2milestone(
          "novelldns(edir):Failed (error=%1) to extend schema using default IP address: %2, using file %3",
          Ops.get_integer(rmap, "exit", -1),
          Ops.get_string(primary_server, "CONFIG_LDAP_SERVER_IP", ""),
          schema_file
        )

        Builtins.foreach(fallback_list) do |server_info|
          cmd = Ops.add(
            Ops.add(
              Ops.add(
                Ops.add(
                  Ops.add(
                    Ops.add(
                      Ops.add(
                        Ops.add(
                          Ops.add(ndssch_file, " -h "),
                          Ops.get_string(
                            server_info,
                            "CONFIG_LDAP_SERVER_IP",
                            ""
                          )
                        ),
                        " -F '"
                      ),
                      @schemaLogPath
                    ),
                    "' '"
                  ),
                  full_admin_context
                ),
                "'"
              ),
              " "
            ),
            schema_file
          )
          if @xadTestMode
            Builtins.y2milestone(
              "NovellDns(edir):Retry:executing: %1",
              Ops.add(Ops.add(Ops.add("ADM_PASSWD='", admin_pwd), "' "), cmd)
            )
          end
          Builtins.y2milestone(
            "novelldns(edir):Retry of schema extension with fallback IP address:Executing %1",
            cmd
          )
          rmap = Convert.to_map(
            SCR.Execute(
              path(".target.bash_output"),
              Ops.add(Ops.add(Ops.add("ADM_PASSWD='", admin_pwd), "' "), cmd)
            )
          )
          if Ops.get_integer(rmap, "exit", -1) != 0
            if insufficient_rights_error(Ops.get_string(rmap, "stderr", "")) == true
              insufficient_rights = true
            end
            Builtins.y2milestone(
              "novelldns(edir):Failed (error=%1) to extend schema using fallback IP address: %2, using file %3",
              Ops.get_integer(rmap, "exit", -1),
              Ops.get_string(server_info, "CONFIG_LDAP_SERVER_IP", ""),
              schema_file
            )
          else
            raise Break
          end
        end
      end
      if Ops.get_integer(rmap, "exit", -1) != 0
        if Mode.normal && insufficient_rights == true
          warn = Ops.add(
            Builtins.sformat(
              _("The user %1 has insufficient rights to extend schema.\n"),
              full_admin_context
            ),
            _(
              "This may not be a problem if joining a tree where the schema is already extended."
            )
          )

          Builtins.y2milestone("novelldns(edir).write:%1", warn)
        end
        Builtins.y2milestone(
          "novelldns(edir).write:Failed to extend schema for Novell DNS Services. Schema may already be extended if joining a NetWare Tree."
        )
      end

      # We need to replicate the schema changes across the tree so the product install below will work.
      ncpAdmin = NovellUtils.Typeful2Typeless(full_admin_context)

      cmd = Builtins.sformat(
        "/opt/novell/eDirectory/bin/ldapconfig -R -t %1 -p %2 -a %3",
        Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_TREE_NAME", ""),
        Ops.get_string(primary_server, "CONFIG_LDAP_SERVER_IP", ""),
        ncpAdmin
      )
      Builtins.y2milestone(
        "novelldns(edir):executing: %1",
        Ops.add(cmd, " -w ****")
      )

      if @xadTestMode
        Builtins.y2milestone(
          "executing: %1",
          Ops.add(Ops.add(Ops.add(cmd, " -w '"), admin_pwd), "'")
        )
      end

      # WARNING - MUST REMOVE PASSWORD FROM COMMAND LINE.
      rmap = Convert.to_map(
        SCR.Execute(
          path(".target.bash_output"),
          Ops.add(Ops.add(Ops.add(cmd, " -w '"), admin_pwd), "'")
        )
      )
      if Ops.get_integer(rmap, "exit", -1) != 0
        Builtins.y2milestone(
          "novelldns(edir):Failed (error=%1) to replicate schema using IP address: %2. Standard out:%3",
          Ops.get_integer(rmap, "exit", -1),
          Ops.get_string(primary_server, "CONFIG_LDAP_SERVER_IP", ""),
          Ops.get_string(rmap, "stdout", "")
        )
      end

      Builtins.foreach(fallback_list) do |server_info|
        cmd = Builtins.sformat(
          "/opt/novell/eDirectory/bin/ldapconfig -R -t %1 -p %2 -a %3",
          Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_TREE_NAME", ""),
          Ops.get_string(server_info, "CONFIG_LDAP_SERVER_IP", ""),
          ncpAdmin
        )
        Builtins.y2milestone(
          "novelldns(edir):executing: %1",
          Ops.add(cmd, " -w ****")
        )
        if @xadTestMode
          Builtins.y2milestone(
            Ops.add(
              Ops.add(Ops.add(Ops.add("executing:", cmd), " -w '"), admin_pwd),
              "'"
            )
          )
        end
        rmap = Convert.to_map(
          SCR.Execute(
            path(".target.bash_output"),
            Ops.add(Ops.add(Ops.add(cmd, " -w '"), admin_pwd), "'")
          )
        )
        if Ops.get_integer(rmap, "exit", -1) != 0
          Builtins.y2milestone(
            "novelldns(edir):Failed (error=%1) to replicate schema using IP address: %2. Standard out:%3",
            Ops.get_integer(rmap, "exit", -1),
            Ops.get_string(server_info, "CONFIG_LDAP_SERVER_IP", ""),
            Ops.get_string(rmap, "stdout", "")
          )
        end
      end

      # Call the Novell DNS Services config module
      ldap_host = Ops.get_string(primary_server, "CONFIG_LDAP_SERVER_IP", "")

      ldap_port = 389

      ldap_basedn = NovellUtils.Nds2Ldap(
        Ops.get_string(@DnsSettings, "CONFIG_DNS_LDAP_BASEDN", "")
      )

      server_context = NovellUtils.Nds2Ldap(
        Ops.get_string(@EdirSettings, "CONFIG_EDIR_SERVER_CONTEXT", "")
      )
      Ops.set(@DnsSettings, "CONFIG_DNS_SERVER_CONTEXT", server_context) # may have changed in just before call to ndsconfig.

      locator_context = NovellUtils.Nds2Ldap(
        Ops.get_string(@DnsSettings, "CONFIG_DNS_LOCATOR_CONTEXT", "")
      )
      group_context = NovellUtils.Nds2Ldap(
        Ops.get_string(@DnsSettings, "CONFIG_DNS_GROUP_CONTEXT", "")
      )
      runtimeAdmin = NovellUtils.Nds2Ldap(
        Ops.get_string(@DnsSettings, "CONFIG_DNS_LDAP_USER_CONTEXT", "")
      )
      runtimePassword = Ops.get_string(
        @DnsSettings,
        "CONFIG_DNS_LDAP_USER_PASSWORD",
        ""
      )

      Builtins.y2milestone(
        "tlc:runtimeAdmin is %1 and pass is %2",
        runtimeAdmin,
        runtimePassword
      )

      useCommonProxy = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_DO_PROXY",
        ""
      )
      Builtins.y2milestone(
        "NovellDns (dsfw).Write:useCommonProxy: %1",
        useCommonProxy
      )
      if useCommonProxy == "yes"
        commonProxyName = NovellUtils.Nds2Ldap(
          Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_PROXY_CONTEXT", "")
        )
        commonProxyPassword = NovellUtils.RetrieveProxyCredentials("password")
        if commonProxyPassword == nil || commonProxyPassword == ""
          commonProxyPassword = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_PROXY_PASSWORD",
            ""
          )
        end

        if NovellUtils.Nds2Ldap(
            Ops.get_string(@DnsSettings, "CONFIG_DNS_LDAP_USER_CONTEXT", "")
          ) == commonProxyName
          runtimePassword = commonProxyPassword
          Ops.set(
            @DnsSettings,
            "CONFIG_DNS_LDAP_USER_PASSWORD",
            runtimePassword
          )
        end
      end

      if Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "new"
        if runtimeAdmin == ""
          runtimeAdmin = NovellUtils.Ldap2Nds(full_admin_context)
          runtimePassword = admin_pwd
        end
      end

      ssl = "0"
      ocs = "0"
      createServer = Ops.get_string(
        @DnsSettings,
        "CONFIG_DNS_CREATE_SERVER_OBJECT",
        "no"
      )
      createServer = "no" if createServer == nil
      addServerParams = false
      addServerParams = true if Builtins.tolower(createServer) == "yes"

      hostName = Ops.get_string(@DnsSettings, "CONFIG_DNS_HOST_NAME", "")
      domainName = Ops.get_string(@DnsSettings, "CONFIG_DNS_DOMAIN_NAME", "")

      serverCreateParams = ""
      if addServerParams
        serverCreateParams = Ops.add(
          Ops.add(Ops.add(Ops.add("1 '", hostName), "' '"), domainName),
          "'"
        )
      end

      if Ops.get_string(@DnsSettings, "CONFIG_DNS_STORE_CREDENTIAL_IN_OCS", "") == "yes"
        ocs = "1"
      end

      if Ops.get_string(@DnsSettings, "CONFIG_DNS_USE_SECURE_PORT", "") != "no"
        ssl = "1"
        ldap_port = 636
      end

      cmd = Builtins.sformat(
        "/opt/novell/named/bin/dns-inst %1 %2 '%3' '---' '%4' '---' %5 '%6' '%7'",
        ldap_host,
        ldap_port,
        NovellUtils.Nds2Ldap(full_admin_context),
        runtimeAdmin,
        ocs,
        locator_context,
        group_context
      )


      cmd = Ops.add(
        cmd,
        Builtins.sformat(
          " '%1' '%2' %3 %4",
          ldap_basedn,
          server_context,
          serverCreateParams,
          ssl
        )
      )

      if @xadTestMode == false
        Builtins.y2milestone("novelldns(edir).write:Executing %1", cmd)
      else
        Builtins.y2milestone(
          "novelldns(edir).write:Executing %1",
          Builtins.sformat(
            "OES_DATA='%1' OES_DATA2='%2' %3",
            admin_pwd,
            runtimePassword,
            cmd
          )
        )
      end

      retval = Convert.to_map(
        SCR.Execute(
          path(".target.bash_output"),
          Builtins.sformat(
            "OES_DATA='%1' OES_DATA2='%2' %3",
            admin_pwd,
            runtimePassword,
            cmd
          )
        )
      )

      Popup.ClearFeedback

      dnsConfiguredOk = true
      if Ops.get_integer(retval, "exit", -1) != 0
        dnsConfiguredOk = false if @xadTestMode == false

        ret = Ops.get_integer(retval, "exit", -1)
        errorMsg = Builtins.sformat(
          _("Unknown error while configuring OES DNS Services: %1"),
          ret
        )
        if ret == 1
          errorMsg = _(
            "BIND to LDAP server failed while configuring OES DNS Services."
          )
        elsif ret == 2
          errorMsg = _(
            "DNS Group object configuration failed while configuring OES DNS Services."
          )
        elsif ret == 3
          errorMsg = _(
            "DNS Locator object configuration failed while configuring OES DNS Services."
          )
        elsif ret == 4
          errorMsg = _(
            "DNS RootServerInfo object configuration failed while configuring OES DNS Services."
          )
        elsif ret == 5
          errorMsg = _(
            "NCP server object configuration for DNS failed while configuring OES DNS Services."
          )
        elsif ret == 6
          errorMsg = _(
            "DNS Locator Object configuration for trustee modification failed while configuring OES DNS Services."
          )
        elsif ret == 7
          errorMsg = _(
            "DNS RootServerInfo object configuration for trustee modification failed while configuring OES DNS Services."
          )
        elsif ret == 8
          errorMsg = Builtins.sformat(_("Could not create server object."))
        elsif ret == 9
          errorMsg = Builtins.sformat(_("NCP Server object search failed."))
        elsif ret == 10
          errorMsg = Builtins.sformat(_("DNS username creation failed."))
        end

        Builtins.y2error(errorMsg)
        Report.Error(errorMsg)
      end

      # Write the /etc/sysconfig file
      SCR.Write(
        path(".sysconfig.novell-dns.CONFIG_DNS_LDAP_SERVER"),
        Builtins.sformat(
          "%1",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_LDAP_SERVER", "")
        )
      )
      SCR.Write(
        path(".sysconfig.novell-dns.CONFIG_DNS_LDAP_BASEDN"),
        ldap_basedn
      )
      SCR.Write(
        path(".sysconfig.novell-dns.CONFIG_DNS_SERVER_CONTEXT"),
        server_context
      )
      SCR.Write(
        path(".sysconfig.novell-dns.CONFIG_DNS_LOCATOR_CONTEXT"),
        locator_context
      )
      SCR.Write(
        path(".sysconfig.novell-dns.CONFIG_DNS_GROUP_CONTEXT"),
        group_context
      )
      SCR.Write(
        path(".sysconfig.novell-dns.CONFIG_DNS_USE_SECURE_PORT"),
        Ops.get_string(@DnsSettings, "CONFIG_DNS_USE_SECURE_PORT", "yes")
      )
      SCR.Write(
        path(".sysconfig.novell-dns.CONFIG_DNS_LDAP_USER_CONTEXT"),
        Ops.get_string(@DnsSettings, "CONFIG_DNS_LDAP_USER_CONTEXT", "")
      )
      SCR.Write(
        path(".sysconfig.novell-dns.CONFIG_DNS_CREATE_SERVER_OBJECT"),
        Ops.get_string(@DnsSettings, "CONFIG_DNS_CREATE_SERVER_OBJECT", "no")
      )
      SCR.Write(
        path(".sysconfig.novell-dns.CONFIG_DNS_HOST_NAME"),
        Ops.get_string(@DnsSettings, "CONFIG_DNS_HOST_NAME", "")
      )
      SCR.Write(
        path(".sysconfig.novell-dns.CONFIG_DNS_DOMAIN_NAME"),
        Ops.get_string(@DnsSettings, "CONFIG_DNS_DOMAIN_NAME", "")
      )
      SCR.Write(
        path(".sysconfig.novell-dns.CONFIG_DNS_STORE_CREDENTIAL_IN_OCS"),
        Ops.get_string(@DnsSettings, "CONFIG_DNS_STORE_CREDENTIAL_IN_OCS", "")
      )

      # open ports 53 and 953
      NovellUtils.SetFirewallPort(53, :both, true)
      NovellUtils.SetFirewallPort(953, :both, true)

      if Ops.get_integer(retval, "exit", -1) == 0
        SCR.Write(path(".sysconfig.novell-dns.SERVICE_CONFIGURED"), "yes")
        SCR.Write(
          path(".sysconfig.novell-dns.SERVICE_PREVIOUSLY_CONFIGURED"),
          "yes"
        )
      end

      # Flush the sysconfig file.
      SCR.Write(path(".sysconfig.novell-dns"), nil)

      Builtins.y2debug(
        "Novell DNS Services Settings(edir version): %1",
        @DnsSettings
      )

      dnsConfiguredOk
    end
  
    def ConfigureCommonProxyDuringUpgradefromOES2SP2(admin,password)

      cmd = Builtins.sformat(
              "/opt/novell/proxymgmt/bin/cp_retrieve_proxy_cred username" )

      exit = Convert.to_integer(SCR.Execute(path(".target.bash"), cmd))
      if exit != 0
        doProxy = Ops.get_string(NovellLDAP.Settings,"CONFIG_LDAP_DO_PROXY", "yes")
        Builtins.y2milestone("Edirectory.ProxyUserDialog:doProxy = %1", doProxy)
        do_proxy = true

        proxyName = ""
        proxyContext = ""

        # Compute the proxy user context if not already done.
        serverContext = NovellUtils.Nds2Ldap(
        Ops.get_string(Edirectory.EdirSettings,"CONFIG_EDIR_SERVER_CONTEXT",""))
        hostName = NovellUtils.GetHostname
        proxyName = Ops.add("cn=OESCommonProxy_", hostName)
        proxyContext = serverContext
        proxyPassword = NovellUtils.GenerateRandomPassword # generate a random password between 20 and 50 characters
        proxyPassword2 = proxyPassword
        originalPassword = proxyPassword

        assignPolicy = Ops.get_string(NovellLDAP.Settings,"CONFIG_LDAP_ASSIGN_POLICY","yes")

        assignPolicy = "yes" if assignPolicy == nil || assignPolicy == ""

        assign_policy = false
        assign_policy = true if assignPolicy == "yes"

        Ops.set(NovellLDAP.Settings,"CONFIG_LDAP_PROXY_CONTEXT",
        Ops.add(Ops.add(proxyName, ","), proxyContext))
        Ops.set(NovellLDAP.Settings,"CONFIG_LDAP_PROXY_PASSWORD", proxyPassword)

        Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_ASSIGN_POLICY", assignPolicy)
        Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_DO_PROXY", "yes")

        stepOK = ConfigureProxyUser(admin, password)
        Builtins.y2milestone("Common Proxy created status : %1",stepOK)
        Ops.set(NovellLDAP.Settings,"CONFIG_LDAP_DO_PROXY", "yes")
      end
    stepOK
    end

    def ConfigureProxyUser(admin, adminPassword)
      ip = ""
      sPort = -1
      exit = true
      moveOn = true

      if NovellPatterns.IsPatternInstalled("novell-edirectory")
        local_server = Ops.get(NovellLDAP.GetLocalServers(nil), 0, {})
        sPort = Ops.get_integer(local_server, "CONFIG_LDAP_SECURE_PORT", 636)
        ip = Ops.get_string(local_server, "CONFIG_LDAP_SERVER_IP", "")
      else
        ip = Ops.get_string(NovellLDAP.Settings,"CONFIG_LDAP_REMOTE_SERVER_IP","")
        sPort = Ops.get_integer(NovellLDAP.Settings, "CONFIG_LDAP_SECURE_PORT", 636)
      end

      proxyUser = NovellUtils.Nds2Ldap(
        Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_PROXY_CONTEXT", "")
      )
      proxyPassword = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_PROXY_PASSWORD",
        ""
      )
      admin = NovellUtils.Nds2Ldap(admin)
      assign_policy = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ASSIGN_POLICY",
        "yes"
      )

      Popup.ShowFeedback(
        _("Configuring Common Proxy User"),
        _("This may take a while")
      )

      if assign_policy == "yes"
        ret2 = NovellUtils.CreateProxyPolicy(
          admin,
          adminPassword,
          ip,
          sPort,
          proxyPassword
        )
        if ret2 != 0
          Popup.Message(
            Builtins.sformat(
              _("Error creating password policy for Common Proxy User: %1"),
              ret2
            )
          )
        end
      end

      ret = NovellUtils.CreateOESProxyUser(
        proxyUser,
        proxyPassword,
        admin,
        adminPassword,
        ip,
        sPort,
        assign_policy
      )
      if ret != 0
        moveOn = false
        if ret == 19 || ret == 80 # password policy violation
          if Ops.get_string(
              @EdirSettings,
              "CONFIG_EDIR_USER_ENTERED_PASSWORD",
              "no"
            ) == "yes"
            Builtins.y2milestone(
              "Edirectory.ConfigureProxyUser:User entered password not compliant with password policy."
            )
            while moveOn != true
              userPwd = NovellLDAPUI.CommonProxyPasswordDialog
              break if userPwd.nil?
              proxyPassword = userPwd
              Ops.set(
                NovellLDAP.Settings,
                "CONFIG_LDAP_PROXY_PASSWORD",
                proxyPassword
              )
              Builtins.y2milestone(
                "Edirectory.ConfigureProxyUser:We have obtained a policy compliant password from user"
              )
              ret = NovellUtils.CreateOESProxyUser(
                proxyUser,
                proxyPassword,
                admin,
                adminPassword,
                ip,
                sPort,
                assign_policy
              )
              if ret == 0
                moveOn = true
                break
              elsif ret != 19 && ret != 80
                break
              end
            end
          else
            # Get a policy compliant password
            proxy_context = Builtins.substring(
              proxyUser,
              Ops.add(Builtins.find(proxyUser, ","), 1),
              Ops.subtract(Builtins.size(proxyUser), 1)
            )
            newPwd = NovellUtils.RetrievePolicyPassword(
              ip,
              sPort,
              admin,
              adminPassword,
              proxy_context
            )
            if newPwd != nil && newPwd != ""
              proxyPassword = newPwd
              Ops.set(
                NovellLDAP.Settings,
                "CONFIG_LDAP_PROXY_PASSWORD",
                proxyPassword
              )
              Builtins.y2milestone(
                "Edirectory.ConfigureProxyUser:We have obtained a policy compliant random password. Ret = %1",
                ret
              )
              ret = NovellUtils.CreateOESProxyUser(
                proxyUser,
                proxyPassword,
                admin,
                adminPassword,
                ip,
                sPort,
                assign_policy
              )
              moveOn = true if ret == 0
            end
          end
        end
      end

      if moveOn == false
        Popup.Message(
          Builtins.sformat(_("Error creating Common Proxy User: %1"), ret)
        )
        Builtins.y2milestone(
          "Edirectory.ConfigureProxyUser:Error creating Common Proxy User: %1",
          ret
        )
      end

      if moveOn
        ret = NovellUtils.StoreCredsInOCS(proxyUser, proxyPassword)
        if ret != 0
          Popup.Message(
            Builtins.sformat(
              _("Error storing credentials in OCS for Common Proxy User: %1"),
              ret
            )
          )
          Builtins.y2milestone(
            "Edirectory.ConfigureProxyUser:Error storing credentials in OCS for common Proxy User: %1",
            ret
          )
        end
        NovellUtils.ProxyAddToCrontab
      end

      Popup.ClearFeedback

      exit = false if ret != 0

      exit
    end

    # Write all edirectory settings
    #
    # Return values
    #
    #     `next - go on to the next step in the control flow
    def Write
      # Initialzie upgrade to FALSE
      upgrade = false
      Builtins.y2milestone("Begin Edirectory::Write()")
      edir_pattern = "novell-edirectory"

      if NovellPatterns.IsPatternInstalled(edir_pattern) == false
        Builtins.y2milestone(
          "The required pattern, %1, is not installed.",
          edir_pattern
        )
        if Mode.normal
          Report.Error(
            Builtins.sformat(
              _(
                "Configuration aborted. Install the required %1 pattern and try again."
              ),
              edir_pattern
            )
          )
        end
        return :next
      end

      if Ops.get_string(@EdirSettings, "DoConfiguration", "") != "DoIT" ||
          !Ops.get(NovellAddonInstall.products_to_configure, "edirectory", true)
        Builtins.y2milestone(
          "Edirectory:write: do config:%1, products_to_configure: %2",
          Ops.get_string(@EdirSettings, "DoConfiguration", ""),
          Ops.get(NovellAddonInstall.products_to_configure, "edirectory", true)
        )
        return :next
      end

      upgrade = true if @dibExists

      if Mode.autoinst
        if Ops.get_string(
            @EdirSettings,
            "CONFIG_EDIR_CONFIGURE_UNIVERSALSTORE",
            ""
          ) == "yes"
          cmd = "grep  'export*NDSD_TRY_NMASLOGIN_FIRST.*=.*' /opt/novell/eDirectory/sbin/pre_ndsd_start > /dev/null"
          rval = Convert.to_integer(SCR.Execute(path(".target.bash"), cmd))
          if rval != 0
            cmd = "echo export NDSD_TRY_NMASLOGIN_FIRST=true >>  /opt/novell/eDirectory/sbin/pre_ndsd_start"
            rval2 = Convert.to_integer(SCR.Execute(path(".target.bash"), cmd))
            Builtins.y2milestone(
              "Edirectory: executing cmd: %1  rval: %2",
              cmd,
              rval2
            )
            if rval2 != 0
              Builtins.y2milestone(
                "Failed to add 'NDSD_TRY_NMASLOGIN_FIRST=true' to /opt/novell/eDirectory/sbin/pre_ndsd_start file"
              )
            end
          end
        end
      end

      #1116991 #1119489
      #Log message required for CDC installation in mixed mode scenario(For AutoyastUpgrade AutoyastInstall)
      if NovellPatterns.IsPatternInstalled("novell-domain-services") == true
        if Mode.autoupgrade
               Builtins.y2milestone(
                   "All Domain Controllers must have the same version of OES. After upgrading this Domain Controller, ensure to upgrade all the other Domain Controllers in this domain and in other domains to the same version of OES."
               )
        elsif Mode.autoinst
               Builtins.y2milestone(
                   "Forest Root Domain Controller must have the same version of OES as the Child Domain Controller or Additional Domain Controller. To continue with the installation, upgrade all the Domain Controllers to the same version of OES and retry this installation."
               )
        end
      end

      # Edirectory read dialog caption
      caption = _("Perform eDirectory Configuration")

      sl = 50
      Builtins.sleep(sl)

      stages = []
      all_stages = [
        _("Configure the firewall for directory services"), ##1
        _("Perform time synchronization"), ##2
        _("Configure and start the Service Location Protocol"), ##3
        _("Copy the NICI Foundation Key file"), ##4
        _("Check for conflicting objects in the directory"), ##5
        _("Establish eDirectory on all static IP addresses"), ##6
        _("Tune eDirectory for OES services"), ##7
        _("Configure and start eDirectory using \"ndsconfig\""), ##8
        _("Wait for eDirectory to respond to LDAP requests"), ##9
        _("Enable eDirectory to start on reboot"), ##10
#        _("Fetch the eDirectory tree root certificate"), ##11
        _("Perform OES schema extension"), ##12
        _("Configure the NMAS login methods"), ##13
        _("Configure OES Common Proxy User")
      ] # This set is for a new install of eDirectory. ##14

      upgrade_mode_stages = [
        _("Save configuration information for YaST2"), ##1
        _("Configure the firewall for directory services"), ##2
        _("Perform time synchronization"), ##2
        _("Configure and start the Service Location Protocol"), ##3
        _("Copy the NICI Foundation Key file"), ##4
        _("Check for conflicting objects in the directory"), ##5
        _("Upgrade and start eDirectory using \"ndsconfig\""), ##8
        _("Wait for eDirectory to respond to LDAP requests"), ##9
        _("Enable eDirectory to start on reboot"), ##10
#        _("Fetch the eDirectory tree root certificate"), ##11
        _("Perform OES schema extension"), ##12
        _("Configure the NMAS login methods")
      ] # This set is for an OES 1.0 8.7 sles 9 to OES 2.0 8.8 sles 10 upgrade. ##13


      upgrade_stages = [
        _("Save configuration information for YaST2"), ##1
        _("Configure the firewall for directory services"), ##2
        _("Establish eDirectory on all static IP addresses"), ##6
        _("Tune eDirectory for OES services"), ##7
        _("Upgrade and Start eDirectory"), ##8
        _("Wait for eDirectory to respond to LDAP requests"), ##9
        _("Enable eDirectory to start on reboot"), ##10
#        _("Fetch the eDirectory tree root certificate"), ##11
        _("Perform OES schema extension"), ##12
        _("Configure the NMAS login methods")
      ] # This set is for a reinstall or minor upgrade of eDirectory. ##13

      stages = deep_copy(upgrade_stages) if upgrade
      if Mode.update || Mode.autoupgrade
        stages = deep_copy(upgrade_mode_stages)
        if Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
          stages = Builtins.add(
            upgrade_mode_stages,
            _("Upgrade Domain Services for Windows")
          )
        end # Step #15/#16
      else
        stages = deep_copy(all_stages)
        if Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
          if Ops.get_string(@EdirSettings, "XAD_CONFIG_DNS", "") == "yes"
            all_stages = Builtins.add(all_stages, _("Configure OES DNS"))
          end # Step #15

          stages = Builtins.add(
            all_stages,
            _("Configure Domain Services for Windows")
          ) # Step #15/#16
        end
      end

      steps = Builtins.size(stages)
      Builtins.y2milestone("Number of steps = %1", steps)
      Progress.New(
        caption,
        _("Perform eDirectory configuration"),
        steps,
        stages,
        stages,
        ""
      )

      stepOK = false
      err = ""

      # Call this or stage 1 information is skipped
      Progress.NextStage

      SCR.Write(path(".sysconfig.edirectory.SERVICE_CONFIGURED"), "no")

      if Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        if Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "") == "forest"
          Ops.set(
            @EdirSettings,
            "XAD_FOREST_ROOT",
            Ops.get_string(@EdirSettings, "XAD_DOMAIN_NAME", "")
          ) # forest root is same as Dns-Domain name if this is a new XAD forest
        end
      end

      # Step #1 - Set up eDir certs to be used for http services.
      overwriteCerts = Ops.get_string(
        @EdirSettings,
        "CONFIG_EDIR_OVERWRITE_CERT_FILES",
        "yes"
      )
      Builtins.y2milestone(
        "Edirectory::Write()-Step #1a:Do overwrite of cert files:%1",
        overwriteCerts
      )
      if Builtins.tolower(overwriteCerts) == "yes"
        bVal = SetupEdirCerts()
        Builtins.y2milestone(
          "Edirectory::Write()-SetupEdirCerts() return:%1",
          bVal
        )
      end

      if Mode.update || Mode.autoupgrade
        Progress.NextStage
      end

      # Step #15 - Open the correct firewall ports
      #
      stepOK = ConfigureFirewall()
      if !stepOK
        err = _("Failed to configure the firewall")
        Report.Warning(err)
      end
      Progress.NextStage
      Builtins.y2milestone(
        "Edirectory::Write()-Step #1 firewall configuration complete"
      )

      # When the dib does not exist THEN this state is not displayed
      if !Mode.update && !Mode.autoupgrade
        Progress.NextStage if upgrade
      end

      Builtins.y2milestone(
        "Edirectory::Write()-Step #1 Update /etc/sysconfig/novell complete"
      )

      # This group of steps only apply to the fresh install case and the oes 1.0 to oes 2.0 case and not
      # to the reinstall/upgrade case of the same version.
      if Mode.update || Mode.autoupgrade || upgrade == false
        if Mode.autoinst
          Service.Restart("network") # FIXME: this may not be a good idea...what about installing via ssh or vnc?
        end

        # Step #2
        timeServers = Ops.get_list(@EdirSettings, "CONFIG_EDIR_NTP_SERVERS", [])
        useLocalClock = Ops.get_string(
          @EdirSettings,
          "CONFIG_EDIR_NTP_USE_LOCAL_CLOCK",
          ""
        )
        stepOK = ConfigureAndStartNTP(timeServers, useLocalClock)

        if !stepOK
          err = Builtins.sformat(
            _("Error synchronizing time to %1"),
            timeServers
          )
          Builtins.y2milestone("Edirectory:%1", err)
          Report.Error(err)
        end
        # End Step #2
        Progress.NextStage
        Builtins.y2milestone("Edirectory::Write()-Step #2 Time Sync complete")

        # Step #3
        stepOK = ConfigureAndStartSLP()
        if !stepOK
          err = _("Error configuring and starting SLP")
          Report.Error(err)
        end
        # End Step #3
        Progress.NextStage
        Builtins.y2milestone(
          "Edirectory::Write()-Step #3 SLP services complete"
        )

        # Step #4
        stepOK = CopyNICIFK()
        if !stepOK
          err = _("Error while copying the NICI foundation key file.")
          Report.Error(err)
        end
        Progress.NextStage

        Builtins.y2milestone("Edirectory::Write()-Step #4 NICIFK file complete")
        # Determine if an object already exists at the proposed location
        # for the new server object (applies only in the existing tree case
        # If the object exists offer to remove it before continuing
        # Step #5
        state = :next
        if !Mode.update && !Mode.autoupgrade
          state = CheckForConflictingObjects()
        end
        return PerformEdirAbort() if state == :abort
        Progress.NextStage
        Builtins.y2milestone(
          "Edirectory::Write()-Step #5 Check for Conflicting Object"
        )
      end

      # Do these steps EVEN if the DIB exists
      # Step #6
      # Establish NCP on ALL static IP addresses (an OES feature)
      if !Mode.update && !Mode.autoupgrade
        configIP = ConfigIPAddresses()
        if configIP != 0
          # Silently log a FAILURE message
          Builtins.y2error(
            "ERROR: ConfigIPAddresses failed, the return code was %1, the command output is %2",
            configIP,
            @ndsConfigFailureMap
          )
        end
        Progress.NextStage
        Builtins.y2milestone(
          "Edirectory::Write()-Step #6 config IP addrs complete"
        )
      end
      Builtins.y2milestone("Edirectory::Write():ConfigIPAddresses complete.")

      # Step #7
      # Set measured tuning parameters
      if !Mode.update && !Mode.autoupgrade
        stepOK = setTuningParameters
        if !stepOK
          err = _("Error while setting eDirectory tuning parameters")
          Report.Error(err)
        end
        Progress.NextStage
        Builtins.y2milestone(
          "Edirectory::Write()-Step #7 Edirectory Tuned complete"
        )
      end

      #1115004
      if @xad_packages_installed
        if @upgrade_from == "OES11SP2" || @upgrade_from == "OES11SP3" || @upgrade_from == "OES2015" || @upgrade_from == "OES2015SP1"
            cmd = Builtins.sformat(
              "%1 set n4u.server.fips_tls=0 --config-file %2",
              @ndsconfig_bin,
              Ops.get_string(@EdirSettings,
                "CONFIG_EDIR_CONFIG_FILE",
                "/etc/opt/novell/eDirectory/conf/nds.conf")
            )
            Builtins.y2milestone(
                "NDSconfg command to set the value of n4u.server.fips_tls : '%1'",cmd)
            retval = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
            Builtins.y2milestone("retval = %1", retval)
        end
      end


      #Steps #8 - ConfigureAndStartEdirectory()
      #Steps #9 - WaitForEdirToComeUp()
      whatNext = ConfigureAndStartEdirectory(upgrade)
      if whatNext != :goon
        if whatNext == :channel_abort
          @ndsconfigWorked = false
          return :next
        end

        return whatNext if @xadTestMode == false
      end
      Builtins.y2milestone("Edirectory::Write() Edirectory Started complete")
      # set port 1636 and 1389 if we are doing an xad install (for iPrint, DNS, and DHCP).
      Set1636and1389forDSFW()

      # set ldapSSLConfig protocol to TLS1.2 only
      SetldapSSLConfig()

      # Adding Object Class to CachedAttrsOnExtRefs
      UpdateCachedAttributes()

      # Write /etc/sysconfig/novell files
      stepOK = SaveSysconfigFiles()
      if !stepOK
        err = "Error saving configuration information to /etc/sysconfig/novell"
        Report.Error(err)
      end

      # Step #10 - Enable eDirectory on reboot
      Service.Enable("ndsd")
      Builtins.sleep(sl)
      Progress.NextStage
      Builtins.y2milestone(
        "Edirectory::Write()-Step #10 eDir to restart complete"
      )

      # Step #11 - Fetch the Self Signed Tree CA certificate to a file
      # This step provided as a courtesy for OES services
#      if !SSRootCert()
#        err = _(
#          "Failed to acquire the self-signed certificate from the Tree Certificate Authority."
#        )
#        Report.Error(err)
#      end
      Progress.NextStage
      Builtins.y2milestone(
        "Edirectory::Write()-Step #11 SSCert extraction skipped as the certificate is created by eDirectory")

      # Step #12 - Extend Schema for OES
      # Should not be a problem if schema is already extended
      stepOK = ExtendSchema()
      Builtins.y2error("ERROR: One or more schema updates failed") if !stepOK
      Progress.NextStage
      Builtins.y2milestone(
        "Edirectory::Write()-Step #12 Schema Update complete"
      )

      admin = NovellUtils.Ldap2Nds(
        Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_CONTEXT", "")
      )
      password = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_PASSWORD",
        ""
      )
      if Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        admin = NovellUtils.Ldap2Nds(
          Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
        )
        if Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "existing"
          password = Ops.get_string(
            @EdirSettings,
            "XAD_LDAP_ADMIN_PASSWORD",
            ""
          )
        end
      end
      tree = Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_TREE_NAME", "")
      stepOK = ConfigureNMASLogin(admin, tree, password)
      Builtins.y2milestone("Edirectory::Write:ConfigureNMASLogin complete.")
      if !stepOK
        err = _("Failed to configure one or more NMAS login methods")
        Builtins.y2error(
          "eDir:Failed to configure one or more NMAS login methods."
        )
      end

      progress_orig = Progress.set(false)
      Ops.set(
        NovellLDAP.Settings,
        "CONFIG_COMMON_PROXY_CONTEXT",
        Ops.get_string(@EdirSettings, "CONFIG_EDIR_SERVER_CONTEXT", "")
      )
      NovellLDAP.Write

      Progress.set(progress_orig)

      Progress.NextStage
      # Step 13/15 - configure common OES proxy user if required
      doProxy = Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_DO_PROXY", "")
      Builtins.y2milestone("Edirectory.Write:doProxy = %1", doProxy)

      if !Mode.update && !Mode.autoupgrade &&
          upgrade == false &&
          doProxy == "yes"
        stepOK = ConfigureProxyUser(admin, password)
        Builtins.y2milestone("EDIR::configure proxy user")
        if !stepOK
          err = _(
            "Failed to configure OES Common Proxy User. Aborting the OES Install."
          )
          Builtins.y2error(err)
          return PerformEdirAbort() if @xadTestMode == false # Abort the OES Install
        end
      end

      doProxy = Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_DO_PROXY", "yes")

      if (Mode.update || Mode.autoupgrade) &&
          doProxy == "yes"

          Builtins.y2milestone(
            "eDirectory:common proxy during upgrade,
            upgradeFrom = #{@upgrade_from},
            doProxy = #{doProxy}"
          )

          admin = NovellUtils.Nds2Ldap(admin)
          proxyUser = NovellUtils.Nds2Ldap(
           Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_PROXY_CONTEXT", "")
           )

          local_server = Ops.get(NovellLDAP.GetLocalServers(nil), 0, {})
          sPort = Ops.get_integer(local_server, "CONFIG_LDAP_SECURE_PORT", 636)
          ip = Ops.get_string(local_server, "CONFIG_LDAP_SERVER_IP", "")

          cp_search="/usr/bin/ldapsearch -LLL -H ldaps://#{ip}:636 -D #{admin} -b #{proxyUser} dn"
          exit = Convert.to_integer(SCR.Execute(path(".target.bash"), cp_search))
          Builtins.y2milestone("Running ldapsearch for common proxy user #{proxyUser} and exit value is : #{exit}") 
          if exit != 0 && proxyUser == "" 
            stepOK = ConfigureCommonProxyDuringUpgradefromOES2SP2(admin,password)
            if (!stepOK)
             Builtins.sformat("Common proxy user creattion faised")
            end
          end

          proxyUser = NovellUtils.Nds2Ldap(
            Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_PROXY_CONTEXT", "")
            )
          cmd = Builtins.sformat(
             "'/opt/novell/proxymgmt/bin/change_pwd_upgrade.sh' -u '%1' -p '%2'",
             proxyUser, 
             admin,
          )
          Builtins.sformat("Edirectory: Setting common proxy password during upgrade")
          cmd = Ops.add(Ops.add(Ops.add("OES_DATA='",password ), "' "), cmd)

          val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
          exit = Ops.get_integer(val, "exit", -1)
          stdout = Ops.get_string(val, "stdout", "")
          Builtins.y2milestone(
            "Edirectory:Storing common proxy details :returned:%1, with stdout:\n%2",
            val,
            stdout
          )

          proxyPassword = NovellUtils.RetrieveProxyCredentials("password")
          Ops.set(
            NovellLDAP.Settings,
            "CONFIG_LDAP_PROXY_PASSWORD",
	    proxyPassword            
          )

          if  Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes" && Ops.get_string(@EdirSettings, "XAD_CONFIG_DNS", "") == "yes"
            Builtins.y2milestone("NovellDns:Setting commonproxy username and password during upgrade")
            proxyPassword = NovellUtils.RetrieveProxyCredentials("password")

            ret = NovellUtils.StoreCredsInOCSforUpgrade(proxyUser, proxyPassword,"dns-ldap")
            if ret != 0
              Popup.Message(
              Builtins.sformat(_("Error storing credentials in OCS for Common Proxy User: %1"), ret ))
              Builtins.y2milestone(
              "Novell-dns.ConfigureProxyUser:Error storing credentials in OCS for common Proxy User: %1", ret)
            end
          end
      NovellLDAP.Write
      end

      # Step 15 - Configure Novell DNS if required
      dnsStepOk = true
      if !Mode.update && !Mode.autoupgrade &&
          upgrade == false &&
          Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        if Ops.get_string(@EdirSettings, "XAD_CONFIG_DNS", "") == "yes"
          Progress.NextStage
          dnsStepOk = ConfigureDNS()
          if !dnsStepOk
            Builtins.y2error(
              "eDirectory::Write() - Failed to configure DNS (XAD)"
            )
            errMsg = _("OES DNS failed to configure.")
            Popup.Message(errMsg)
          end
        end
      end
      if Mode.update || Mode.autoupgrade ||
          upgrade == true ||
          Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        if Ops.get_string(@EdirSettings, "XAD_CONFIG_DNS", "") == "yes"
          SCR.Write(
            path(".sysconfig.novell-dns.CONFIG_DNS_LDAP_SERVER"),
            Builtins.sformat(
              "%1",
              Ops.get_string(@DnsSettings, "CONFIG_DNS_LDAP_SERVER", "")
            )
          )
          SCR.Write(
            path(".sysconfig.novell-dns.CONFIG_DNS_LDAP_BASEDN"),
            NovellUtils.Nds2Ldap(
              Ops.get_string(@DnsSettings, "CONFIG_DNS_LDAP_BASEDN", "")
            )
          )
          SCR.Write(
            path(".sysconfig.novell-dns.CONFIG_DNS_SERVER_CONTEXT"),
            Ops.get_string(@DnsSettings, "CONFIG_DNS_SERVER_CONTEXT", "")
          )
          SCR.Write(
            path(".sysconfig.novell-dns.CONFIG_DNS_LOCATOR_CONTEXT"),
            NovellUtils.Nds2Ldap(
              Ops.get_string(@DnsSettings, "CONFIG_DNS_LOCATOR_CONTEXT", "")
            )
          )
          SCR.Write(
            path(".sysconfig.novell-dns.CONFIG_DNS_GROUP_CONTEXT"),
            NovellUtils.Nds2Ldap(
              Ops.get_string(@DnsSettings, "CONFIG_DNS_GROUP_CONTEXT", "")
            )
          )
          SCR.Write(
            path(".sysconfig.novell-dns.CONFIG_DNS_USE_SECURE_PORT"),
            Ops.get_string(@DnsSettings, "CONFIG_DNS_USE_SECURE_PORT", "yes")
          )
          SCR.Write(
            path(".sysconfig.novell-dns.CONFIG_DNS_LDAP_USER_CONTEXT"),
            Ops.get_string(@DnsSettings, "CONFIG_DNS_LDAP_USER_CONTEXT", "")
          )
          SCR.Write(
            path(".sysconfig.novell-dns.CONFIG_DNS_CREATE_SERVER_OBJECT"),
            Ops.get_string(
              @DnsSettings,
              "CONFIG_DNS_CREATE_SERVER_OBJECT",
              "no"
            )
          )
          SCR.Write(
            path(".sysconfig.novell-dns.CONFIG_DNS_HOST_NAME"),
            Ops.get_string(@DnsSettings, "CONFIG_DNS_HOST_NAME", "")
          )
          SCR.Write(
            path(".sysconfig.novell-dns.CONFIG_DNS_DOMAIN_NAME"),
            Ops.get_string(@DnsSettings, "CONFIG_DNS_DOMAIN_NAME", "")
          )
          SCR.Write(
            path(".sysconfig.novell-dns.CONFIG_DNS_STORE_CREDENTIAL_IN_OCS"),
            Ops.get_string(
              @DnsSettings,
              "CONFIG_DNS_STORE_CREDENTIAL_IN_OCS",
              "yes"
            )
          )
          SCR.Write(
            path(".sysconfig.novell-dns.CONFIG_DNS_GET_CONTEXT_FROM_EXISTING"),
            Ops.get_string(
              @DnsSettings,
              "CONFIG_DNS_GET_CONTEXT_FROM_EXISTING",
              ""
            )
          )
          SCR.Write(
            path(".sysconfig.novell-dns.CONFIG_DNS_EXISTING_DNS_IP"),
            Ops.get_string(@DnsSettings, "CONFIG_DNS_EXISTING_DNS_IP", "")
          )
          SCR.Write(path(".sysconfig.novell-dns.SERVICE_CONFIGURED"), "yes")
          SCR.Write(
            path(".sysconfig.novell-dns.SERVICE_PREVIOUSLY_CONFIGURED"),
            "yes"
          )
          SCR.Write(path(".sysconfig.novell-dns"), nil)
        end
      end

      Progress.NextStage

      abortInstall = "no"
      # Step 16 - Configure/upgrade Domain Services for Windows (XAD)
      if Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        #        if( dnsStepOk )
        #	{
        # xad retry loop
        retryConfig = false
        while true
          Wizard.DisableAbortButton # Yast is single threaded so abort does not work during call to ndsdcinit.
          stepOK = ConfigureAndStartXad(retryConfig)
          return :abort if NovellUtils.channelUpgrade_abort
          Wizard.EnableAbortButton
          abortInstall = Builtins.tolower(
            NovellUtils.ReadOption("ABORT_OES_INSTALL")
          )
          if !stepOK
            break if abortInstall == "yes"
            doNdsdcinitRetry = Popup.AnyQuestion(
              _("Domain Services for Windows Configuration Failure"),
              _(
                "Domain Services for Windows has encountered an error during configuration.\nSelect Retry Configuration to try again."
              ),
              _("&Retry Configuration"),
              _("&Abort"),
              :focus_no
            )

            if doNdsdcinitRetry
              Builtins.y2milestone("xad:retrying ndsdcinit...")
              retryConfig = true
              next
            end
          end
          break
        end # end while loop

        if !stepOK
          Builtins.y2error(
            "eDirectory::Write() - Failed to configure Domain Services for Windows (XAD)"
          )
          if abortInstall == "yes"
            Builtins.y2error(
              "eDirectory::Write() - Aborting OES install due to DSFW admin creation error."
            )
          end
        end
        Progress.NextStage 
        #	}
        #	else
        #	{
        #            string errMsg = _("Novell DNS failed to configure. Setup of Domain Services for Windows cannot be done at this time.");
        #            Popup::Message( errMsg );
        #	    y2error( errMsg );
        #	}
      end
      Builtins.y2milestone(
        "EDIR::ConfigureAndStartXad after: %1",
        _("eDirectory Configuration - New or Existing Tree")
      )
      Progress.Finish

      Builtins.y2milestone("Edirectory:Write:complete.")

      if abortInstall != "yes"
        SCR.Write(path(".sysconfig.edirectory.SERVICE_CONFIGURED"), "yes")
        SCR.Write(path(".sysconfig.edirectory"), nil) # flush
      end

      :next
    end

    # Get all edirectory settings from the first parameter
    # (For use by autoinstallation.)
    # @param [Hash] settings The YCP structure to be imported.
    # @return [Boolean] True on success
    def Import(settings)
      settings = deep_copy(settings)
      if settings == {}
        @globals_configured = false
        Ops.set(NovellAddonInstall.products_to_configure, "edirectory", false)
        return true
      end

      # Read tree type - as set by the user
      Ops.set(
        @EdirSettings,
        "CONFIG_EDIR_TREE_TYPE",
        Ops.get_string(settings, "tree_type", "")
      )

      # Read in or default the cert file overwrite option.
      Ops.set(
        @EdirSettings,
        "CONFIG_EDIR_OVERWRITE_CERT_FILES",
        Ops.get_string(settings, "overwrite_cert_files", "")
      )
      if Ops.get_string(@EdirSettings, "CONFIG_EDIR_OVERWRITE_CERT_FILES", "") == nil ||
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_OVERWRITE_CERT_FILES", "") == ""
        Ops.set(@EdirSettings, "CONFIG_EDIR_OVERWRITE_CERT_FILES", "yes")
      end

      # Read in "Require TLS for Simple Binds with Password" value
      Ops.set(
        @EdirSettings,
        "CONFIG_EDIR_TLS_FOR_SIMPLE_BINDS",
        Ops.get_string(settings, "tls_for_simple_binds", "")
      )
      if Ops.get_string(@EdirSettings, "CONFIG_EDIR_TLS_FOR_SIMPLE_BINDS", "") == nil ||
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_TLS_FOR_SIMPLE_BINDS", "") == ""
        Ops.set(@EdirSettings, "CONFIG_EDIR_TLS_FOR_SIMPLE_BINDS", "yes")
      end

      # Read in "Install SecretStore" value
      Ops.set(
        @EdirSettings,
        "CONFIG_EDIR_CONFIGURE_SECRETSTORE",
        Ops.get_string(settings, "install_secretstore", "")
      )
      if Ops.get_string(@EdirSettings, "CONFIG_EDIR_CONFIGURE_SECRETSTORE", "") == nil ||
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_CONFIGURE_SECRETSTORE", "") == ""
        Ops.set(@EdirSettings, "CONFIG_EDIR_CONFIGURE_SECRETSTORE", "yes")
      end

      # Read in "Install Universal password" value
      Ops.set(
        @EdirSettings,
        "CONFIG_EDIR_CONFIGURE_UNIVERSALSTORE",
        Ops.get_string(settings, "install_universalstore", "")
      )
      if Ops.get_string(
          @EdirSettings,
          "CONFIG_EDIR_CONFIGURE_UNIVERSALSTORE",
          ""
        ) == nil ||
          Ops.get_string(
            @EdirSettings,
            "CONFIG_EDIR_CONFIGURE_UNIVERSALSTORE",
            ""
          ) == ""
        Ops.set(@EdirSettings, "CONFIG_EDIR_CONFIGURE_UNIVERSALSTORE", "no")
      end

      # Domain services for windows (XAD)
      Ops.set(
        @EdirSettings,
        "XAD_PARENT_DOMAIN_ADDRESS",
        Ops.get_string(settings, "xad_parent_domain_address", "")
      )
      Ops.set(
        @EdirSettings,
        "XAD_SERVICE_CONFIGURED",
        Ops.get_string(settings, "xad_service_configured", "")
      )
      Ops.set(
        @EdirSettings,
        "XAD_DOMAIN_TYPE",
        Ops.get_string(settings, "xad_domain_type", "").downcase
      )
      Ops.set(
        @EdirSettings,
        "XAD_DOMAIN_NAME",
        Ops.get_string(settings, "xad_domain_name", "")
      )
      Ops.set(
        @EdirSettings,
        "XAD_CONFIG_DNS",
        Ops.get_string(settings, "xad_config_dns", "")
      )
      Ops.set(
        @EdirSettings,
        "XAD_WINS_SERVER",
        Ops.get_string(settings, "xad_wins_server", "")
      )
      Ops.set(
        @EdirSettings,
        "XAD_SITE_NAME",
        Ops.get_string(settings, "xad_site_name", "")
      )
      Ops.set(
        @EdirSettings,
        "XAD_NETBIOS",
        Ops.get_string(settings, "xad_netbios", "")
      )
      Ops.set(
        @EdirSettings,
        "XAD_FOREST_ROOT",
        Ops.get_string(settings, "xad_forest_root", "")
      )
      Ops.set(
        @EdirSettings,
        "XAD_PARENT_DOMAIN",
        Ops.get_string(settings, "xad_parent_domain", "")
      )
      Ops.set(
        @EdirSettings,
        "XAD_PARENT_DOMAIN_ADMIN_CONTEXT",
        Ops.get_string(settings, "xad_parent_domain_admin_context", "")
      )
      Ops.set(
        @EdirSettings,
        "XAD_PARENT_DOMAIN_ADMIN_PASSWORD",
        Ops.get_string(settings, "xad_parent_domain_admin_password", "")
      )
      Ops.set(
        @EdirSettings,
        "XAD_CONVERT_EXISTING_CONTAINER",
        Ops.get_string(settings, "xad_convert_existing_container", "")
      )
      Ops.set(
        @EdirSettings,
        "XAD_EXISTING_CONTAINER",
        Ops.get_string(settings, "xad_existing_container", "")
      )
      Ops.set(
        @EdirSettings,
        "XAD_REPLICATE_PARTITIONS",
        Ops.get_string(settings, "xad_replicate_partitions", "")
      )
      Ops.set(
        @EdirSettings,
        "XAD_LDAP_ADMIN_PASSWORD",
        Ops.get_string(settings, "xad_ldap_admin_password", "")
      )
      Ops.set(
        @EdirSettings,
        "XAD_ADMIN_PASSWORD",
        Ops.get_string(settings, "xad_admin_password", "")
      )
      Ops.set(
        @EdirSettings,
        "XAD_LDAP_ADMIN_CONTEXT",
        Ops.get_string(settings, "xad_ldap_admin_context", "")
      )
      Ops.set(
        @EdirSettings,
        "XAD_RETAIN_POLICIES",
        Ops.get_string(settings, "xad_retain_policies", "")
      )

      Ops.set(
        @DnsSettings,
        "CONFIG_DNS_LDAP_BASEDN",
        Ops.get_string(settings, "ldap_basedn", "")
      )
      Ops.set(
        @DnsSettings,
        "CONFIG_DNS_LOCATOR_CONTEXT",
        Ops.get_string(settings, "locator_context", "")
      )
      Ops.set(
        @DnsSettings,
        "CONFIG_DNS_GROUP_CONTEXT",
        Ops.get_string(settings, "group_context", "")
      )
      Ops.set(
        @DnsSettings,
        "CONFIG_DNS_LDAP_USER_CONTEXT",
        Ops.get_string(settings, "runtime_admin", "")
      )
      Ops.set(
        @DnsSettings,
        "CONFIG_DNS_LDAP_USER_PASSWORD",
        Ops.get_string(settings, "runtime_admin_password", "")
      )
      Ops.set(
        @DnsSettings,
        "CONFIG_DNS_LDAP_SERVER",
        Ops.get_string(settings, "ldap_server", "")
      )
      Ops.set(
        @DnsSettings,
        "CONFIG_DNS_SERVER_CONTEXT",
        Ops.get_string(settings, "server_context", "")
      )
      Ops.set(
        @DnsSettings,
        "CONFIG_DNS_USE_SECURE_PORT",
        Ops.get_string(settings, "use_secure_port", "yes")
      )
      Ops.set(
        @DnsSettings,
        "CONFIG_DNS_HOST_NAME",
        Ops.get_string(settings, "host_name", "")
      )
      Ops.set(
        @DnsSettings,
        "CONFIG_DNS_DOMAIN_NAME",
        Ops.get_string(settings, "domain_name", "")
      )
      Ops.set(
        @DnsSettings,
        "CONFIG_DNS_EXISTING_DNS_IP",
        Ops.get_string(settings, "existing_dns_ip", "")
      )
      Ops.set(
        @DnsSettings,
        "CONFIG_DNS_SERVER_OBJECT",
        Ops.get_string(settings, "server_object", "")
      )
      Ops.set(
        @DnsSettings,
        "CONFIG_DNS_CREATE_SERVER_OBJECT",
        Ops.get_string(settings, "create_server_object", "yes")
      )
      Ops.set(
        @DnsSettings,
        "CONFIG_DNS_STORE_CREDENTIAL_IN_OCS",
        Ops.get_string(settings, "ocs_store", "yes")
      )

      # Contexts and Password
      Ops.set(
        @EdirSettings,
        "CONFIG_EDIR_SERVER_CONTEXT",
        NovellUtils.Ldap2Nds(Ops.get_string(settings, "server_context", ""))
      )

      # Migrate Option
      Ops.set(
        @EdirSettings,
        "CONFIG_EDIR_MIGRATE_OPTION",
        Ops.get_string(settings, "migrate_option", "no")
      )

      # Dib location
      Ops.set(
        @EdirSettings,
        "CONFIG_EDIR_DIB_LOCATION",
        Ops.get_string(
          settings,
          "dib_location",
          "/var/opt/novell/eDirectory/data/dib"
        )
      )

      # iMonitor ports
      Ops.set(
        @EdirSettings,
        "CONFIG_EDIR_HTTP_PORT",
        Ops.get_integer(settings, "http_port", 8028)
      )
      Ops.set(
        @EdirSettings,
        "CONFIG_EDIR_HTTPS_PORT",
        Ops.get_integer(settings, "https_port", 8030)
      )

      if Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "existing"
        Ops.set(
          @EdirSettings,
          "CONFIG_EDIR_REPLICA_SERVER",
          Ops.get_string(settings, "replica_server", "")
        )
      end

      workList = Ops.get_list(settings, "ntp_server_list", [])
      # See if we have any ntp servers in the standard OES 11 tag
      if workList == nil || workList == []
        # Check for patched OES 2 sp3 tag
        workList = Ops.get_list(settings, "ntp_server", [])
        if workList == nil || workList == []
          # Next, check for the old style tag for a single NTP server
          old_ntp_server = Ops.get_string(settings, "ntp_server", "")
          if old_ntp_server != nil && old_ntp_server != ""
            workList = Builtins.add(workList, old_ntp_server)
          end
        end
      end

      # Set the internal value for the NTP server to use
      # No longer defaulted to local or existing ip (#249973)
      if workList == []
        Ops.set(@EdirSettings, "CONFIG_EDIR_NTP_USE_LOCAL_CLOCK", "yes")
      end

      Ops.set(@EdirSettings, "CONFIG_EDIR_NTP_SERVERS", workList)

      # SLP settings
      Ops.set(
        @EdirSettings,
        "CONFIG_EDIR_SLP_MODE",
        Ops.get_string(settings, "slp_mode", "none")
      )
      Ops.set(
        @EdirSettings,
        "CONFIG_EDIR_SLP_DA",
        Ops.get_list(settings, "slp_da", [])
      )
      Ops.set(
        @EdirSettings,
        "CONFIG_EDIR_SLP_SCOPES",
        Ops.get_string(settings, "slp_scopes", "DEFAULT")
      )
      Ops.set(
        @EdirSettings,
        "CONFIG_EDIR_DASYNC",
        Ops.get_string(settings, "slp_dasync", "no")
      )
      Ops.set(
        @EdirSettings,
        "CONFIG_EDIR_SLP_BACKUP",
        Ops.get_string(settings, "slp_backup", "yes")
      )
      Ops.set(
        @EdirSettings,
        "CONFIG_EDIR_SLP_BACKUP_INTERVAL",
        Ops.get_string(settings, "slp_backup_interval", "900")
      )

      # NMAS Login Methods
      Ops.set(
        @EdirSettings,
        "CONFIG_EDIR_NMAS_CERTMUTUAL",
        Ops.get_string(settings, "cert_mutual", "no")
      )
      Ops.set(
        @EdirSettings,
        "CONFIG_EDIR_NMAS_CHLG_RESPONSE",
        Ops.get_string(settings, "challenge_response", "yes")
      )
      Ops.set(
        @EdirSettings,
        "CONFIG_EDIR_NMAS_DIGEST_MD5",
        Ops.get_string(settings, "digest_md5", "no")
      )
      Ops.set(
        @EdirSettings,
        "CONFIG_EDIR_NMAS_NDS",
        Ops.get_string(settings, "nds", "yes")
      )
      Ops.set(
        @EdirSettings,
        "CONFIG_EDIR_NMAS_SIMPWD",
        Ops.get_string(settings, "simple_password", "no")
      )
      Ops.set(
        @EdirSettings,
        "CONFIG_EDIR_NMAS_GSSAPI",
        Ops.get_string(settings, "sasl_gssapi", "no")
      )

      # Variables that must be set
      Ops.set(@EdirSettings, "DoConfiguration", "DoIT")

      @globals_configured = true
      true
    end

    # Dump the edirectory settings to a single map
    # (For use by autoinstallation.)
    # @return [Hash] Dumped settings (later acceptable by Import ())
    def Export
      v = {}

      return v if NovellUtils.CloneSettingstoAutoinstXml("novell-edirectory") == false

      Builtins.y2milestone(
        "edirectory.Export:Entering Export method. Config edir? - %1",
        Ops.get(NovellAddonInstall.products_to_configure, "edirectory", true)
      )
      if @auto_clone
        Ops.set(NovellAddonInstall.products_to_configure, "edirectory", true)
        Builtins.y2milestone(
          "edirectory.Export:Entering Export method. Config edir? - %1",
          Ops.get(NovellAddonInstall.products_to_configure, "edirectory", true)
        )
      end
      if Ops.get(NovellAddonInstall.products_to_configure, "edirectory", true)
        # tree type
        Ops.set(
          v,
          "tree_type",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "")
        )

        # Write out or default the cert file overwrite option.
        Ops.set(
          v,
          "overwrite_cert_files",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_OVERWRITE_CERT_FILES", "")
        )
        if Ops.get_string(v, "overwrite_cert_files", "") == nil ||
            Ops.get_string(v, "overwrite_cert_files", "") == ""
          Ops.set(v, "overwrite_cert_files", "yes")
        end

        # Write out the "Require TLS for Simple Binds with Password" value.
        Ops.set(
          v,
          "tls_for_simple_binds",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_TLS_FOR_SIMPLE_BINDS", "")
        )
        if Ops.get_string(v, "tls_for_simple_binds", "") == nil ||
            Ops.get_string(v, "tls_for_simple_binds", "") == ""
          Ops.set(v, "tls_for_simple_binds", "yes")
        end

        # Write out the "Install SecretStore" value.
        Ops.set(
          v,
          "install_secretstore",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_CONFIGURE_SECRETSTORE", "")
        )
        if Ops.get_string(v, "install_secretstore", "") == nil ||
            Ops.get_string(v, "install_secretstore", "") == ""
          Ops.set(v, "install_secretstore", "yes")
        end

        # Write out the "Install Universal password" value.
        Ops.set(
          v,
          "install_universalstore",
          Ops.get_string(
            @EdirSettings,
            "CONFIG_EDIR_CONFIGURE_UNIVERSALSTORE",
            ""
          )
        )
        if Ops.get_string(v, "install_universalstore", "") == nil ||
            Ops.get_string(v, "install_universalstore", "") == ""
          Ops.set(v, "install_universalstore", "no")
        end

        # Domain Services for Windows (XAD)
        Ops.set(
          v,
          "xad_parent_domain_address",
          Ops.get_string(@EdirSettings, "XAD_PARENT_DOMAIN_ADDRESS", "")
        )
        Ops.set(
          v,
          "xad_service_configured",
          Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "")
        )
        Ops.set(
          v,
          "xad_domain_type",
          Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "")
        )
        Ops.set(
          v,
          "xad_domain_name",
          Ops.get_string(@EdirSettings, "XAD_DOMAIN_NAME", "")
        )
        Ops.set(
          v,
          "xad_config_dns",
          Ops.get_string(@EdirSettings, "XAD_CONFIG_DNS", "")
        )
        Ops.set(
          v,
          "xad_wins_server",
          Ops.get_string(@EdirSettings, "XAD_WINS_SERVER", "")
        )
        Ops.set(
          v,
          "xad_site_name",
          Ops.get_string(@EdirSettings, "XAD_SITE_NAME", "")
        )
        Ops.set(
          v,
          "xad_netbios",
          Ops.get_string(@EdirSettings, "XAD_NETBIOS", "")
        )
        Ops.set(
          v,
          "xad_forest_root",
          Ops.get_string(@EdirSettings, "XAD_FOREST_ROOT", "")
        )
        Ops.set(
          v,
          "xad_parent_domain",
          Ops.get_string(@EdirSettings, "XAD_PARENT_DOMAIN", "")
        )
        Ops.set(
          v,
          "xad_parent_domain_admin_context",
          Ops.get_string(@EdirSettings, "XAD_PARENT_DOMAIN_ADMIN_CONTEXT", "")
        )
        Ops.set(
          v,
          "xad_parent_domain_admin_password",
          NovellUtils.passwordMessage
        )
        Ops.set(
          v,
          "xad_convert_existing_container",
          Ops.get_string(@EdirSettings, "XAD_CONVERT_EXISTING_CONTAINER", "")
        )
        Ops.set(
          v,
          "xad_existing_container",
          Ops.get_string(@EdirSettings, "XAD_EXISTING_CONTAINER", "")
        )
        Ops.set(
          v,
          "xad_replicate_partitions",
          Ops.get_string(@EdirSettings, "XAD_REPLICATE_PARTITIONS", "")
        )
        Ops.set(v, "xad_ldap_admin_password", NovellUtils.passwordMessage)
        Ops.set(v, "xad_admin_password", NovellUtils.passwordMessage)

        if Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "new" &&
            Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "") == "forest"
          Ops.set(
            @EdirSettings,
            "XAD_LDAP_ADMIN_CONTEXT",
            Builtins.sformat(
              "cn=xad_provisioning_user.%1",
              NovellUtils.GetContextNDS(
                NovellUtils.GetContextNDS(
                  Ops.get_string(
                    NovellLDAP.Settings,
                    "CONFIG_LDAP_ADMIN_CONTEXT",
                    ""
                  )
                )
              )
            )
          )
        end

	#bug 1108405
        if Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "existing" &&
            Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "") =~ /^(forest|controller|domain)$/
          Ops.set( @EdirSettings, "XAD_LDAP_ADMIN_CONTEXT",
                 Ops.get_string( NovellLDAP.Settings, "XAD_TREE_ADMIN_CONTEXT", "" ) )
        end

        Ops.set(
          v,
          "xad_ldap_admin_context",
          Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
        )
        Ops.set(
          v,
          "xad_retain_policies",
          Ops.get_string(@EdirSettings, "XAD_RETAIN_POLICIES", "no")
        )

        Ops.set(
          v,
          "ldap_basedn",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_LDAP_BASEDN", "")
        )
        Ops.set(
          v,
          "locator_context",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_LOCATOR_CONTEXT", "")
        )
        Ops.set(
          v,
          "group_context",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_GROUP_CONTEXT", "")
        )
        Ops.set(
          v,
          "runtime_admin",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_LDAP_USER_CONTEXT", "")
        )
        Ops.set(v, "runtime_admin_password", NovellUtils.passwordMessage)
        Ops.set(
          v,
          "ldap_server",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_LDAP_SERVER", "")
        )
        Ops.set(
          v,
          "server_context",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_SERVER_CONTEXT", "")
        )
        Ops.set(
          v,
          "use_secure_port",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_USE_SECURE_PORT", "yes")
        )
        Ops.set(
          v,
          "create_server_object",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_CREATE_SERVER_OBJECT", "yes")
        )
        Ops.set(
          v,
          "host_name",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_HOST_NAME", "")
        )
        Ops.set(
          v,
          "domain_name",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_DOMAIN_NAME", "")
        )
        Ops.set(
          v,
          "existing_dns_ip",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_EXISTING_DNS_IP", "")
        )

        Ops.set(
          v,
          "ocs_store",
          Ops.get_string(
            @DnsSettings,
            "CONFIG_DNS_STORE_CREDENTIAL_IN_OCS",
            "yes"
          )
        )


        # Existing server information
        Ops.set(
          v,
          "replica_server",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_REPLICA_SERVER", "")
        )
        if Ops.get_string(v, "replica_server", "") == nil ||
            Ops.get_string(v, "replica_server", "") == ""
          Ops.set(
            v,
            "replica_server",
            Convert.to_string(
              SCR.Read(path(".sysconfig.edirectory.CONFIG_EDIR_REPLICA_SERVER"))
            )
          )
        end

        # Server context
        Ops.set(
          v,
          "server_context",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_SERVER_CONTEXT", "")
        )
        Ops.set(
          @DnsSettings,
          "CONFIG_DNS_SERVER_OBJECT",
          Builtins.sformat(
            "cn=DNS_edir-%1,%2",
            Ops.get_string(@DnsSettings, "CONFIG_DNS_HOST_NAME", ""),
            NovellUtils.Nds2Ldap(
              Ops.get_string(@EdirSettings, "CONFIG_EDIR_SERVER_CONTEXT", "")
            )
          )
        )
        Ops.set(
          v,
          "server_object",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_SERVER_OBJECT", "")
        )


        # Migrate Option
        Ops.set(
          v,
          "migrate_option",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_MIGRATE_OPTION", "no")
        )

        # DIB location
        Ops.set(
          v,
          "dib_location",
          Ops.get_string(
            @EdirSettings,
            "CONFIG_EDIR_DIB_LOCATION",
            "/var/opt/novell/eDirectory/data/dib"
          )
        )

        # Local Ports
        Ops.set(
          v,
          "http_port",
          Ops.get_integer(@EdirSettings, "CONFIG_EDIR_HTTP_PORT", -1)
        )
        Ops.set(
          v,
          "https_port",
          Ops.get_integer(@EdirSettings, "CONFIG_EDIR_HTTPS_PORT", -1)
        )

        # ntp server
        Ops.set(
          v,
          "ntp_server_list",
          Ops.get_list(@EdirSettings, "CONFIG_EDIR_NTP_SERVERS", [])
        )


        # SLP
        Ops.set(
          v,
          "slp_mode",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_SLP_MODE", "")
        )
        Ops.set(
          v,
          "slp_da",
          Ops.get_list(@EdirSettings, "CONFIG_EDIR_SLP_DA", [])
        )
        Ops.set(
          v,
          "slp_scopes",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_SLP_SCOPES", "")
        )
        Ops.set(
          v,
          "slp_dasync",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_DASYNC", "no")
        )
        Ops.set(
          v,
          "slp_backup",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_SLP_BACKUP", "yes")
        )
        Ops.set(
          v,
          "slp_backup_interval",
          Ops.get_string(
            @EdirSettings,
            "CONFIG_EDIR_SLP_BACKUP_INTERVAL",
            "900"
          )
        )

        # NMAS login methods
        Ops.set(
          v,
          "cert_mutual",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_NMAS_CERTMUTUAL", "no")
        )
        Ops.set(
          v,
          "challenge_response",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_NMAS_CHLG_RESPONSE", "yes")
        )
        Ops.set(
          v,
          "digest_md5",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_NMAS_DIGEST_MD5", "no")
        )
        Ops.set(
          v,
          "nds",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_NMAS_NDS", "yes")
        )
        Ops.set(
          v,
          "simple_password",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_NMAS_SIMPWD", "no")
        )
        Ops.set(
          v,
          "sasl_gssapi",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_NMAS_GSSAPI", "no")
        )
      else
        Builtins.y2milestone(
          "edirectory.Export:returning empty map because configured set to no."
        )
      end

      deep_copy(v)
    end

    # Dump all of the edirectory settings to a single map
    # (For use by autoinstallation.)
    # @return [Hash] Dumped settings (later acceptable by Import ())
    def ExportSettings
      v = {}

      return v if NovellUtils.CloneSettingstoAutoinstXml("novell-edirectory") == false

      if @auto_clone
        Ops.set(NovellAddonInstall.products_to_configure, "edirectory", true)
        Builtins.y2milestone(
          "edirectory.Export:Entering Export method. Config edir? - %1",
          Ops.get(NovellAddonInstall.products_to_configure, "edirectory", true)
        )
      end
      Builtins.y2milestone(
        "edirectory.Export:Entering Export method. Config edir? - %1",
        Ops.get(NovellAddonInstall.products_to_configure, "edirectory", true)
      )
      if Ops.get(NovellAddonInstall.products_to_configure, "edirectory", true)
        # tree type
        Ops.set(
          v,
          "tree_type",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "")
        )

        # Write out or default the cert file overwrite option.
        Ops.set(
          v,
          "overwrite_cert_files",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_OVERWRITE_CERT_FILES", "")
        )
        if Ops.get_string(v, "overwrite_cert_files", "") == nil ||
            Ops.get_string(v, "overwrite_cert_files", "") == ""
          Ops.set(v, "overwrite_cert_files", "yes")
        end

        # Write out the "Require TLS for Simple Binds with Password" value.
        Ops.set(
          v,
          "tls_for_simple_binds",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_TLS_FOR_SIMPLE_BINDS", "")
        )
        if Ops.get_string(v, "tls_for_simple_binds", "") == nil ||
            Ops.get_string(v, "tls_for_simple_binds", "") == ""
          Ops.set(v, "tls_for_simple_binds", "yes")
        end

        # Write out the "Install SecretStore" value.
        Ops.set(
          v,
          "install_secretstore",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_CONFIGURE_SECRETSTORE", "")
        )
        if Ops.get_string(v, "install_secretstore", "") == nil ||
            Ops.get_string(v, "install_secretstore", "") == ""
          Ops.set(v, "install_secretstore", "yes")
        end

        # Write out the "Install Universal password" value.
        Ops.set(
          v,
          "install_universalstore",
          Ops.get_string(
            @EdirSettings,
            "CONFIG_EDIR_CONFIGURE_UNIVERSALSTORE",
            ""
          )
        )
        if Ops.get_string(v, "install_universalstore", "") == nil ||
            Ops.get_string(v, "install_universalstore", "") == ""
          Ops.set(v, "install_universalstore", "no")
        end

        # Domain Services for Windows (XAD)
        Ops.set(
          v,
          "xad_parent_domain_address",
          Ops.get_string(@EdirSettings, "XAD_PARENT_DOMAIN_ADDRESS", "")
        )
        Ops.set(
          v,
          "xad_service_configured",
          Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "")
        )
        Ops.set(
          v,
          "xad_domain_type",
          Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "")
        )
        Ops.set(
          v,
          "xad_domain_name",
          Ops.get_string(@EdirSettings, "XAD_DOMAIN_NAME", "")
        )
        Ops.set(
          v,
          "xad_config_dns",
          Ops.get_string(@EdirSettings, "XAD_CONFIG_DNS", "")
        )
        Ops.set(
          v,
          "xad_wins_server",
          Ops.get_string(@EdirSettings, "XAD_WINS_SERVER", "")
        )
        Ops.set(
          v,
          "xad_site_name",
          Ops.get_string(@EdirSettings, "XAD_SITE_NAME", "")
        )
        Ops.set(
          v,
          "xad_netbios",
          Ops.get_string(@EdirSettings, "XAD_NETBIOS", "")
        )
        Ops.set(
          v,
          "xad_forest_root",
          Ops.get_string(@EdirSettings, "XAD_FOREST_ROOT", "")
        )
        Ops.set(
          v,
          "xad_parent_domain",
          Ops.get_string(@EdirSettings, "XAD_PARENT_DOMAIN", "")
        )
        Ops.set(
          v,
          "xad_parent_domain_admin_context",
          Ops.get_string(@EdirSettings, "XAD_PARENT_DOMAIN_ADMIN_CONTEXT", "")
        )
        Ops.set(
          v,
          "xad_parent_domain_admin_password",
          Ops.get_string(@EdirSettings, "XAD_PARENT_DOMAIN_ADMIN_PASSWORD", "")
        )
        Ops.set(
          v,
          "xad_convert_existing_container",
          Ops.get_string(@EdirSettings, "XAD_CONVERT_EXISTING_CONTAINER", "")
        )
        Ops.set(
          v,
          "xad_existing_container",
          Ops.get_string(@EdirSettings, "XAD_EXISTING_CONTAINER", "")
        )
        Ops.set(
          v,
          "xad_replicate_partitions",
          Ops.get_string(@EdirSettings, "XAD_REPLICATE_PARTITIONS", "")
        )
        Ops.set(
          v,
          "xad_ldap_admin_password",
          Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_PASSWORD", "")
        )
        Ops.set(
          v,
          "xad_admin_password",
          Ops.get_string(@EdirSettings, "XAD_ADMIN_PASSWORD", "")
        )

        if Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "new" &&
            Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "") == "forest"
          Ops.set(
            @EdirSettings,
            "XAD_LDAP_ADMIN_CONTEXT",
            Builtins.sformat(
              "cn=xad_provisioning_user.%1",
              NovellUtils.GetContextNDS(
                NovellUtils.GetContextNDS(
                  Ops.get_string(
                    NovellLDAP.Settings,
                    "CONFIG_LDAP_ADMIN_CONTEXT\n",
                    ""
                  )
                )
              )
            )
          )
        end

        Ops.set(
          v,
          "xad_ldap_admin_context",
          Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
        )
        Ops.set(
          v,
          "xad_retain_policies",
          Ops.get_string(@EdirSettings, "XAD_RETAIN_POLICIES", "no")
        )

        Ops.set(
          v,
          "ldap_basedn",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_LDAP_BASEDN", "")
        )
        Ops.set(
          v,
          "locator_context",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_LOCATOR_CONTEXT", "")
        )
        Ops.set(
          v,
          "group_context",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_GROUP_CONTEXT", "")
        )
        Ops.set(
          v,
          "runtime_admin",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_LDAP_USER_CONTEXT", "")
        )
        Ops.set(v, "runtime_admin_password", NovellUtils.passwordMessage)
        Ops.set(
          v,
          "ldap_server",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_LDAP_SERVER", "")
        )
        Ops.set(
          v,
          "server_context",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_SERVER_CONTEXT", "")
        )
        Ops.set(
          v,
          "use_secure_port",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_USE_SECURE_PORT", "yes")
        )
        Ops.set(
          v,
          "create_server_object",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_CREATE_SERVER_OBJECT", "yes")
        )
        Ops.set(
          v,
          "host_name",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_HOST_NAME", "")
        )
        Ops.set(
          v,
          "domain_name",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_DOMAIN_NAME", "")
        )
        Ops.set(
          v,
          "existing_dns_ip",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_EXISTING_DNS_IP", "")
        )
        Ops.set(
          v,
          "ocs_store",
          Ops.get_string(
            @DnsSettings,
            "CONFIG_DNS_STORE_CREDENTIAL_IN_OCS",
            "yes"
          )
        )

        # Existing server information
        Ops.set(
          v,
          "replica_server",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_REPLICA_SERVER", "")
        )
        if Ops.get_string(v, "replica_server", "") == nil ||
            Ops.get_string(v, "replica_server", "") == ""
          Ops.set(
            v,
            "replica_server",
            Convert.to_string(
              SCR.Read(path(".sysconfig.edirectory.CONFIG_EDIR_REPLICA_SERVER"))
            )
          )
        end

        # Server context
        Ops.set(
          v,
          "server_context",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_SERVER_CONTEXT", "")
        )

        Ops.set(
          @DnsSettings,
          "CONFIG_DNS_SERVER_OBJECT",
          Builtins.sformat(
            "cn=DNS_edir-%1,%2",
            Ops.get_string(@DnsSettings, "CONFIG_DNS_HOST_NAME", ""),
            NovellUtils.Nds2Ldap(
              Ops.get_string(@EdirSettings, "CONFIG_EDIR_SERVER_CONTEXT", "")
            )
          )
        )
        Ops.set(
          v,
          "server_object",
          Ops.get_string(@DnsSettings, "CONFIG_DNS_SERVER_OBJECT", "")
        )

        # Migrate Option
        Ops.set(
          v,
          "migrate_option",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_MIGRATE_OPTION", "no")
        )

        # DIB location
        Ops.set(
          v,
          "dib_location",
          Ops.get_string(
            @EdirSettings,
            "CONFIG_EDIR_DIB_LOCATION",
            "/var/opt/novell/eDirectory/data/dib"
          )
        )

        # Local Ports
        Ops.set(
          v,
          "http_port",
          Ops.get_integer(@EdirSettings, "CONFIG_EDIR_HTTP_PORT", -1)
        )
        Ops.set(
          v,
          "https_port",
          Ops.get_integer(@EdirSettings, "CONFIG_EDIR_HTTPS_PORT", -1)
        )

        # ntp server
        Ops.set(
          v,
          "ntp_server_list",
          Ops.get_list(@EdirSettings, "CONFIG_EDIR_NTP_SERVERS", [])
        )


        # SLP
        Ops.set(
          v,
          "slp_mode",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_SLP_MODE", "")
        )
        Ops.set(
          v,
          "slp_da",
          Ops.get_list(@EdirSettings, "CONFIG_EDIR_SLP_DA", [])
        )
        Ops.set(
          v,
          "slp_scopes",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_SLP_SCOPES", "")
        )
        Ops.set(
          v,
          "slp_dasync",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_DASYNC", "no")
        )
        Ops.set(
          v,
          "slp_backup",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_SLP_BACKUP", "yes")
        )
        Ops.set(
          v,
          "slp_backup_interval",
          Ops.get_string(
            @EdirSettings,
            "CONFIG_EDIR_SLP_BACKUP_INTERVAL",
            "900"
          )
        )

        # NMAS login methods
        Ops.set(
          v,
          "cert_mutual",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_NMAS_CERTMUTUAL", "no")
        )
        Ops.set(
          v,
          "challenge_response",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_NMAS_CHLG_RESPONSE", "yes")
        )
        Ops.set(
          v,
          "digest_md5",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_NMAS_DIGEST_MD5", "no")
        )
        Ops.set(
          v,
          "nds",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_NMAS_NDS", "yes")
        )
        Ops.set(
          v,
          "simple_password",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_NMAS_SIMPWD", "no")
        )
        Ops.set(
          v,
          "sasl_gssapi",
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_NMAS_GSSAPI", "no")
        )
      else
        Builtins.y2milestone(
          "edirectory.Export:returning empty map because configured set to no."
        )
      end

      deep_copy(v)
    end

    # Tranlate a new or existing string
    # @return translated "new" or "existing" string
    def Trans_new_exist(newexist)
      if Builtins.tolower(newexist) == "new"
        return _("new")
      else
        return _("existing")
      end
    end

    # Tranlate a slp mode string
    # @return translated "da", "multicast" or "none" string
    def Trans_slp_mode(slpmode)
      mode = Builtins.tolower(slpmode)
      if mode == "da"
        return _("directory agent")
      elsif mode == "multicast"
        return _("multicast")
      elsif mode == "da_server"
        return _("localhost")
      else
        return _("none")
      end
    end

    # Tranlate a yes or no string
    # @return translated "yes" or "no" string
    def Trans_yes_no(yesno)
      if Builtins.tolower(yesno) == "yes"
        return _("yes")
      else
        return _("no")
      end
    end

    # Create a textual summary and a list of unconfigured cards
    # @return summary of the current configuration
    def Summary

      summary = ""

      if !@globals_configured
        nc = Summary.NotConfigured
        summary = Summary.AddLine(summary, nc)
      else
        summary = Summary.OpenList(summary)

        if !Mode.update && !Mode.autoupgrade
          summary = Summary.AddListItem(
            summary,
            Builtins.sformat(
              _("Tree Name: %1"),
              Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_TREE_NAME", "")
            )
          )

          tree_type = Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "")

          summary = Summary.AddListItem(
            summary,
            Builtins.sformat(_("Tree Type: %1"), Trans_new_exist(tree_type))
          )

          summary = Summary.AddListItem(
            summary,
            Builtins.sformat(
              _("Use eDirectory certificates for HTTP services: %1"),
              Trans_yes_no(
                Ops.get_string(
                  @EdirSettings,
                  "CONFIG_EDIR_OVERWRITE_CERT_FILES",
                  ""
                )
              )
            )
          )

          summary = Summary.AddListItem(
            summary,
            Builtins.sformat(
              _("Require TLS for Simple Binds with Password: %1"),
              Trans_yes_no(
                Ops.get_string(
                  @EdirSettings,
                  "CONFIG_EDIR_TLS_FOR_SIMPLE_BINDS",
                  ""
                )
              )
            )
          )

          summary = Summary.AddListItem(
            summary,
            Builtins.sformat(
              _("Install SecretStore: %1"),
              Trans_yes_no(
                Ops.get_string(
                  @EdirSettings,
                  "CONFIG_EDIR_CONFIGURE_SECRETSTORE",
                  ""
                )
              )
            )
          )

          summary = Summary.AddListItem(
            summary,
            Builtins.sformat(
              _("Enable NMAS-based login for LDAP authentication: %1"),
              Trans_yes_no(
                Ops.get_string(
                  @EdirSettings,
                  "CONFIG_EDIR_CONFIGURE_UNIVERSALSTORE",
                  ""
                )
              )
            )
          )

          if tree_type == "existing"
            summary = Summary.AddListItem(
              summary,
              Builtins.sformat(
                _("Address of an existing server: %1"),
                Ops.get_string(@EdirSettings, "CONFIG_EDIR_REPLICA_SERVER", "")
              )
            )
          end

          # Domain Services for Windows (XAD)
          if @xad_packages_installed
            summary = Summary.AddListItem(
              summary,
              Builtins.sformat(
                _("Configure Domain Services for Windows: %1"),
                Trans_yes_no(
                  Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no")
                )
              )
            )
            if Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
              # Domain type
              domain_type = _("New forest")
              if Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "") == "domain"
                domain_type = _("New domain in an existing forest")
              elsif Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "") == "controller"
                domain_type = _("New domain controller in an existing domain")
              end
              summary = Summary.AddListItem(
                summary,
                Builtins.sformat(_("Domain type: %1"), domain_type)
              )

              # DNS domain name
              summary = Summary.AddListItem(
                summary,
                Builtins.sformat(
                  _("DNS name for new domain: %1"),
                  Ops.get_string(@EdirSettings, "XAD_DOMAIN_NAME", "")
                )
              )

              # Configure this machine to be a primary DNS server
              summary = Summary.AddListItem(
                summary,
                Builtins.sformat(
                  _("Configure this server to be a primary DNS server: %1"),
                  Trans_yes_no(
                    Ops.get_string(@EdirSettings, "XAD_CONFIG_DNS", "no")
                  )
                )
              )

              # Configure this machine with Wins Server
              summary = Summary.AddListItem(
                summary,
                Builtins.sformat(
                  _("Configure this server as a WINS Server: %1"),
                  Trans_yes_no(
                    Ops.get_string(@EdirSettings, "XAD_WINS_SERVER", "")
                  )
                )
              )

              # Configure this machine with Wins Server
              summary = Summary.AddListItem(
                summary,
                Builtins.sformat(
                  _("Site Name: %1"),
                  Ops.get_string(@EdirSettings, "XAD_SITE_NAME", "")
                )
              )

              # Domain NetBIOS
              if Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "") != "controller"
                summary = Summary.AddListItem(
                  summary,
                  Builtins.sformat(
                    _("Domain NetBIOS Name: %1"),
                    Ops.get_string(@EdirSettings, "XAD_NETBIOS", "")
                  )
                )
              end

              # Forest root
              if Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "") == "domain" ||
                  Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "") == "controller"
                summary = Summary.AddListItem(
                  summary,
                  Builtins.sformat(
                    _("Forest root domain: %1"),
                    Ops.get_string(@EdirSettings, "XAD_FOREST_ROOT", "")
                  )
                )
              end

              # Parent domain and parent domain admin DN
              if Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "") == "domain"
                summary = Summary.AddListItem(
                  summary,
                  Builtins.sformat(
                    _("Parent domain: %1"),
                    Ops.get_string(@EdirSettings, "XAD_PARENT_DOMAIN", "")
                  )
                )
                summary = Summary.AddListItem(
                  summary,
                  Builtins.sformat(
                    _("Parent domain administrator: %1"),
                    Ops.get_string(
                      @EdirSettings,
                      "XAD_PARENT_DOMAIN_ADMIN_CONTEXT",
                      ""
                    )
                  )
                )
              end

              # eDirectory Container/Partition to convert to an XAD domain (Name-Mapping)
              if tree_type == "existing" &&
                  (Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "") == "forest" ||
                    Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "") == "domain")
                summary = Summary.AddListItem(
                  summary,
                  Builtins.sformat(
                    _("Existing eDirectory admin: %1"),
                    Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
                  )
                )
                if Builtins.tolower(
                    Ops.get_string(
                      @EdirSettings,
                      "XAD_CONVERT_EXISTING_CONTAINER",
                      ""
                    )
                  ) != "no"
                  summary = Summary.AddListItem(
                    summary,
                    Builtins.sformat(
                      _(
                        "Existing eDirectory container to convert to a Domain Services for Windows container: %1"
                      ),
                      Ops.get_string(
                        @EdirSettings,
                        "XAD_EXISTING_CONTAINER",
                        ""
                      )
                    )
                  )
                  summary = Summary.AddListItem(
                    summary,
                    Builtins.sformat(
                      _("Retain existing Novell Password Policies on Users: %1"),
                      Trans_yes_no(
                        Ops.get_string(
                          @EdirSettings,
                          "XAD_RETAIN_POLICIES",
                          "no"
                        )
                      )
                    )
                  )
                end
              end
              # Replicate partitions
              summary = Summary.AddListItem(
                summary,
                Builtins.sformat(
                  _("Replicate Partitions: %1"),
                  Trans_yes_no(
                    Ops.get_string(
                      @EdirSettings,
                      "XAD_REPLICATE_PARTITIONS",
                      "yes"
                    )
                  )
                )
              )

              # DNS Locator Context
              summary = Summary.AddListItem(
                summary,
                Builtins.sformat(
                  _("OES DNS Services Locator Object Context: %1"),
                  NovellUtils.Nds2Ldap(
                    Ops.get_string(
                      @DnsSettings,
                      "CONFIG_DNS_LOCATOR_CONTEXT",
                      ""
                    )
                  )
                )
              )

              # DNS base DN
              summary = Summary.AddListItem(
                summary,
                Builtins.sformat(
                  _("OES DNS Services Root Server Info Context: %1"),
                  NovellUtils.Nds2Ldap(
                    Ops.get_string(@DnsSettings, "CONFIG_DNS_LDAP_BASEDN", "")
                  )
                )
              )

              # DNS Group Context
              summary = Summary.AddListItem(
                summary,
                Builtins.sformat(
                  _("OES DNS Services Group Object Context: %1"),
                  NovellUtils.Nds2Ldap(
                    Ops.get_string(@DnsSettings, "CONFIG_DNS_GROUP_CONTEXT", "")
                  )
                )
              )

              # DNS use secure port
              summary = Summary.AddListItem(
                summary,
                Builtins.sformat(
                  _("OES DNS Use Secure LDAP Port: %1"),
                  Trans_yes_no(
                    Ops.get_string(
                      @DnsSettings,
                      "CONFIG_DNS_USE_SECURE_PORT",
                      ""
                    )
                  )
                )
              )

              # DNS Proxy User
              summary = Summary.AddListItem(
                summary,
                Builtins.sformat(
                  _("Proxy User for OES DNS Management: %1"),
                  NovellUtils.Nds2Ldap(
                    Ops.get_string(
                      @DnsSettings,
                      "CONFIG_DNS_LDAP_USER_CONTEXT",
                      ""
                    )
                  )
                )
              )

              # DNS create server object
              summary = Summary.AddListItem(
                summary,
                Builtins.sformat(
                  _("Create OES DNS Server Object: %1"),
                  Trans_yes_no(
                    Ops.get_string(
                      @DnsSettings,
                      "CONFIG_DNS_CREATE_SERVER_OBJECT",
                      ""
                    )
                  )
                )
              )

              # DNS proxy credential storage location
              summary = Summary.AddListItem(
                summary,
                Builtins.sformat(
                  _("Store DNS Proxy Credentials in OCS: %1"),
                  Trans_yes_no(
                    Ops.get_string(
                      @DnsSettings,
                      "CONFIG_DNS_STORE_CREDENTIAL_IN_OCS",
                      "yes"
                    )
                  )
                )
              )
            end
          end

          summary = Summary.AddListItem(
            summary,
            Builtins.sformat(
              _("Admin Context: %1"),
              Ops.get_string(
                NovellLDAP.Settings,
                "CONFIG_LDAP_ADMIN_CONTEXT",
                ""
              )
            )
          )

          summary = Summary.AddListItem(
            summary,
            Builtins.sformat(
              _("Server Context: %1"),
              Ops.get_string(@EdirSettings, "CONFIG_EDIR_SERVER_CONTEXT", "")
            )
          )

          # Note, if there are multiple LAN cards in the machine, this will only display the first one.
          server_list = NovellLDAP.GetLocalServers(nil)
          firstStaticIP = Ops.get_string(
            Ops.get(server_list, 0, {}),
            "CONFIG_LDAP_SERVER_IP",
            ""
          )
          primary_server = NovellLDAP.GetAddressServer(
            firstStaticIP,
            server_list
          )

          summary = Summary.AddListItem(
            summary,
            Builtins.sformat(
              _("LDAP Port: %1"),
              Ops.get_integer(primary_server, "CONFIG_LDAP_PORT", 389)
            )
          )

          summary = Summary.AddListItem(
            summary,
            Builtins.sformat(
              _("LDAP Secure Port: %1"),
              Ops.get_integer(primary_server, "CONFIG_LDAP_SECURE_PORT", 636)
            )
          )

          summary = Summary.AddListItem(
            summary,
            Builtins.sformat(
              _("iMonitor Port: %1"),
              Ops.get_integer(@EdirSettings, "CONFIG_EDIR_HTTP_PORT", 8028)
            )
          )

          summary = Summary.AddListItem(
            summary,
            Builtins.sformat(
              _("iMonitor Secure Port: %1"),
              Ops.get_integer(@EdirSettings, "CONFIG_EDIR_HTTPS_PORT", 8030)
            )
          )

          # Time Servers
          timeServerList = Ops.get_list(
            @EdirSettings,
            "CONFIG_EDIR_NTP_SERVERS",
            []
          )
          if timeServerList != nil && timeServerList != []
            # Time Servers
            time_servers = ""
            cnt = 1
            Builtins.foreach(timeServerList) do |s|
              if cnt == 1
                time_servers = s
              else
                time_servers = Ops.add(Ops.add(time_servers, ", "), s)
              end
              cnt = Ops.add(cnt, 1)
            end
            summary = Summary.AddListItem(
              summary,
              Builtins.sformat(
                _("Network Time Protocol (NTP) servers: %1"),
                time_servers
              )
            )
          else
            summary = Summary.AddListItem(
              summary,
              Builtins.sformat(_("Network Time Protocol: %1"), _("Local Clock"))
            )
          end

          slp_mode = Ops.get_string(@EdirSettings, "CONFIG_EDIR_SLP_MODE", "")
          summary = Summary.AddListItem(
            summary,
            Builtins.sformat(_("SLP mode: %1"), Trans_slp_mode(slp_mode))
          )

          if slp_mode == "da_server"
            summary = Summary.AddListItem(
              summary,
              Builtins.sformat(
                _("Set SLP DASyncReg parameter in SLP configuration file: %1"),
                Trans_yes_no(
                  Ops.get_string(@EdirSettings, "CONFIG_EDIR_DASYNC", "")
                )
              )
            )

            summary = Summary.AddListItem(
              summary,
              Builtins.sformat(
                _("Periodically backup SLP settings: %1"),
                Trans_yes_no(
                  Ops.get_string(@EdirSettings, "CONFIG_EDIR_SLP_BACKUP", "")
                )
              )
            )

            if Ops.get_string(@EdirSettings, "CONFIG_EDIR_SLP_BACKUP", "yes") == "yes"
              summary = Summary.AddListItem(
                summary,
                Builtins.sformat(
                  _("Backup Interval in Seconds: %1"),
                  Ops.get_string(
                    @EdirSettings,
                    "CONFIG_EDIR_SLP_BACKUP_INTERVAL",
                    ""
                  )
                )
              )
            end
          end

          # Scopes
          if slp_mode == "multicast" || slp_mode == "da" ||
              slp_mode == "da_server"
            summary = Summary.AddListItem(
              summary,
              Builtins.sformat(
                _("SLP Scopes: %1"),
                Ops.get_string(@EdirSettings, "CONFIG_EDIR_SLP_SCOPES", "")
              )
            )
          end

          if slp_mode == "da"
            # DA Servers
            da_servers = ""
            slpDAList = Ops.get_list(@EdirSettings, "CONFIG_EDIR_SLP_DA", [])
            cnt = 1
            Builtins.foreach(slpDAList) do |s|
              if cnt == 1
                da_servers = s
              else
                da_servers = Ops.add(Ops.add(da_servers, ", "), s)
              end
              cnt = Ops.add(cnt, 1)
            end
            summary = Summary.AddListItem(
              summary,
              Builtins.sformat(_("SLP DA servers: %1"), da_servers)
            )
          end # upgrade mode
        else
          summary = Summary.AddListItem(
            summary,
            Builtins.sformat(
              _("Admin Name: %1"),
              Ops.get_string(
                NovellLDAP.Settings,
                "CONFIG_LDAP_ADMIN_CONTEXT",
                ""
              )
            )
          )

          summary = Summary.AddListItem(
            summary,
            Builtins.sformat(
              _("Path to nds.conf file: %1"),
              Ops.get_string(@EdirSettings, "CONFIG_EDIR_OLD_NDSCONF_FILE", "")
            )
          )
        end

        # NMAS Login Methods
        summary = Summary.AddListItem(
          summary,
          Builtins.sformat(
            _("NMAS Login:CertMutual: %1"),
            Trans_yes_no(
              Ops.get_string(@EdirSettings, "CONFIG_EDIR_NMAS_CERTMUTUAL", "no")
            )
          )
        )

        summary = Summary.AddListItem(
          summary,
          Builtins.sformat(
            _("NMAS Login:Challenge Response: %1"),
            Trans_yes_no(
              Ops.get_string(
                @EdirSettings,
                "CONFIG_EDIR_NMAS_CHLG_RESPONSE",
                "yes"
              )
            )
          )
        )

        summary = Summary.AddListItem(
          summary,
          Builtins.sformat(
            _("NMAS Login:DIGEST-MD5: %1"),
            Trans_yes_no(
              Ops.get_string(@EdirSettings, "CONFIG_EDIR_NMAS_DIGEST_MD5", "no")
            )
          )
        )

        summary = Summary.AddListItem(
          summary,
          Builtins.sformat(
            _("NMAS Login:NDS: %1"),
            Trans_yes_no(
              Ops.get_string(@EdirSettings, "CONFIG_EDIR_NMAS_NDS", "yes")
            )
          )
        )

        summary = Summary.AddListItem(
          summary,
          Builtins.sformat(
            _("NMAS Login:Simple Password: %1"),
            Trans_yes_no(
              Ops.get_string(@EdirSettings, "CONFIG_EDIR_NMAS_SIMPWD", "no")
            )
          )
        )

        summary = Summary.AddListItem(
          summary,
          Builtins.sformat(
            _("NMAS Login:SASL GSSAPI Password: %1"),
            Trans_yes_no(
              Ops.get_string(@EdirSettings, "CONFIG_EDIR_NMAS_GSSAPI", "no")
            )
          )
        )

        # Show the proxy user if available
        useCommonProxy = Ops.get_string(
          NovellLDAP.Settings,
          "CONFIG_LDAP_DO_PROXY",
          ""
        )
        if useCommonProxy == "yes"
          summary = Summary.AddListItem(
            summary,
            Builtins.sformat(
              _("OES Common Proxy User: %1"),
              Ops.get_string(
                NovellLDAP.Settings,
                "CONFIG_LDAP_PROXY_CONTEXT",
                ""
              )
            )
          )
        end

        summary = Summary.CloseList(summary)
      end

      [summary, []]
    end

    # Return packages needed to be installed and removed during
    # Autoinstallation to insure module has all needed software
    # installed.
    # @return [Hash] with 2 lists.
    def AutoPackages
      { "install" => [], "remove" => [] }
    end



    # Constructor - Ensure this modules SCR agents are properly registered.
    # FIXME: This is a bad hack!!!  Must talk with SUSE YaST team to solve the problem...
    def Edirectory
      agent_cfg = "cfg_edirectory.scr"
      agent_path = path(".sysconfig.edirectory")
      NovellUtils.EnsureSysconfigAgentMounted(agent_cfg, agent_path)

      nil
    end

    def SetldapSSLConfig
      if Ops.get_string(@EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        adminName = NovellUtils.Ldap2Nds(
          Ops.get_string(@EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
        )

        adminPassword = Ops.get_string(
          NovellLDAP.Settings,
          "CONFIG_LDAP_ADMIN_PASSWORD",
          ""
        )

        if Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "") != "forest" &&
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") != "new" ||
          Ops.get_string(@EdirSettings, "XAD_DOMAIN_TYPE", "") == "forest" &&
          Ops.get_string(@EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") != "new"

          adminPassword = Ops.get_string(
            @EdirSettings,
            "XAD_LDAP_ADMIN_PASSWORD",
            ""
          )
        end
      else
        adminName = NovellUtils.Ldap2Nds(
          Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_CONTEXT", "")
        )

        adminPassword = Ops.get_string(
          NovellLDAP.Settings,
          "CONFIG_LDAP_ADMIN_PASSWORD",
          ""
        )
      end

      adminName = NovellUtils.Typeful2Typeless(adminName)
      protocol_value = "+TLSv1.2"
      cipher_value = ""

      # Fetching the value of ldapSSLConfig during upgrade and retaining protocol and ciphers
      if Mode.update || Mode.autoupgrade
        cmd = Builtins.sformat(
          ("/opt/novell/eDirectory/bin/ldapconfig get \\\"ldapInterfaces\\\" -a %1 -w 'env:ADM_PASSWD' | grep -i 'ldapSSLConfig'"),
          adminName
        )
        val = Convert.to_map(
          SCR.Execute(
            path(".target.bash_output"),
            Ops.add(Ops.add(Ops.add("ADM_PASSWD='", adminPassword), "' "),cmd)
          )
        )
        exit_val = Ops.get_integer(val, "exit", -1)
        Builtins.y2milestone(
          "Edirectory.GetldapSSLConfig:ldapconfig:return exit code:%1",
          exit_val
        )
        if exit_val == 0
          val_out = NovellUtils.CleanUpString(
            Ops.get_string(val, "stdout", "")
          )
          Builtins.y2milestone(
            "Edirectory.GetldapSSLConfig:ldapconfig:return  stdout:%1",
            val_out
          )
          val_out = val_out.split('ldapSSLConfig: ').last
          parsed = JSON.parse(val_out)
          protocol_value = parsed["Info"]["Protocol"]
          cipher_value = parsed["Info"]["Ciphers"]

          if !Builtins.contains(protocol_value, "+TLSv1.2")
            protocol_value.concat("+TLSv1.2")
          end
        end
      end

      configValue = Builtins.sformat(
        ("{ \\\"Version\\\" : 1, \\\"Info\\\" : { \\\"Protocol\\\" : \\\"%1\\\", \\\"Ciphers\\\" : \\\"%2\\\" } }"),
        protocol_value,
        cipher_value
      )

      cmd = Builtins.sformat(
        "/opt/novell/eDirectory/bin/ldapconfig set \"ldapSSLConfig=%1\" -a '%2' -w 'env:ADM_PASSWD'",
        configValue,
        adminName
      )

      logCmd = Builtins.sformat(
        "/opt/novell/eDirectory/bin/ldapconfig set \"ldapSSLConfig=%1\" -a '%2' -w **** ",
        configValue,
        adminName,
      )

      Builtins.y2milestone(
        "Edirectory.SetldapSSLConfig:executing: %1",
        logCmd
      )

      val = Convert.to_map(
        SCR.Execute(
          path(".target.bash_output"),
          Ops.add(Ops.add(Ops.add("ADM_PASSWD='", adminPassword), "' "),cmd)
        )
      )

      exit_val = Ops.get_integer(val, "exit", -1)
      Builtins.y2milestone(
        "Edirectory.SetldapSSLConfig:ldapconfig:return exit code:%1",
        exit_val
      )
      ret = Ops.get_string(val, "stdout", "")
      ret = "" if ret == nil
      Builtins.y2milestone("Edirectory.SetldapSSLConfig:stdout:%1", ret)

      if exit_val == 0
        nldap_cmd = [ "nldap -u", "nldap -l" ]
        nldap_cmd.each do |f|
          Builtins.sleep(15000)
          val = Convert.to_map(SCR.Execute(path(".target.bash_output"), f))
          exit_val = Ops.get_integer(val, "exit", -1)
          Builtins.y2milestone(
            "Edirectory.SetldapSSLConfig:executing %1 return %2 exit_Code %3",
            f,
            val,
            exit_val
          )
        end
      end
    end

    def UpdateCachedAttributes
      if !NovellPatterns.IsPatternInstalled("novell-domain-services")
        local_server = Ops.get(NovellLDAP.GetLocalServers(nil), 0, {})
        sPort = Ops.get_integer(local_server, "CONFIG_LDAP_SECURE_PORT", 636)
        ip = Ops.get_string(local_server, "CONFIG_LDAP_SERVER_IP", "")

        adminPassword = Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_PASSWORD", "")

        cmd = Builtins.sformat(
          "/opt/novell/ncpserv/bin/ncp_update_cached_attrs_on_ext_refs.sh -d \"%1\" -i %2 -p %3 -s 1",
          NovellUtils.Nds2Ldap(Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_CONTEXT", "")),
          ip,
          sPort
        )

        val = Convert.to_map(
          SCR.Execute(
            path(".target.bash_output"),
            Ops.add(Ops.add(Ops.add("OES_ADMIN_DATA='", adminPassword), "' "),cmd)
          )
        )
        Builtins.y2milestone("Return value for %1 is = %2", cmd, val)
      end
    end

    publish :variable => :EdirSettings, :type => "map"
    publish :variable => :old_EdirSettings, :type => "map"
    publish :variable => :old_XadSettings, :type => "map"
    publish :variable => :old_DnsSettings, :type => "map"
    publish :variable => :DnsSettings, :type => "map"
    publish :variable => :ndsconfigWorked, :type => "boolean"
    publish :variable => :backButtonClicked, :type => "boolean"
    publish :variable => :quickInstallBackButtonClicked, :type => "boolean"
    publish :variable => :auto_clone, :type => "boolean"
    publish :variable => :oesinstall_dir, :type => "string"
    publish :variable => :schemaLogPath, :type => "string"
    publish :variable => :eDirInstalled, :type => "boolean"
    publish :variable => :dibExists, :type => "boolean"
    publish :variable => :eDirRunning, :type => "boolean"
    publish :variable => :eDir_Being_Configured, :type => "boolean"
    publish :variable => :ndsconfig_bin, :type => "string"
    publish :variable => :dibLocation, :type => "string"
    publish :variable => :ndsConfigFailureMap, :type => "map"
    publish :variable => :rerun_workflow, :type => "boolean"
    publish :variable => :retryInProgress, :type => "boolean"
    publish :variable => :nameMapCheck, :type => "boolean"
    publish :variable => :ldap_bind_no_response, :type => "string"
    publish :variable => :ldap_secure_bind_timeout, :type => "string"
    publish :variable => :validateCredsWarning, :type => "string"
    publish :variable => :credentialsFailedWarning, :type => "string"
    publish :variable => :adminWarning, :type => "string"
    publish :variable => :xadTestMode, :type => "boolean"
    publish :variable => :doXadSequence, :type => "boolean"
    publish :variable => :upgradeTestMode, :type => "boolean"
    publish :variable => :xad_pattern, :type => "string"
    publish :variable => :xad_packages_installed, :type => "boolean"
    publish :variable => :migration_pattern_installed, :type => "boolean"
    publish :variable => :ndsdcinit_bin, :type => "string"
    publish :variable => :service_configured_str, :type => "string"
    publish :variable => :channelUpgrade, :type => "boolean"
    publish :variable => :oesContext, :type => "string"
    publish :function => :Modified, :type => "boolean ()"
    publish :variable => :modified, :type => "boolean"
    publish :variable => :proposal_valid, :type => "boolean"
    publish :variable => :globals_configured, :type => "boolean"
    publish :variable => :autoyast_tool, :type => "boolean"
    publish :variable => :AbortFunction, :type => "boolean ()"
    publish :function => :Abort, :type => "boolean ()"
    publish :function => :GetNameServer, :type => "string ()"
    publish :function => :WriteNRMCerts, :type => "boolean ()"
    publish :function => :SetupEdirCerts, :type => "boolean ()"
    publish :function => :SoftwareInstalled, :type => "boolean ()"
    publish :function => :ProposeTreeType, :type => "string ()"
    publish :function => :ValidateTreeRootRights, :type => "integer (string, string, string, string)"
    publish :function => :GetExistingTreeName, :type => "string (string)"
    publish :function => :GetServerIP, :type => "string (string)"
    publish :function => :GetForestRoot, :type => "string (string)"
    publish :function => :GetParentDomain, :type => "string ()"
    publish :function => :GetParentDomainIP, :type => "string ()"
    publish :function => :GetDomainAdministrator, :type => "string (string)"
    publish :function => :CheckNameMapContainer, :type => "integer (string, string)"
    publish :function => :DoesDomainExistInForest, :type => "integer (string, string)"
    publish :function => :IsParentDomainMapped, :type => "integer (string)"
    publish :function => :CheckForExistingForest, :type => "integer (string, string)"
    publish :function => :CheckForValidNetbiosName, :type => "integer (string)"
    publish :function => :CheckForExistingNetbiosName, :type => "integer (string, string)"
    publish :function => :CheckForExistingNetbiosNameInSubnet, :type => "integer (string)"
    publish :function => :CheckContainerPartitioning, :type => "integer (string)"
    publish :function => :DoXadVersionCheck, :type => "integer (string)"
    publish :function => :GetXadServerContext, :type => "string (string, string, string, string)"
    publish :function => :ProposeXadContextSettings, :type => "map (string, string, string)"
    publish :function => :ProposeXadSettings, :type => "map ()"
    publish :function => :GetOES10dibLocation, :type => "string ()"
    publish :function => :DoesDIBExist, :type => "boolean ()"
    publish :function => :GetTreeName, :type => "string (string, integer)"
    publish :function => :DoesEdirectoryTreeExist, :type => "boolean (string)"
    publish :function => :CheckEdirUp, :type => "integer (string, string, string, integer)"
    publish :function => :WaitForLDAPtoBind, :type => "integer (integer, string, string, string)"
    publish :function => :ValidateXadSettings, :type => "boolean ()"
    publish :function => :ReadXadSettings, :type => "map ()"
    publish :function => :ReadEdirSettings, :type => "map ()"
    publish :function => :SaveXadSettings, :type => "boolean (map)"
    publish :function => :SaveEdirSettings, :type => "boolean (map)"
    publish :function => :setTuningParameters, :type => "boolean ()"
    publish :function => :Read, :type => "symbol ()"
    publish :function => :SSRootCert, :type => "boolean ()"
    publish :function => :ConfigIPAddresses, :type => "integer ()"
    publish :function => :SaveSysconfigFiles, :type => "boolean ()"
    publish :function => :ConfigureAndStartSLP, :type => "boolean ()"
    publish :function => :WriteEdirFailedFile, :type => "boolean ()"
    publish :function => :RunNDSconfigUpgrade, :type => "integer ()"
    publish :function => :RunNDSconfigRemove, :type => "integer ()"
    publish :function => :ContainerIsDefault, :type => "boolean ()"
    publish :function => :RunNDSconfig, :type => "integer (boolean)"
    publish :function => :GetContextInfo, :type => "list <string> (string, string)"
    publish :function => :Write, :type => "symbol ()"
    publish :function => :Import, :type => "boolean (map)"
    publish :function => :Export, :type => "map ()"
    publish :function => :ExportSettings, :type => "map ()"
    publish :function => :Summary, :type => "list ()"
    publish :function => :AutoPackages, :type => "map ()"
    publish :function => :Edirectory, :type => "void ()"
  end

  Edirectory = EdirectoryClass.new
  Edirectory.main
end
